@@ -26,7 +26,7 @@
 #include <kfiledialog.h>
 #include <kmenubar.h>
 #include <klocale.h>
-#include <kcolordlg.h>
+#include <kcolordialog.h>
 #include <kconfig.h>
 
 // application specific includes
@@ -35,6 +35,8 @@
 #include "kcoloreditdoc.h"
 #include "loadpalettedlg.h"
 #include "resource.h"
+#include <kpopupmenu.h>
+#include <kstatusbar.h>
 
 
 KColorEditApp::KColorEditApp() : KMainWindow(0) {
@@ -84,20 +86,22 @@ void KColorEditApp::initKeyAccel() {
 
   keyAccel->connectItem(KStdAccel::Help, this, SLOT(appHelpActivated()));
 
-  keyAccel->changeMenuAccel(fileMenu, ID_FILE_NEW, KStdAccel::New);
-  keyAccel->changeMenuAccel(fileMenu, ID_FILE_OPEN, KStdAccel::Open);
-  keyAccel->changeMenuAccel(fileMenu, ID_FILE_SAVE, KStdAccel::Save);
-  keyAccel->changeMenuAccel(fileMenu, ID_FILE_CLOSE, KStdAccel::Close);
-  keyAccel->changeMenuAccel(fileMenu, ID_FILE_PRINT, KStdAccel::Print);
-  keyAccel->changeMenuAccel(fileMenu, ID_FILE_QUIT, KStdAccel::Quit);
+  fileMenu->setAccel(KStdAccel::openNew().keyCodeQt(), ID_FILE_NEW);
+  fileMenu->setAccel(KStdAccel::open().keyCodeQt(), ID_FILE_OPEN);
+  fileMenu->setAccel(KStdAccel::save().keyCodeQt(), ID_FILE_SAVE);
+  fileMenu->setAccel(KStdAccel::close().keyCodeQt(), ID_FILE_CLOSE);
+  fileMenu->setAccel(KStdAccel::print().keyCodeQt(), ID_FILE_PRINT);
+  fileMenu->setAccel(KStdAccel::quit().keyCodeQt(), ID_FILE_QUIT);
+
+  editMenu->setAccel(KStdAccel::cut().keyCodeQt(), ID_EDIT_CUT);
+  editMenu->setAccel(KStdAccel::copy().keyCodeQt(), ID_EDIT_COPY);
+  editMenu->setAccel(KStdAccel::paste().keyCodeQt(), ID_EDIT_PASTE);
 
-  keyAccel->changeMenuAccel(editMenu, ID_EDIT_CUT, KStdAccel::Cut);
-  keyAccel->changeMenuAccel(editMenu, ID_EDIT_COPY, KStdAccel::Copy);
-  keyAccel->changeMenuAccel(editMenu, ID_EDIT_PASTE, KStdAccel::Paste);
 
   keyAccel->readSettings();
 }
 
+
 void KColorEditApp::initMenuBar() {
   ///////////////////////////////////////////////////////////////////
   // MENUBAR
@@ -111,7 +115,7 @@ void KColorEditApp::initMenuBar() {
   fileMenu->insertSeparator();
   fileMenu->insertItem(SmallIcon("filenew"), i18n("&New"), ID_FILE_NEW);
   fileMenu->insertItem(SmallIcon("fileopen"), i18n("&Open..."), ID_FILE_OPEN);
-  fileMenu->insertItem(i18n("Open &recent"), recentFilesMenu, ID_FILE_OPEN_RECENT);
+  fileMenu->insertItem(i18n("Open &Recent"), recentFilesMenu, ID_FILE_OPEN_RECENT);
 
   fileMenu->insertItem(SmallIcon("fileclose"), i18n("&Close"), ID_FILE_CLOSE);
   fileMenu->insertSeparator();
@@ -132,8 +136,8 @@ void KColorEditApp::initMenuBar() {
   ///////////////////////////////////////////////////////////////////
   // menuBar entry editMenu
   colorMenu = new QPopupMenu(this);
-  colorMenu->insertItem(i18n("From palette"), ID_COLOR_FROM_PALETTE);
-  colorMenu->insertItem(i18n("From screen"), ID_COLOR_FROM_SCREEN);
+  colorMenu->insertItem(i18n("From Palette"), ID_COLOR_FROM_PALETTE);
+  colorMenu->insertItem(i18n("From Screen"), ID_COLOR_FROM_SCREEN);
   //colorMenu->insertSeparator();
   //colorMenu->insertItem(i18n("Copy"), ID_COLOR_COPY);
   //colorMenu->insertItem(i18n("Paste"), ID_COLOR_PASTE);
@@ -142,7 +146,7 @@ void KColorEditApp::initMenuBar() {
   // menuBar entry viewMenu
   viewMenu = new QPopupMenu(this);
   viewMenu->setCheckable(true);
-  viewMenu->insertItem(i18n("&Color names"), ID_VIEW_COLOR_NAMES);
+  viewMenu->insertItem(i18n("&Color Names"), ID_VIEW_COLOR_NAMES);
   viewMenu->insertItem(i18n("&Toolbar"), ID_VIEW_TOOLBAR);
   viewMenu->insertItem(i18n("&Statusbar"), ID_VIEW_STATUSBAR);
 
@@ -485,7 +489,7 @@ bool KColorEditApp::slotFileSaveAs()
 
     while(result) {
         QString newName=KFileDialog::getSaveFileName(lastSavePaletteAsFileDir,
-                                                     "*|" + i18n("All files"), this, i18n("Save as..."));
+                                                     "*|" + i18n("All files"), this, i18n("Save As..."));
         if(newName.isEmpty())
             result = false;
         else {
@@ -547,7 +551,7 @@ void KColorEditApp::slotFileQuit()
   KMainWindow* w;
   if(memberList)
   {
-    for(w=memberList->first(); w!=0; w=memberList->first())
+    for(w=memberList->first(); w!=0; w=memberList->next())
     {
       // only close the window if the closeEvent is accepted. If the user presses Cancel on the saveModified() dialog,
       // the window and the application stay open.
