@@ -2,24 +2,18 @@
 #include <kaction.h>
 #include <kaboutdata.h>
 #include <kaboutdialog.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kbugreport.h>
 #include <kconfig.h>
 #include <kdebug.h>
 #include <kglobal.h>
 #include <klocale.h>
-#include <kimageeffect.h>
-#include <kinstance.h>
 #include <kmessagebox.h>
 #include <kprinter.h>
-#include <qobject.h>
-#include <qlabel.h>
-#include <qstring.h>
-#include <qimage.h>
-#include <qpixmap.h>
+#include <kstdaction.h>
+#include <ktip.h>
+#include <qtimer.h>
 
-// #include "../kviewshell/centeringScrollView.h"
-#include "fontpool.h"
 #include "kviewpart.h"
 #include "optiondialog.h"
 #include "kdvi_multipage.h"
@@ -51,10 +45,9 @@ KDVIMultiPageFactory::~KDVIMultiPageFactory()
 }
 
 
-KParts::Part *KDVIMultiPageFactory::createPart( QWidget *parentWidget, const char *widgetName, QObject *parent, const char *name, const char *, const QStringList & )
+KParts::Part *KDVIMultiPageFactory::createPartObject( QWidget *parentWidget, const char *widgetName, QObject *parent, const char *name, const char *, const QStringList & )
 {
   KParts::Part *obj = new KDVIMultiPage(parentWidget, widgetName, parent, name);
-  emit objectCreated(obj);
   return obj;
 }
 
@@ -74,28 +67,48 @@ KDVIMultiPage::KDVIMultiPage(QWidget *parentWidget, const char *widgetName, QObj
   setInstance(KDVIMultiPageFactory::instance()); 
 
   printer = 0;
+  document_history.clear();
   window = new dviWindow( 1.0, true, scrollView());
   preferencesChanged();
 
   connect( window, SIGNAL( setStatusBarText( const QString& ) ), this, SIGNAL( setStatusBarText( const QString& ) ) );
-  docInfoAction   = new KAction(i18n("Document &Info"), 0, this, SLOT(doInfo()), actionCollection(), "info_dvi");
-  exportPSAction  = new KAction(i18n("PostScript"), 0, this, SLOT(doExportPS()), actionCollection(), "export_postscript");
-  exportPDFAction = new KAction(i18n("PDF"), 0, this, SLOT(doExportPDF()), actionCollection(), "export_pdf");
+  docInfoAction    = new KAction(i18n("Document &Info"), 0, this, SLOT(doInfo()), actionCollection(), "info_dvi");
+
+  backAction       = KStdAction::back(this, SLOT(doGoBack()), actionCollection(), "go_back");
+  forwardAction    = KStdAction::forward(this, SLOT(doGoForward()), actionCollection(), "go_forward");
+  document_history.setAction(backAction, forwardAction);
+  document_history.clear();
+
+  findTextAction         = KStdAction::find(window, SLOT(showFindTextDialog()), actionCollection(), "find");
+  window->findNextAction = KStdAction::findNext(window, SLOT(findNextText()), actionCollection(), "findnext");
+  window->findNextAction->setEnabled(false);
+  window->findPrevAction = KStdAction::findPrev(window, SLOT(findPrevText()), actionCollection(), "findprev");
+  window->findPrevAction->setEnabled(false);
+  copyTextAction     = KStdAction::copy(window, SLOT(copyText()), actionCollection(), "copy_text");
+  window->DVIselection.setAction(copyTextAction);
+  selectAllAction    = KStdAction::selectAll(this, SLOT(doSelectAll()), actionCollection(), "edit_select_all");
+  new KAction(i18n("Enable All Warnings and Messages"), 0, this, SLOT(doEnableWarnings()), actionCollection(), "enable_msgs");
+  exportPSAction     = new KAction(i18n("PostScript"), 0, this, SLOT(doExportPS()), actionCollection(), "export_postscript");
+  exportPDFAction    = new KAction(i18n("PDF"), 0, this, SLOT(doExportPDF()), actionCollection(), "export_pdf");
+  exportTextAction   = new KAction(i18n("Text"), 0, this, SLOT(doExportText()), actionCollection(), "export_text");
 
   new KAction(i18n("&DVI Options"), 0, this, SLOT(doSettings()), actionCollection(), "settings_dvi");
+  new KAction(i18n("&Tip of the Day..."), 0, this, SLOT(showTip()), actionCollection(), "help_tipofday");
   new KAction(i18n("About the KDVI plugin..."), 0, this, SLOT(about()), actionCollection(), "about_kdvi");
   new KAction(i18n("Help on the KDVI plugin..."), 0, this, SLOT(helpme()), actionCollection(), "help_dvi");
   new KAction(i18n("Report Bug in the KDVI plugin..."), 0, this, SLOT(bugform()), actionCollection(), "bug_dvi");
 
   setXMLFile("kdvi_part.rc");
 
-  //@@@  scrollView()->setPage(window);
   scrollView()->addChild(window);
   connect(window, SIGNAL(request_goto_page(int, int)), this, SLOT(goto_page(int, int) ) );
   connect(window, SIGNAL(contents_changed(void)), this, SLOT(contents_of_dviwin_changed(void)) );
 
   readSettings();
   enableActions(false);
+
+  // Show tip of the day, when the first main window is shown.
+  QTimer::singleShot(0,this,SLOT(showTipOnStart()));
 }
 
 
@@ -112,12 +125,13 @@ KDVIMultiPage::~KDVIMultiPage()
 
 bool KDVIMultiPage::openFile()
 {
+  document_history.clear();
   emit setStatusBarText(QString(i18n("Loading file %1")).arg(m_file));
 
-  bool r = window->setFile(m_file);
-  window->gotoPage(1);
+  bool r = window->setFile(m_file,url().ref());
+  if (!r)
+    emit setStatusBarText(QString::null);
   window->changePageSize(); //  This also calles drawPage();
-  
   emit numberOfPages(window->totalPages());
   enableActions(r);
 
@@ -125,6 +139,15 @@ bool KDVIMultiPage::openFile()
 }
 
 
+void KDVIMultiPage::jumpToReference(QString reference)
+{
+  kdError() << "Reference: " << reference << endl;
+  if (window != 0) {
+    window->reference = reference;
+    window->all_fonts_loaded(); // In spite of its name, this method tries to parse the reference.
+  }
+}
+
 void KDVIMultiPage::contents_of_dviwin_changed(void)
 {
   emit previewChanged(true);
@@ -133,6 +156,7 @@ void KDVIMultiPage::contents_of_dviwin_changed(void)
 
 bool KDVIMultiPage::closeURL()
 {
+  document_history.clear();
   window->setFile(""); // That means: close the file. Resize the widget to 0x0.
   enableActions(false);
   return true;
@@ -149,13 +173,18 @@ QStringList KDVIMultiPage::fileFormats()
 
 bool KDVIMultiPage::gotoPage(int page)
 {
+  document_history.add(page,0);
   window->gotoPage(page+1);
   return true;
 }
 
 void KDVIMultiPage::goto_page(int page, int y)
 {
-  window->gotoPage(page+1, y);
+  document_history.add(page,y);
+  if (y != 0)
+    window->gotoPage(page+1, y);
+  else
+    window->gotoPage(page+1);
   scrollView()->ensureVisible(scrollView()->width()/2, y );
   emit pageInfo(window->totalPages(), page );
 }
@@ -212,6 +241,11 @@ void KDVIMultiPage::doInfo(void)
   window->showInfo();
 }
 
+void KDVIMultiPage::doSelectAll(void)
+{
+  window->selectAll();
+}
+
 void KDVIMultiPage::doExportPS(void)
 {
   window->exportPS();
@@ -222,15 +256,17 @@ void KDVIMultiPage::doExportPDF(void)
   window->exportPDF();
 }
 
+void KDVIMultiPage::doExportText(void)
+{
+  window->exportText();
+}
+
 void KDVIMultiPage::doSettings()
 {
-  if (options) {
-    options->show();
-    return;
+  if (!options) {
+    options = new OptionDialog(window);
+    connect(options, SIGNAL(preferencesChanged()), this, SLOT(preferencesChanged()));
   }
-
-  options = new OptionDialog(window);
-  connect(options, SIGNAL(preferencesChanged()), this, SLOT(preferencesChanged()));
   options->show();
 }
 
@@ -240,7 +276,7 @@ void KDVIMultiPage::about()
 				      i18n("the KDVI plugin"), 
 				      KAboutDialog::Close, KAboutDialog::Close);
 
-  ab->setProduct("kdvi", "0.9h", QString::null, QString::null);
+  ab->setProduct("kdvi", "1.0", QString::null, QString::null);
   ab->addTextPage (i18n("About"), 
 		   i18n("A previewer for Device Independent files (DVI files) produced "
 			"by the TeX typesetting system.<br>"
@@ -275,7 +311,7 @@ void KDVIMultiPage::about()
 
 void KDVIMultiPage::bugform()
 {
-  KAboutData *kab = new KAboutData("kdvi", I18N_NOOP("KDVI"), "0.9h", 0, 0, 0, 0, 0);
+  KAboutData *kab = new KAboutData("kdvi", I18N_NOOP("KDVI"), "1.0", 0, 0, 0, 0, 0);
   KBugReport *kbr = new KBugReport(0, true, kab );
   kbr->show();
 }
@@ -314,6 +350,8 @@ void KDVIMultiPage::preferencesChanged()
   int showHyperLinks = config->readNumEntry( "ShowHyperLinks", 1 );
   if (showHyperLinks != window->showHyperLinks())
     window->setShowHyperLinks(showHyperLinks);
+
+  window->setEditorCommand( config->readEntry( "EditorCommand", "" ));
 }
 
 
@@ -376,21 +414,14 @@ bool KDVIMultiPage::print(const QStringList &pages, int current)
   if (printer->pageList().isEmpty() == true) {
     KMessageBox::error( window,
 			i18n("The list of pages you selected was empty.\n"
-			     "Maybe you made an error in selecting the pages, \n"
-			     "e.g. by giving in invalid range like '7-2'.") );
+			     "Maybe you made an error in selecting the pages, "
+			     "e.g. by giving an invalid range like '7-2'.") );
     return false;
   }
 
   // Turn the results of the options requestor into a list arguments
   // which are used by dvips.
-  QString dvips_options;
-  // Number of copies and collated copies.
-  int copies = printer->numCopies();
-  if (copies > 1)
-    if (printer->collate() == KPrinter::Collate)
-      dvips_options += QString("-C %1 ").arg(copies);
-    else
-      dvips_options += QString("-c %1 ").arg(copies);
+  QString dvips_options = QString::null;
   // Print in reverse order.
   if ( printer->pageOrder() == KPrinter::LastPageFirst )
     dvips_options += "-r ";
@@ -414,7 +445,6 @@ bool KDVIMultiPage::print(const QStringList &pages, int current)
       commaflag = 1;
     dvips_options += QString("%1").arg(*it);
   }
-  kdDebug() << "dvips_options " << dvips_options << "\n";
 
   // Now print. For that, export the DVI-File to PostScript. Note that
   // dvips will run concurrently to keep the GUI responsive, keep log
@@ -422,12 +452,11 @@ bool KDVIMultiPage::print(const QStringList &pages, int current)
   // means that the dvi-widget will print the file when dvips
   // terminates, and then delete the output file.
   KTempFile tf;
-  kdDebug() << "TMP " << tf.name() << "\n";
   window->exportPS(tf.name(), dvips_options, printer);
 
   // "True" may be a bit euphemistic. However, since dvips runs
   // concurrently, there is no way of telling the result of the
-  // printing command now.
+  // printing command at this stage.
   return true;
 }
 
@@ -474,7 +503,7 @@ void KDVIMultiPage::reload()
     timer_id = -1;
     int currsav = window->curr_page();
 
-    bool r = window->setFile(m_file);
+    bool r = window->setFile(m_file, QString::null, false);
     enableActions(r);
 
     // Go to the old page and tell kviewshell where we are.
@@ -491,8 +520,50 @@ void KDVIMultiPage::reload()
 void KDVIMultiPage::enableActions(bool b)
 {
   docInfoAction->setEnabled(b);
+  selectAllAction->setEnabled(b);
+  findTextAction->setEnabled(b);
   exportPSAction->setEnabled(b);
   exportPDFAction->setEnabled(b);
+  exportTextAction->setEnabled(b);
 }
 
+void KDVIMultiPage::doGoBack(void)
+{
+  historyItem *it = document_history.back();
+  if (it != 0) 
+    goto_page(it->page, it->ypos);
+  else
+    kdDebug(4300) << "Faulty return -- bad history buffer" << endl;
+  return;
+}
+
+void KDVIMultiPage::doGoForward(void)
+{
+  historyItem *it = document_history.forward();
+  if (it != 0)
+    goto_page(it->page, it->ypos);
+  else
+    kdDebug(4300) << "Faulty return -- bad history buffer" << endl;
+  return;
+}
+
+void KDVIMultiPage::doEnableWarnings(void)
+{
+  KMessageBox::information (window, i18n("All messages and warnings will now be shown."));
+  KMessageBox::enableAllMessages();
+  kapp->config()->reparseConfiguration();
+  KTipDialog::setShowOnStart(true);
+}
+
+void KDVIMultiPage::showTip(void)
+{
+  KTipDialog::showTip(window, "kdvi/tips", true);
+}
+
+void KDVIMultiPage::showTipOnStart(void)
+{
+  KTipDialog::showTip(window, "kdvi/tips");
+}
+
+
 #include "kdvi_multipage.moc"
