@@ -1,6 +1,6 @@
 /*
 
-  $Id: fax2tiff.c,v 1.4 1999/07/24 21:20:19 waba Exp $
+  $Id: fax2tiff.c,v 1.5 2001/02/18 05:39:05 waba Exp $
 
   Copyright (C) 1997 Bernd Johannes Wuebben   
                      wuebben@math.cornell.edu
@@ -49,8 +49,8 @@
 
 TIFF	*faxTIFF;
 #define XSIZE		1728
-char	rowbuf[TIFFhowmany(XSIZE,8)];
-char	refbuf[TIFFhowmany(XSIZE,8)];
+unsigned char	rowbuf[TIFFhowmany(XSIZE,8)];
+unsigned char	refbuf[TIFFhowmany(XSIZE,8)];
 
 int	faxt2tiffverbose;
 int	stretch;
@@ -58,7 +58,6 @@ uint16	badfaxrun;
 uint32	badfaxlines;
 
 int	copyFaxFile(TIFF* tifin, TIFF* tifout);
-static	void usage(void);
 
 static tsize_t
 DummyReadProc(thandle_t fd, tdata_t buf, tsize_t size)
@@ -79,14 +78,13 @@ fax2tiffmain(const char* inputfile, const char* outputfile,int bitorder,int stre
 {
   FILE *in;
   TIFF *out = NULL;
-  TIFFErrorHandler whandler;
+  TIFFErrorHandler whandler = NULL;
   int compression = COMPRESSION_CCITTFAX3;
   int fillorder = FILLORDER_LSB2MSB;
   uint32 group3options = GROUP3OPT_FILLBITS|GROUP3OPT_2DENCODING;
   int photometric = PHOTOMETRIC_MINISWHITE;
   int mode = FAXMODE_CLASSF;
   int rows;
-  int c;
   int pn, npages;
   
   if(stretchit)
@@ -187,6 +185,7 @@ fax2tiffmain(const char* inputfile, const char* outputfile,int bitorder,int stre
   /*	npages = argc - optind;*/ /* TODO ???????*/
 
   npages = 1;
+  pn = 0;
 
   /* NB: this must be done after directory info is setup */
   
@@ -343,6 +342,8 @@ copyFaxFile(TIFF* tifin, TIFF* tifout)
 	return (row);
 }
 
+#if 0
+
 char* fax2tiffstuff[] = {
 "usage: fax2tiff [options] input.g3...",
 "where options are:",
@@ -376,3 +377,4 @@ usage(void)
 		fprintf(stderr, "%s\n", fax2tiffstuff[i]);
 	exit(EXIT_FAILURE);
 }
+#endif
