@@ -1,6 +1,6 @@
    /*
 
-    $Id: kfax.cpp,v 1.58 2001/05/08 02:42:27 jsinger Exp $
+    $Id: kfax.cpp,v 1.65 2002/01/26 22:53:18 binner Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -34,10 +34,11 @@
 #include <qfile.h>
 #include <qstrlist.h>
 #include <qdragobject.h>
+#include <qtimer.h>
 
 #include <klocale.h>
 #include <kaboutdata.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kiconloader.h>
 #include <kfiledialog.h>
 #include <kstdaccel.h>
@@ -53,6 +54,7 @@
 #include "kfax.moc"
 #include "version.h"
 #include "viewfax.h"
+#include <kpopupmenu.h>
 
 #ifdef HAVE_PATHS_H
 #include <paths.h>
@@ -402,8 +404,8 @@ void TopLevel::setupMenuBar(){
   view->insertItem(i18n("&Mirror Page"),this,SLOT(mirrorPage()));
   view->insertItem(i18n("&Flip Page"),this,SLOT(flipPage()));
   view->insertSeparator(-1);
-  view->insertItem(i18n("Zoom &in"),this,SLOT(zoomin()));
-  view->insertItem(i18n("Zoom &out"),this,SLOT(zoomout()));
+  view->insertItem(i18n("Zoom &In"),this,SLOT(zoomin()));
+  view->insertItem(i18n("Zoom &Out"),this,SLOT(zoomout()));
 
 
 
@@ -447,7 +449,7 @@ void TopLevel::setupToolBar()
     */
     toolBar()->insertSeparator();
 
-    toolBar()->insertButton(BarIcon("page"), ID_PAGE, TRUE, i18n("Go to page ..."));
+    toolBar()->insertButton(BarIcon("page"), ID_PAGE, TRUE, i18n("Go to Page ..."));
 
     toolBar()->setBarPos( KToolBar::Top );
 	
@@ -1084,8 +1086,8 @@ void TopLevel::readSettings()
 	pi.lpr = config->readNumEntry("print", 1);
 	pi.scale = config->readNumEntry("scale", 0);
 	pi.margins = config->readNumEntry("margins", 0);
-	pi.xmargin = config->readNumEntry("xmargin", 0.0);
-	pi.ymargin = config->readNumEntry("ymargin", 0.0);
+	pi.xmargin = config->readDoubleNumEntry("xmargin", 0.0);
+	pi.ymargin = config->readDoubleNumEntry("ymargin", 0.0);
 	pi.pagesize = config->readEntry("PageSize",US_LETTER);
 }
 
@@ -2337,8 +2339,8 @@ int copyfile(const char* toname,char* fromname)
 
   if (QFile::exists(toname)) {
     if(KMessageBox::questionYesNo( 0,
-			      i18n("A file with this name already exists\n"
-			      "Do you want to overwrite it?\n\n")))
+			      i18n("A file with this name already exists.\n"
+			      "Do you want to overwrite it?")))
       return 1;
   }
 
