@@ -1,6 +1,6 @@
     /*
 
-    $Id: kfax.h,v 1.24 2000/11/30 23:20:54 waba Exp $
+    $Id: kfax.h,v 1.27 2001/11/03 14:20:14 andreas Exp $
 
     Requires the Qt widget libraries, available at no cost at
     http://www.troll.no
@@ -28,7 +28,7 @@
 #ifndef _KFAX_H_
 #define _KFAX_H_
 
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstring.h>
 
 #include <qpopupmenu.h>
@@ -37,7 +37,7 @@
 #include <qkeycode.h>
 #include <qaccel.h>
 #include <qobject.h>
-#include <qmultilinedit.h>
+#include <qmultilineedit.h>
 #include <qradiobutton.h>
 #include <qfiledialog.h>
 #include <qcheckbox.h>
@@ -46,7 +46,7 @@
 #include <qregexp.h>
 #include <qprinter.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kconfig.h>
 #include <ktoolbar.h>
 
@@ -109,7 +109,7 @@ public:
     void openNetFile( const KURL& _url);
     void saveNetFile( const KURL& _url );
 
-    static QList<TopLevel> windowList;
+    static QPtrList<TopLevel> windowList;
     QPopupMenu *file, *view, *help,*options,*right_mouse_button, *colors;
 
     void closeEvent( QCloseEvent *e );
