@@ -1,5 +1,5 @@
 /*
-    $Id: print.h,v 1.7 1999/10/09 17:17:04 bieker Exp $
+    $Id: print.h,v 1.8 2001/11/03 14:20:14 andreas Exp $
 
     Requires the Qt widget libraries, available at no cost at 
     http://www.troll.no
@@ -44,7 +44,7 @@
 
 #include <qstring.h>
 #include <qfont.h>
-#include <kapp.h>
+#include <kapplication.h>
 
 #define US_LETTER i18n("US Letter 8.5x11 in")
 #define US_LEGAL i18n("US Legal 8.5x14 in")
