@@ -161,7 +161,7 @@ static KCmdLineOptions options[] =
    {"l", 0, 0 },
    {"landscape", 	I18N_NOOP("Turn image 90 degrees (landscape mode)"), 0 },
    {"u", 0, 0 },
-   {"upsidedown", 	I18N_NOOP("Turn image upside/down"), 0 },
+   {"upsidedown", 	I18N_NOOP("Turn image upside down"), 0 },
    {"i", 0, 0 },
    {"invert", 		I18N_NOOP("Invert black and white."), 0 },
    {"m", 0, 0 },
