@@ -7,8 +7,9 @@
 #include <qscrollview.h>
 #include <qimage.h>
 #include <qpixmap.h>
-#include <qprinter.h>
+#include <kprinter.h>
 #include <qpaintdevicemetrics.h>
+#include <qpainter.h>
 #include <qfile.h>
 
 #include <kinstance.h>
@@ -18,7 +19,7 @@
 #include <kglobal.h>
 #include <kconfig.h>
 #include <kimageio.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 
 
 #include <tiffio.h>
@@ -52,10 +53,9 @@ KFaxMultiPageFactory::~KFaxMultiPageFactory()
   s_instance = 0;
 }
 
-KParts::Part *KFaxMultiPageFactory::createPart( QWidget *parentWidget, const char *widgetName, QObject *parent, const char *name, const char *, const QStringList & )
+KParts::Part *KFaxMultiPageFactory::createPartObject( QWidget *parentWidget, const char *widgetName, QObject *parent, const char *name, const char *, const QStringList & )
 {
   KParts::Part *obj = new KFaxMultiPage( parentWidget, widgetName, parent, name);
-  emit objectCreated(obj);
   return obj;
 }
 
@@ -204,8 +204,8 @@ bool KFaxMultiPage::gotoPage(int page)
   if (!fp)
     return false;
 
-  int w = (int)_zoom*672.0;
-  int h = (int)_zoom*825.0;
+  int w = static_cast<int>(_zoom*672.0);
+  int h = static_cast<int>(_zoom*825.0);
   fp->scale(w, h, antiAct->isChecked());
   window->setBackgroundPixmap(fp->scaledPixmap());
   window->resize(w, h);
@@ -224,8 +224,8 @@ double KFaxMultiPage::setZoom(double zoom)
   KFaxPage *fp = faxPages.at(_currentPage);
   if (!fp)
     return 0;
-  fp->scale((int)672.0*zoom, (int)825.0*zoom, antiAct->isChecked());
-  window->resize((int)672.0*zoom, (int)825.0*zoom);
+  fp->scale((int)(672.0*zoom), (int)(825.0*zoom), antiAct->isChecked());
+  window->resize((int)(672.0*zoom), (int)(825.0*zoom));
   window->setBackgroundPixmap(fp->scaledPixmap());
   scrollView()->resizeContents(window->width(), window->height());
   _zoom = zoom;
@@ -280,16 +280,16 @@ void KFaxMultiPage::toggleAnti()
 
 bool KFaxMultiPage::print(const QStringList &pages, int current)
 {
-  QPrinter printer;
+  KPrinter printer;
 
-  printer.setColorMode(QPrinter::GrayScale);
+  printer.setColorMode(KPrinter::GrayScale);
   printer.setFullPage(true);
 
   if (printer.setup())
     {
       QStringList pagesTmp = pages;
       QStringList::Iterator it = pagesTmp.begin();
-      if (printer.pageOrder() == QPrinter::FirstPageFirst)
+      if (printer.pageOrder() == KPrinter::FirstPageFirst)
 	{
 	  for (; it != pagesTmp.end(); ++it)
 	    {
@@ -413,7 +413,7 @@ QPixmap KFaxPage::scaledPixmap()
 }
 
 
-void KFaxPage::print(QPrinter *printer)
+void KFaxPage::print(KPrinter *printer)
 {
   QPainter p;
   QPaintDeviceMetrics metric(printer);
