@@ -50,6 +50,8 @@ class DrawView : public QWidget
     enum ColorScheme { Rgb, Hsv };
     enum FractRunning { FUnknown, FMandel, FJulia };
     DrawView( QWidget *parent );
+    ~DrawView();
+
     int getActualIter();
     int getDefaultIter();
     double getActualBailout();
@@ -84,10 +86,11 @@ class DrawView : public QWidget
     void changeToMandel();
     void changeToJulia();
     void stop();
+    void prepareClose();
     void doZoomIn();
     void doZoomOut();
     void goDefaults();
-    void loadParam( char *name = NULL );
+    void loadParam( const QString & name = QString::null );
     void saveParam();
     void savePic();
   protected:
