@@ -1,8 +1,6 @@
 /*
- *   kghostview: KDE PostScript viewer
- *   This file: Copyright (C) 2000 Espen Sand, espen@kde.org
- *   Uses ideas from ealier dialog code 
- *
+ *   Copyright (C) 1997-2002 the KGhostView authors. See file AUTHORS.
+ *   
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -26,7 +24,7 @@
 #include <qlineedit.h>
 #include <qvalidator.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 
@@ -131,7 +129,7 @@ int GotoDialogData::numPage( int section ) const
 
 
 GotoDialog::GotoDialog( QWidget *parent, const char *name, bool modal)
-  :KDialogBase( parent, name, modal, i18n("Go to page"), Ok|Apply|Close, Ok, 
+  :KDialogBase( parent, name, modal, i18n("Go to Page"), Ok|Apply|Close, Ok, 
 		true )
 {
   QFrame *page = makeMainWidget();
