@@ -1,55 +1,74 @@
-#include <kiconloader.h>
-#include <kstddirs.h>
-#include <kapp.h>
+/** 
+ * Copyright (C) 2000-2002 the KGhostView authors. See file AUTHORS.
+ * 	
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
+#include <stdlib.h>
+
 #include <kaction.h>
-#include <klocale.h>
+#include <kapplication.h>
 #include <kfiledialog.h>
-#include <kmessagebox.h>
+#include <kiconloader.h>
 #include <klibloader.h>
+#include <klocale.h>
+#include <kmessagebox.h>
+#include <kstandarddirs.h>
+#include <kstatusbar.h>
 #include <kstdaction.h>
+#include <ktempfile.h>
 
 #include "kgv_miniwidget.h"
 #include "kgv_view.h"
 #include "kgvpageview.h"
 
+#undef Always  // avoid X11/Qt namespace clash
 #include "kgvshell.moc"
 
 //TODO -- disable GUI when no file
 //TODO -- don't stay open when no file, go directly to KFileDialog
 
-KGVShell::KGVShell()
+KGVShell::KGVShell() : 
+    _tmpFile( 0 )
 {
-    m_gvpart = new KGVPart( false, this, "kgvpart", this, "kgvpart" );
-
-    statedep = new KActionCollection( this, "statedep" );
+    m_gvpart = new KGVPart( this, "kgvpart", this, "kgvpart" );
 
     /*---- File -----------------------------------------------------------*/
-    openact =
-	    KStdAction::open( this, SLOT( slotFileOpen() ),
+    openact = 
+	    KStdAction::open( this, SLOT( slotFileOpen() ), 
 			      actionCollection() );
-    recent =
-	    KStdAction::openRecent( this, SLOT( openURL( const KURL& ) ),
+    recent = 
+	    KStdAction::openRecent( this, SLOT( openURL( const KURL& ) ), 
 				    actionCollection() );
-    statedep->insert(
-	    KStdAction::print( m_gvpart->miniWidget(), SLOT( print() ),
-			       actionCollection() ) );
+	    KStdAction::print( m_gvpart->miniWidget(), SLOT( print() ), 
+			       actionCollection() );
     (void)
 	    KStdAction::quit( this, SLOT( slotQuit() ), actionCollection() );
 
     /*---- View -----------------------------------------------------------*/
-    statedep->insert(
 	    KStdAction::redisplay( m_gvpart->miniWidget(), SLOT( redisplay() ),
-				   actionCollection()) );
-    statedep->insert(
-	    new KAction( i18n( "&Fit To Page Width" ), 0, this,
+				   actionCollection());
+	    new KAction( i18n( "&Fit to Page Width" ), 0, this,
 			 SLOT( slotFitToPage() ), actionCollection(),
-			 "fit_to_page") );
-
+			 "fit_to_page");
+  
     /*---- Settings -------------------------------------------------------*/
-    showtoolbar =
+    showtoolbar = 
 	    KStdAction::showToolbar( this, SLOT(slotShowToolBar() ),
 				     actionCollection());
-    showstatusbar =
+    showstatusbar = 
 	    KStdAction::showStatusbar( this, SLOT(slotShowStatusBar() ),
 				       actionCollection());
 
@@ -67,11 +86,12 @@ KGVShell::KGVShell()
     setCentralWidget( m_gvpart->widget() );
     createGUI( m_gvpart );
 
-    readSettings();
-    enableStateDepActions( false );
+    if (!initialGeometrySet())
+        resize(640,400);
 
-    //TODO: use last size
-    resize( width0, height0 );
+    (void) statusBar(); // Create statusBar
+    readSettings();
+    stateChanged( "initState" );
 
     // Make sure the view has the keyboard focus.
     m_gvpart->widget()->setFocus();
@@ -80,7 +100,15 @@ KGVShell::KGVShell()
 KGVShell::~KGVShell()
 {
     writeSettings();
-    delete m_gvpart;
+    
+    if( _tmpFile )
+    {
+	_tmpFile->setAutoDelete( true );
+	delete _tmpFile;
+	_tmpFile = 0;
+    }
+    
+    // delete m_gvpart;
 }
 
 void
@@ -89,19 +117,19 @@ KGVShell::slotQuit()
     kapp->closeAllWindows();
 }
 
-void 
+void
 KGVShell::readProperties( KConfig *config )
 {
     KURL url = config->readEntry( "URL" );
     if ( url.isValid() ) {
         openURL( url );
         m_gvpart->miniWidget()->goToPage( config->readNumEntry( "Current Page", 0 ));
-        m_gvpart->miniWidget()->setMagstep( config->readNumEntry( "Magnification", 1 ));
+        // m_gvpart->miniWidget()->setMagstep( config->readNumEntry( "Magnification", 1 ));
     }
 }
 
 void 
-KGVShell::saveProperties( KConfig *config )
+KGVShell::saveProperties( KConfig* config )
 {
     config->writeEntry( "URL", m_gvpart->url().prettyURL() );
     config->writeEntry( "Current Page", m_gvpart->miniWidget()->currentPage() );
@@ -111,36 +139,22 @@ KGVShell::saveProperties( KConfig *config )
 void
 KGVShell::readSettings()
 {
-    KConfig* config = KGlobal::config();
-    QString oldGroup = config->group();
-    config->setGroup( "General" );
-    showtoolbar->setChecked( config->readBoolEntry( "ShowToolBar", true ) );
-    showstatusbar->setChecked( config->readBoolEntry( "ShowStatusBar", true ));
-    width0 = config->readUnsignedNumEntry( "WindowWidth", 600 );
-    height0 = config->readUnsignedNumEntry( "WindowHeight", 300 );
-    config->setGroup( oldGroup );
+    applyMainWindowSettings(KGlobal::config(), "MainWindow");
 
-    slotShowToolBar();
-    slotShowStatusBar();
-
-    recent->loadEntries( config );
+    showstatusbar->setChecked(!statusBar()->isHidden());
+    showtoolbar->setChecked(!toolBar()->isHidden());
+    
+    recent->loadEntries( KGlobal::config() );
 }
 
 void
 KGVShell::writeSettings()
 {
-    KConfig *config = KGlobal::config();
-    QString oldGroup = config->group();
-    config->setGroup( "General" );
-    config->writeEntry( "ShowToolBar", showtoolbar->isChecked() );
-    config->writeEntry( "ShowStatusBar", showstatusbar->isChecked() );
-    config->writeEntry( "WindowWidth", width() );
-    config->writeEntry( "WindowHeight", height() );
-    config->setGroup( oldGroup );
+    saveMainWindowSettings(KGlobal::config(), "MainWindow");
 
-    recent->saveEntries( config );
+    recent->saveEntries( KGlobal::config() );
 
-    config->sync();
+    KGlobal::config()->sync();
 }
 
 void
@@ -148,15 +162,53 @@ KGVShell::openURL( const KURL & url )
 {
     if( m_gvpart->openURL( url ) ) {
 	recent->addURL (url);
-	enableStateDepActions( true );
+	stateChanged( "documentState" );
     }
 }
 
 void
 KGVShell::openStdin()
-{
-    if( m_gvpart->openStdin() )
-	enableStateDepActions( true );
+{    
+    if( _tmpFile ) 
+    {
+	_tmpFile->setAutoDelete( true );
+	delete _tmpFile;
+    }
+ 
+    _tmpFile = new KTempFile;
+    _tmpFile->setAutoDelete( true );
+    
+    if( _tmpFile->status() != 0 ) {
+	KMessageBox::error( this,
+		i18n( "Could not create temporary file: %1" )
+		.arg( strerror( _tmpFile->status() ) ) );
+	return;
+    }
+
+    QByteArray buf( BUFSIZ );
+    int read = 0, wrtn = 0;
+    while( ( read = fread( buf.data(), sizeof(char), buf.size(), stdin ) )
+	    > 0 ) {
+	wrtn = _tmpFile->file()->writeBlock( buf.data(), read );
+	if( read != wrtn )
+	    break;
+	kapp->processEvents();
+    }
+
+    if( read != 0 ) {
+	KMessageBox::error( this,
+		i18n( "Could not open standard input stream: %1" )
+		.arg( strerror( errno ) ) );
+	return;
+    }
+
+    _tmpFile->close();
+
+    if( m_gvpart->openURL( _tmpFile->name() ) )
+    {
+	setCaption( "stdin" );
+	stateChanged( "documentState" );
+    }
 }
 
 void KGVShell::slotFileOpen()
@@ -206,8 +258,3 @@ void KGVShell::slotShowToolBar()
     }
 }
 
-void KGVShell::enableStateDepActions( bool enable )
-{
-    for( uint i = 0; i < statedep->count(); i++ )
-	statedep->action( i )->setEnabled( enable );
-}
