@@ -18,6 +18,9 @@
     Boston, MA 02111-1307, USA.
 */  
 
+#include <qpainter.h>
+#include <kdebug.h>
+
 #include "kcolorgrid.h"
 #include "utils.h"
 
@@ -26,7 +29,7 @@ void KColorArray::remove(int idx)
   int oldsize = size();
   if(idx >= (int)size())
   {
-    warning("KColorArray::remove: Index %d out of range", idx);
+    kdWarning() << "KColorArray::remove: Index " << idx << " out of range" << endl;
     return;
   }
   KColorArray tmp(*this);
@@ -34,22 +37,22 @@ void KColorArray::remove(int idx)
   resize(size()-1);
   for(int i = idx; i < oldsize-1; i++)
     at(i) = tmp[i+1];
-  //debug("KColorArray::remove() %u\t-\tsize: %d", at(idx), size());
+  //kdDebug() << "KColorArray::remove() " << at(idx) << "\t-\tsize: " << size() << endl;
 }
 
 void KColorArray::append(uint c)
 {
   resize(size()+1);
   at(size()-1) = c;
-  //debug("KColorArray::append() %u\t-\tsize: %d", c, size());
+  //kdDebug() << "KColorArray::append() " << c << "\t-\tsize: " << size() << endl;
 }
 
 uint KColorArray::closestMatch(uint color)
 {
-  //debug("KColorArray: %u", c);
+  //kdDebug() << "KColorArray: " << c << endl;
   uint c = color & ~OPAQUE_MASK, d = 0xffffff, t;
-  //debug("KColorArray: %u", c);
-  //debug("KColorArray: %u", c|OPAQUE_MASK);
+  //kdDebug() << "KColorArray: " << c << endl;
+  //kdDebug() << "KColorArray: " << c|OPAQUE_MASK << endl;
   uint cb = c;
   for(uint i = 0; i < size(); i++)
   {
@@ -69,7 +72,7 @@ uint KColorArray::closestMatch(uint color)
 KColorGrid::KColorGrid(QWidget *parent, const char *name, int space)
  : QWidget(parent, name)
 {
-  //debug("KColorGrid - constructor");
+  //kdDebug() << "KColorGrid - constructor" << endl;
   s = space;
   rows = cols = totalwidth = totalheight = 0;
   setCellSize(10);
@@ -78,7 +81,7 @@ KColorGrid::KColorGrid(QWidget *parent, const char *name, int space)
   numcolors.resize(0);
   gridcolors.resize(0);
 
-  //debug("KColorGrid - constructor - done");
+  //kdDebug() << "KColorGrid - constructor - done" << endl;
 }
 /*
 void KColorGrid::show()
@@ -89,15 +92,14 @@ void KColorGrid::show()
 */
 void KColorGrid::paintEvent(QPaintEvent *e)
 {
-  //debug("KColorGrid::paintEvent");
+  //kdDebug() << "KColorGrid::paintEvent" << endl;
 
   //updateScrollBars();
   //QWidget::paintEvent(e);
 
   const QRect urect = e->rect();
 
-  //debug("Update rect = ( %i, %i, %i, %i )",
-    //urect.left(),urect.top(), urect.width(), urect.height() );
+  //kdDebug() << "Update rect = ( " << //urect.left() << ", " << urect.top() << ", " << urect.width() << ", " << urect.height() << " )" << endl;
 
 
   int firstcol = getX(urect.x())-1;
@@ -113,18 +115,17 @@ void KColorGrid::paintEvent(QPaintEvent *e)
   firstcol = (firstcol < 0) ? 0 : firstcol;
   lastrow = (lastrow >= rows) ? rows : lastrow;
   lastcol = (lastcol >= cols) ? cols : lastcol;
-  //debug("%d x %d  -  row: %d x %d", urect.x(), urect.y(), urect.width(), urect.height());
-  //debug("col: %d -> %d  -  row: %d -> %d", firstcol, lastcol, firstrow, lastrow);
+  //kdDebug() << urect.x() << " x " << urect.y() << "  -  row: " << urect.width() << " x " << urect.height() << endl;
+  //kdDebug() << "col: " << firstcol << " -> " << lastcol << "  -  row: " << firstrow << " -> " << lastrow << endl;
 
 /*
   if(this->isA("KDrawGrid"))
-    debug("KDrawGrid\n   firstcol: %d\n   lastcol: %d\n   firstrow: %d\n   lastrow: %d",
-        firstcol, lastcol, firstrow, lastrow);
+    kdDebug() << "KDrawGrid\n   firstcol: " << firstcol << "\n   lastcol: " << lastcol << "\n   firstrow: " << firstrow << "\n   lastrow: " << lastrow << endl;
 */
   for(int i = firstrow; i < lastrow; i++)
   {
     //if(this->isA("KDrawGrid"))
-    //  debug("Updating row %d", i);
+    //  kdDebug() << "Updating row " << i << endl;
     for(int j = firstcol; j < lastcol; j++)
     {
       matrix.translate( (j*cellsize), (i*cellsize) );
@@ -145,8 +146,8 @@ void KColorGrid::paintEvent(QPaintEvent *e)
 /*
 void KColorGrid::resizeEvent(QResizeEvent *)
 {
-  //debug("resize: width:  %d - total: %d", width(), totalwidth);
-  //debug("resize: height: %d - total: %d", height(), totalheight);
+  //kdDebug() << "resize: width:  " << width() << " - total: " << totalwidth << endl;
+  //kdDebug() << "resize: height: " << height() << " - total: " << totalheight << endl;
 }
 */
 
@@ -175,15 +176,15 @@ int KColorGrid::getX( int x )
 
 const QRect KColorGrid::viewRect()
 {
-  //debug("viewRect");
+  //kdDebug() << "viewRect" << endl;
   const QRect r(0, 0, width(), height());
-  //debug("viewRect - %d x %d - %d x %d", x, y, w, h);
+  //kdDebug() << "viewRect - " << x << " x " << y << " - " << w << " x " << h << endl;
   return r;
 }
 
 void KColorGrid::setNumRows(int n)
 {
-  //debug("setNumRows");
+  //kdDebug() << "setNumRows" << endl;
   if(n < 0 || n == rows)
     return;
 
@@ -193,25 +194,25 @@ void KColorGrid::setNumRows(int n)
   //QTableView::setNumRows(n);
   totalheight = (n * cellsize) + 1;
   resize(totalwidth, totalheight);
-  //debug("setNumRows() - gridcolors: %d  size: %d", gridcolors.size(), numCols()*numRows());
+  //kdDebug() << "setNumRows() - gridcolors: " << gridcolors.size() << "  size: " << numCols()*numRows() << endl;
 }
 
 void KColorGrid::setNumCols(int n)
 {
-  //debug("setNumCols");
+  //kdDebug() << "setNumCols" << endl;
   if(n < 0)
     return;
   int on = numCols();
   KColorArray gc(gridcolors);
   gc.detach();
-  //debug("gc size: %d numrows: %d", gc.size(), numRows());
+  //kdDebug() << "gc size: " << gc.size() << " numrows: " << numRows() << endl;
   gridcolors.resize(n*numRows());
   cols = n;
 
   totalwidth = (n * cellsize) + 1;
   resize(totalwidth, totalheight);
-  //debug("numRows: %d", numRows());
-  //debug("gridcolor: %d  grid: %d", gridcolors.size(), numRows()*numCols());
+  //kdDebug() << "numRows: " << numRows() << endl;
+  //kdDebug() << "gridcolor: " << gridcolors.size() << "  grid: " << numRows()*numCols() << endl;
   if(numRows() == 0)
     return;
 
@@ -219,10 +220,10 @@ void KColorGrid::setNumCols(int n)
   {
     for(int j = 0; j < on; j++)
     {
-      //debug("row %d , col %d", i, j);
+      //kdDebug() << "row " << i << " , col " << j << endl;
       if(on <= n)
       {
-        //debug("%d %d", (i*numCols())+j, (i*on)+j);
+        //kdDebug() << (i*numCols())+j << " " << (i*on)+j << endl;
         gridcolors.at((i*numCols())+j) = gc.at((i*on)+j);
       }
       else
@@ -230,7 +231,7 @@ void KColorGrid::setNumCols(int n)
     }
   }
 
-  //debug("setNumCols() - gridcolors: %d  size: %d", gridcolors.size(), numCols()*numRows());
+  //kdDebug() << "setNumCols() - gridcolors: " << gridcolors.size() << "  size: " << numCols()*numRows() << endl;
 }
 
 void KColorGrid::fill( uint color)
@@ -243,48 +244,46 @@ void KColorGrid::fill( uint color)
 
 void KColorGrid::setColor( int colNum, uint col, bool update )
 {
-  //debug("KColorGrid::setColor");
+  //kdDebug() << "KColorGrid::setColor" << endl;
   uint oldcolor = gridcolors[colNum];
   gridcolors[colNum] = col;
 
   if(!update)
     return;
 
-  //debug("KColorGrid::setColor - before adding");
+  //kdDebug() << "KColorGrid::setColor - before adding" << endl;
   if(!numcolors.contains(col))
   {
-    //debug("KColorGrid::setColor() - adding %u - %d %d %d",
-    //  col, qRed(col), qGreen(col), qBlue(col));
+    //kdDebug() << "KColorGrid::setColor() - adding " << //  col << " - " << qRed(col) << " " << qGreen(col) << " " << qBlue(col) << endl;
     numcolors.append(col);
-    //debug("KColorGrid::setColor() - adding done %d", numcolors.size()-1); 
+    //kdDebug() << "KColorGrid::setColor() - adding done " << numcolors.size()-1 << endl;
     //numcolors++;
     emit addingcolor(col);
   }
 
-  //debug("KColorGrid::setColor - before removing");
+  //kdDebug() << "KColorGrid::setColor - before removing" << endl;
   if(!gridcolors.contains(oldcolor))
   {
     int idx = numcolors.find(oldcolor);
     if(idx != -1)
     {
-      //debug("KColorGrid::setColor() - removing %u - %d %d %d",
-      //  oldcolor, qRed(oldcolor), qGreen(oldcolor), qBlue(oldcolor));
+      //kdDebug() << "KColorGrid::setColor() - removing " << //  oldcolor << " - " << qRed(oldcolor) << " " << qGreen(oldcolor) << " " << qBlue(oldcolor) << endl;
       numcolors.remove(idx);
-      //debug("KColorGrid::setColor() - removing done"); 
+      //kdDebug() << "KColorGrid::setColor() - removing done" << endl;
       emit colorschanged(numcolors.size(), numcolors.data());
     }
     //numcolors--;
   }
 
-  //debug("KColorGrid::setColor - before updateCell");
+  //kdDebug() << "KColorGrid::setColor - before updateCell" << endl;
   repaint((colNum%numCols())*cellsize,(colNum/numCols())*cellsize,  cellsize, cellsize);
   //updateCell( colNum/numCols(), colNum%numCols(), false );
-  //debug("KColorGrid::setColor - after updateCell");
+  //kdDebug() << "KColorGrid::setColor - after updateCell" << endl;
 }
 
 void KColorGrid::updateCell( int row, int col, bool  )
 {
-    //debug("updateCell - before repaint");
+    //kdDebug() << "updateCell - before repaint" << endl;
   QWMatrix matrix;
   QPainter p;
   p.begin( this );
@@ -317,3 +316,4 @@ void KColorGrid::setCellSize( int s )
   if ( isVisible() )
     repaint(viewRect(), false);
 }
+#include "kcolorgrid.moc"
