@@ -26,7 +26,7 @@
 #include <qimage.h>
 #include <qfile.h>
 #include <qfileinfo.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kfiledialog.h>
 #include "kcolorgrid.h"
 #include "utils.h"
@@ -61,6 +61,7 @@ public:
 
   bool isLocal() { return local; }
   QString url() { return _url; }
+  void setUrl( const QString & u ) { _url = u; };
 
 public slots:
   void open(const QImage*, const QString &xpm= QString::null);
