@@ -18,16 +18,19 @@
     Boston, MA 02111-1307, USA.
 */  
 
+#include <qpainter.h>
+#include <kdebug.h>
+
 #include "kiconcolors.h"
 
 KDrawColors::KDrawColors(QWidget *parent) : KColorGrid(parent, 0, 3)
 {
-  debug("KDrawColors - constructor");
+  kdDebug() << "KDrawColors - constructor" << endl;
   setCellSize(17);
   setGrid(true);
   setGridState(KColorGrid::Shaded);
   selected = 0;
-  debug("KDrawColors - constructor - done");
+  kdDebug() << "KDrawColors - constructor - done" << endl;
 }
 
 void KDrawColors::paintCell( QPainter *painter, int row, int col )
@@ -62,7 +65,7 @@ void KDrawColors::mouseReleaseEvent( QMouseEvent *e )
 
 KSysColors::KSysColors(QWidget *parent) : KDrawColors(parent)
 {
-  debug("KSysColors - constructor");
+  kdDebug() << "KSysColors - constructor" << endl;
 
   setNumRows(7);
   setNumCols(6);
@@ -71,15 +74,15 @@ KSysColors::KSysColors(QWidget *parent) : KDrawColors(parent)
 
   int numcells = 42;
 
-  debug("KSysColors - constructor - before setColor");
+  kdDebug() << "KSysColors - constructor - before setColor" << endl;
   for(int i = 0; i < numcells; i++)
     setColor(i, iconpalette[i]|OPAQUE_MASK);
-  debug("KSysColors - constructor - done");
+  kdDebug() << "KSysColors - constructor - done" << endl;
 }
 
 KCustomColors::KCustomColors(QWidget *parent) : KDrawColors(parent)
 {
-  debug("KCustomColors - constructor");
+  kdDebug() << "KCustomColors - constructor" << endl;
   setNumRows(3);
   setNumCols(6);
   fill(TRANSPARENT|OPAQUE_MASK);
@@ -87,7 +90,7 @@ KCustomColors::KCustomColors(QWidget *parent) : KDrawColors(parent)
   freecells = new bool[numRows()*numCols()];
   for(int i = 0; i < numRows()*numCols(); i++)
     freecells[i] = true;
-  debug("KCustomColors - constructor - done");
+  kdDebug() << "KCustomColors - constructor - done" << endl;
 }
 
 KCustomColors::~KCustomColors()
@@ -100,17 +103,13 @@ void KCustomColors::mouseDoubleClickEvent(QMouseEvent *e)
   int row = findRow( e->pos().y() );
   int col = findCol( e->pos().x() );
   int cell = row * numCols() + col;
-
-  QColor color;
-  KColorDialog *cdlg = new KColorDialog;
-  cdlg->setColor(colorAt(cell));
-  if(cdlg->getColor(color))
+  QColor color=colorAt(cell);
+  if(KColorDialog::getColor(color))
   {
     setColor(cell, color.rgb());
     emit newcolor(color.rgb()|OPAQUE_MASK);
     freecells[cell] = false;
   }
-  delete cdlg;
 }
 
 void KCustomColors::addColor(uint c)
@@ -123,10 +122,10 @@ void KCustomColors::addColor(uint c)
       QColor color(c);
       if(!color.isValid())
       {
-        debug("KCustomColors::addColor: Not a valid color: %u", c);
+        kdDebug() << "KCustomColors::addColor: Not a valid color: " << c << endl;
         return;
       }
-      //debug("KCustomColors::addColor: Adding color: %u - %d %d %d", c, qRed(c), qGreen(c), qBlue(c));
+      //kdDebug() << "KCustomColors::addColor: Adding color: " << c << " - " << qRed(c) << " " << qGreen(c) << " " << qBlue(c) << endl;
       setColor(f, c);
       freecells[f] = false;
     }
@@ -145,7 +144,7 @@ int KCustomColors::getFreeCell()
         freecells[0] = true;
       return i;
       break;
-    } 
+    }
   }
   freeAllCells(); // start over again - not very elegant
   return 0;
@@ -163,3 +162,4 @@ void KCustomColors::clear()
   freeAllCells();
   update();
 }
+#include "kiconcolors.moc"
