@@ -22,15 +22,14 @@
 #define __KICONEDIT_H__
 
 #include <qdir.h>
-#include <kprinter.h>
 #include <qwidget.h>
 #include <qpixmap.h>
 #include <qfileinfo.h> 
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qkeycode.h>
 #include <qtimer.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kmainwindow.h>
 #include <kiconloader.h>
 #include <kmenubar.h>
@@ -39,7 +38,6 @@
 #include <kaccel.h>
 #include <kurl.h>
 
-#include "kicontools.h"
 #include "knew.h"
 #include "kicon.h"
 #include "kiconconfig.h"
@@ -47,7 +45,8 @@
 #include "kresize.h"
 #include "properties.h"
 
-#include <netwm.h>
+class KIconEdit;
+typedef QPtrList<KIconEdit> WindowList;
 
 #define ID_FILE_NEWWIN  500
 #define ID_FILE_NEWFILE 501
@@ -108,6 +107,9 @@
 
 class QWhatsThis;
 class QToolButton;
+class QLabel;
+class KSysColors;
+class KCustomColors;
 
 /**
 * KIconEdit
@@ -124,37 +126,53 @@ public:
   ~KIconEdit();
 
   virtual QSize sizeHint() const;
+  static WindowList windowList;
 
 signals:
 
 public slots:
   virtual void saveProperties(KConfig*);
   virtual void readProperties(KConfig*);
-  void unsaved(bool flag);
+  void updateProperties();
 
 protected slots:
   void addColors(uint, uint*);
   void addColor(uint);
-  void slotNewWin();
   void slotNewWin(const QString & url = 0);
   void slotNew();
   void slotOpen();
   void slotClose();
-  void slotQuit();
   void slotSave();
   void slotSaveAs();
   void slotPrint();
   void slotView(int);
+  void slotZoomIn();
+  void slotZoomOut();
   void slotCopy();
   void slotCut();
   void slotPaste();
   void slotClear();
-  void slotImage(int id);
   void slotSaved();
   void slotSelectAll();
-  void slotOpenRecent(int id);
+  //void slotOpenRecent(int id);
+  void slotOpenRecent(const KURL&);
+  void slotToolPointer();
+  void slotToolFreehand();
+  void slotToolRectangle();
+  void slotToolFilledRectangle();
+  void slotToolCircle();
+  void slotToolFilledCircle();
+  void slotToolEllipse();
+  void slotToolFilledEllipse();
+  void slotToolSpray();
+  void slotToolFlood();
+  void slotToolLine();
+  void slotToolEraser();
+  void slotToolSelectRect();
+  void slotToolSelectCircle();
+  void slotConfigureSettings();
+  void slotConfigureKeys();
   void slotConfigure(int);
-  void slotTools(int);
 
   void slotUpdateStatusColors(uint);
   void slotUpdateStatusColors(uint, uint*);
@@ -167,14 +185,15 @@ protected slots:
   void slotUpdatePaste(bool);
   void slotUpdateCopy(bool);
   void slotOpenBlank(const QSize);
-  void addRecent(const QString &);  
-  
+  void addRecent(const QString &);
+
   virtual void dragEnterEvent(QDragEnterEvent* event);
   virtual void dropEvent(QDropEvent *e);
 
 protected:
   void init();
   bool setupMenuBar();
+  void setupTools();
   bool setupToolBar();
   bool setupDrawToolBar();
   bool setupPaletteToolBar();
@@ -183,30 +202,24 @@ protected:
   virtual bool queryClose();
   virtual void resizeEvent(QResizeEvent*);
   void writeConfig();
-  void toggleTool(int id);
 
-  void updateMenuAccel();
-
-  KIconTemplateContainer *icontemplates;
+  void updateAccels();
 
   QLabel *syslabel, *customlabel;
-  Preview *preview;
+  QLabel *preview;
   KSysColors *syscolors;
   KCustomColors *customcolors;;
 
   KMenuBar *menubar;
   KToolBar *toolbar, *drawtoolbar, *palettetoolbar;
   KStatusBar *statusbar;
-  QPopupMenu *edit, *file, *view, *image, *help;
-  QPopupMenu *tools, *options, *zoom, *recent, *select;
+  QPopupMenu *edit, *file, *view, *help;
+  QPopupMenu *tools, *options, *zoom, /*recent,*/ *select;
   KIconEditGrid *grid;
   QTimer *msgtimer;
   KGridView *gridview;
   KIconEditIcon *icon;
-  KIconEditProperties *kiprops;
-  QWhatsThis *what;
   QImage img;
-  KPrinter *printer;
 };
 
 #endif //__KICONEDIT_H__
