@@ -16,25 +16,48 @@
     along with this library; see the file COPYING.LIB.  If not, write to
     the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
-*/  
+*/
 
 #include <qdragobject.h>
 #include <qstrlist.h>
 #include <qprintdialog.h>
 #include <qpaintdevicemetrics.h>
+#include <qpainter.h>
 
+#include <kaction.h>
+#include <kkeydialog.h>
 #include <klocale.h>
 #include <ktoolbarbutton.h>
 #include <kmessagebox.h>
 #include <kdebug.h>
+#include <kprinter.h>
 
 #include "kiconedit.h"
+#include "kiconcolors.h"
 
 #ifndef PICS_INCLUDED
 #define PICS_INCLUDED
 #include "pics/logo.xpm"
 #endif
 
+void KIconEdit::updateProperties()
+{
+        Properties *pprops = KIconEditProperties::self()->properties();
+        gridview->setShowRulers(pprops->showrulers);
+        if(pprops->backgroundmode == QWidget::FixedPixmap)
+        {
+            QPixmap pix(pprops->backgroundpixmap);
+            if(pix.isNull())
+            {
+                QPixmap pmlogo((const char**)logo);
+                pix = pmlogo;
+            }
+            gridview->viewPortWidget()->viewport()->setBackgroundPixmap(pix);
+        }
+        else
+            gridview->viewPortWidget()->viewport()->setBackgroundColor(pprops->backgroundcolor);
+}
+
 void KIconEdit::addColors(uint n, uint *c)
 {
     //kdDebug() << "KIconTools::addColors()" << endl;
@@ -52,26 +75,22 @@ void KIconEdit::addColor(uint color)
         customcolors->addColor(color);
 }
 
-void KIconEdit::slotNewWin()
-{
-    slotNewWin((const char*)0);
-}
 
 void KIconEdit::slotNewWin(const QString & url)
 {
-    kdDebug() << "KIconEdit::openNewWin() - " << url << endl;
-  
+    //kdDebug() << "KIconEdit::openNewWin() - " << url << endl;
+
     KIconEdit *w = new KIconEdit(url, "kiconedit");
-    CHECK_PTR(w);
+    Q_CHECK_PTR(w);
 }
 
 
 void KIconEdit::slotNew()
 {
     bool cancel = false;
-    if (grid->isModified()) 
+    if (grid->isModified())
     {
-        int r = KMessageBox::warningYesNoCancel(this, 
+        int r = KMessageBox::warningYesNoCancel(this,
         i18n("The current file has been modified.\nDo you want to save it?"));
 
         switch(r)
@@ -101,7 +120,7 @@ void KIconEdit::slotNew()
             {
                 grid->editClear();
                 const QSize s = newicon.templateSize();
-                kdDebug() << "Size: " << s.width() << " x " << s.height() << endl;
+                //kdDebug() << "Size: " << s.width() << " x " << s.height() << endl;
                 grid->setSize(s);
                 grid->setModified(false);
             }
@@ -110,6 +129,8 @@ void KIconEdit::slotNew()
                 QString str = newicon.templatePath();
                 icon->open(&grid->image(), str);
             }
+            icon->setUrl("");
+            setCaption("");
         }
     }
 }
@@ -118,12 +139,12 @@ void KIconEdit::slotNew()
 void KIconEdit::slotOpen()
 {
     bool cancel = false;
-  
-    if( grid->isModified() ) 
+
+    if( grid->isModified() )
     {
-        int r = KMessageBox::warningYesNoCancel(this, 
+        int r = KMessageBox::warningYesNoCancel(this,
       i18n("The current file has been modified.\nDo you want to save it?"));
-        
+
         switch( r )
         {
             case 0:
@@ -141,9 +162,12 @@ void KIconEdit::slotOpen()
                 break;
         }
     }
-    
+
     if( !cancel )
+    {
         icon->promptForFile( &grid->image() );
+        grid->setModified(false);
+    }
 }
 
 /*
@@ -151,54 +175,60 @@ void KIconEdit::slotOpen()
 */
 void KIconEdit::slotClose()
 {
+    //kdDebug() << "KIconEdit: Closing " <<  endl;
     close();
 }
 
 /*
     close all member windows
-*/
+
 void KIconEdit::slotQuit()
 {
-    kdDebug() << "KIconEdit: Closing " <<  endl;
-    
-    KIconEdit *ki = 0L;
-    while((ki = (KIconEdit*)memberList->getFirst()) != 0)
-    {
-        CHECK_PTR(ki);
-        memberList->getFirst()->close();
-    }
-}
+    kdDebug() << "KIconEdit: Quitting " <<  endl;
 
+    KIconEdit *ki = 0L;
+    for (ki = windowList.first(); ki; ki = windowList.next())
+    {
+        if (ki != this)
+        {
+            ki->slotClose();
+        }
+    }
+
+    slotClose();
+}
+*/
 
 void KIconEdit::slotSave()
 {
-    kdDebug() << "KIconEdit: slotSave() " << endl;
+    //kdDebug() << "KIconEdit: slotSave() " << endl;
     icon->save(&grid->image());
 }
 
 
 void KIconEdit::slotSaveAs()
 {
-    kdDebug() << "KIconEdit: slotSaveAs() " << endl;
+    //kdDebug() << "KIconEdit: slotSaveAs() " << endl;
     icon->saveAs(&grid->image());
 }
 
 
 void KIconEdit::slotPrint()
 {
+    KPrinter printer;
     file->setItemEnabled(ID_FILE_PRINT, false);
     toolbar->setItemEnabled(ID_FILE_PRINT, false);
 
-    if ( printer->setup(this) )
+    if ( printer.setup(this) )
     {
         int margin = 10, yPos = 0;
-        printer->setCreator("KDE Icon Editor");
-    
+        printer.setCreator("KDE Icon Editor");
+
         QPainter p;
-        p.begin( printer );
+        p.begin( &printer );
         QFontMetrics fm = p.fontMetrics();
         // need width/height
-        QPaintDeviceMetrics metrics( printer ); 
+        QPaintDeviceMetrics metrics( &printer );
 
         p.drawText( margin, margin + yPos, metrics.width(), fm.lineSpacing(),
                         ExpandTabs | DontClip, icon->url() );
@@ -206,11 +236,26 @@ void KIconEdit::slotPrint()
         p.drawPixmap( margin, margin + yPos, grid->pixmap() );
         p.end();
   }
-  
+
   file->setItemEnabled(ID_FILE_PRINT, true);
   toolbar->setItemEnabled(ID_FILE_PRINT, true);
 }
 
+void KIconEdit::slotZoomIn()
+{
+    grid->zoom(In);
+    toolbar->setItemEnabled(ID_VIEW_ZOOM_OUT, true);
+    view->setItemEnabled(ID_VIEW_ZOOM_OUT, true);
+}
+
+void KIconEdit::slotZoomOut()
+{
+    if(!grid->zoom(Out))
+    {
+        toolbar->setItemEnabled(ID_VIEW_ZOOM_OUT, false);
+        view->setItemEnabled(ID_VIEW_ZOOM_OUT, false);
+    }
+}
 
 void KIconEdit::slotView( int id )
 {
@@ -240,20 +285,6 @@ void KIconEdit::slotView( int id )
             //slotUpdateStatusScaling(10, true);
             break;
 
-        case ID_VIEW_ZOOM_OUT:
-            if(!grid->zoom(Out))
-            {
-                toolbar->setItemEnabled(ID_VIEW_ZOOM_OUT, false);
-                view->setItemEnabled(ID_VIEW_ZOOM_OUT, false);
-            }
-            break;
-
-        case ID_VIEW_ZOOM_IN:
-            grid->zoom(In);
-            toolbar->setItemEnabled(ID_VIEW_ZOOM_OUT, true);
-            view->setItemEnabled(ID_VIEW_ZOOM_OUT, true);
-            break;
-
         default:
             break;
     }
@@ -271,7 +302,7 @@ void KIconEdit::slotCut()
 
 void KIconEdit::slotPaste()
 {
-    toggleTool(ID_DRAW_FIND);
+    static_cast<KRadioAction*>(actionCollection()->action("pointer"))->setChecked(true);
     grid->setTool(KIconEditGrid::Find);
     grid->editPaste();
 }
@@ -287,68 +318,80 @@ void KIconEdit::slotSelectAll()
     grid->editSelectAll();
 }
 
-void KIconEdit::slotOpenRecent(int id)
+void KIconEdit::slotOpenRecent(const KURL& iconFile)
 {
-    kdDebug() << "Opening recent file: menu id is: " << id << endl;
+    bool cancel = false;
 
-    int indx = recent->indexOf(id);
-    kdDebug() << "Opening recent file: index of menu id is: " << indx << endl;
-
-    QString fname = recent->text(id);
-    kdDebug() << "Opening recent file: string at menu id is: " << fname << endl;
-    
-    if(!fname.isNull())
+    if( grid->isModified() )
     {
-        icon->open(&grid->image(), fname);    
+        int r = KMessageBox::warningYesNoCancel(this,
+      i18n("The current file has been modified.\nDo you want to save it?"));
+
+        switch( r )
+        {
+            case 0:
+                icon->save( &grid->image() );
+                break;
+
+            case 1:
+                break;
+
+            case 2:
+                cancel = true;
+                break;
+
+            default:
+                break;
+        }
     }
+
+    if( !cancel )
+        icon->open(&grid->image(), iconFile.url());
 }
 
+void KIconEdit::slotConfigureSettings()
+{
+    KIconConfig* c = new KIconConfig(this);
+    c->show();
+}
+
+void KIconEdit::slotConfigureKeys()
+{
+    KKeyDialog::configure(actionCollection());
+
+    KIconEdit *ki = 0L;
+    for (ki = windowList.first(); ki; ki = windowList.next())
+    {
+        if (ki != this)
+        {
+            ki->updateAccels();
+        }
+    }
+
+//    KKeyDialog::configure(KIconEditProperties::self()->properties()->keys);
+}
 
 void KIconEdit::slotConfigure(int id)
 {
     switch(id)
     {
-        case ID_OPTIONS_CONFIGURE:
-        {
-            KIconConfig c(this);
-            if(c.exec())
-            {
-                Properties *pprops = props(this);
-                updateMenuAccel();
-                gridview->setShowRulers(pprops->showrulers);
-                if(pprops->backgroundmode == QWidget::FixedPixmap)
-                {
-                    QPixmap pix(pprops->backgroundpixmap);
-                    if(pix.isNull())
-                    {
-                        QPixmap pmlogo((const char**)logo);
-                        pix = pmlogo;
-                    }
-                    gridview->viewPortWidget()->viewport()->setBackgroundPixmap(pix);
-                }
-                else
-                    gridview->viewPortWidget()->viewport()->setBackgroundColor(pprops->backgroundcolor);
-            }
-            break;
-        }
-        
         case ID_OPTIONS_TOGGLE_GRID:
             if(options->isItemChecked(ID_OPTIONS_TOGGLE_GRID))
             {
                 options->setItemChecked(ID_OPTIONS_TOGGLE_GRID, false);
                 ((KToolBarButton*)toolbar->getButton(ID_OPTIONS_TOGGLE_GRID))->on(false);
-                props(this)->showgrid = false;
+                KIconEditProperties::self()->properties()->showgrid = false;
                 grid->setGrid(false);
             }
             else
             {
                 options->setItemChecked(ID_OPTIONS_TOGGLE_GRID, true);
                 ((KToolBarButton*)toolbar->getButton(ID_OPTIONS_TOGGLE_GRID))->on(true);
-                props(this)->showgrid = true;
+                KIconEditProperties::self()->properties()->showgrid = true;
                 grid->setGrid(true);
             }
             break;
-            
+
         case ID_OPTIONS_TOGGLE_TOOL1:
             if(options->isItemChecked(ID_OPTIONS_TOGGLE_TOOL1))
             {
@@ -361,7 +404,7 @@ void KIconEdit::slotConfigure(int id)
                 toolBar()->show();
             }
             break;
-    
+
         case ID_OPTIONS_TOGGLE_TOOL2:
             if(options->isItemChecked(ID_OPTIONS_TOGGLE_TOOL2))
             {
@@ -374,7 +417,7 @@ void KIconEdit::slotConfigure(int id)
                 toolBar("drawToolBar")->show();
             }
             break;
-            
+
         case ID_OPTIONS_TOGGLE_STATS:
             if(options->isItemChecked(ID_OPTIONS_TOGGLE_STATS))
             {
@@ -387,118 +430,85 @@ void KIconEdit::slotConfigure(int id)
                 statusBar()->show();
             }
             break;
-            
+
         case ID_OPTIONS_SAVE:
             writeConfig();
             break;
-        
+
         default:
             break;
     }
 }
 
-
-void KIconEdit::slotTools( int id )
+void KIconEdit::slotToolPointer()
 {
-    switch(id)
-    {
-        case ID_SELECT_RECT:
-            grid->setTool(KIconEditGrid::SelectRect);
-            break;
-            
-        case ID_SELECT_CIRCLE:
-            grid->setTool(KIconEditGrid::SelectCircle);
-            break;
-        
-        case ID_DRAW_FREEHAND:
-            toggleTool(id);
-            grid->setTool(KIconEditGrid::Freehand);
-            break;
-    
-        case ID_DRAW_ELLIPSE:
-            toggleTool(id);
-            grid->setTool(KIconEditGrid::Ellipse);
-            break;
-    
-        case ID_DRAW_ELLIPSE_FILL:
-            toggleTool(id);
-            grid->setTool(KIconEditGrid::FilledEllipse);
-            break;
-    
-        case ID_DRAW_CIRCLE:
-            toggleTool(id);
-            grid->setTool(KIconEditGrid::Circle);
-            break;
-        
-        case ID_DRAW_CIRCLE_FILL:
-            toggleTool(id);
-            grid->setTool(KIconEditGrid::FilledCircle);
-            break;
-        
-        case ID_DRAW_RECT:
-            toggleTool(id);
-            grid->setTool(KIconEditGrid::Rect);
-            break;
-        
-        case ID_DRAW_RECT_FILL:
-            toggleTool(id);
-            grid->setTool(KIconEditGrid::FilledRect);
-            break;
-        
-        case ID_DRAW_ERASE:
-            toggleTool(id);
-            grid->setTool(KIconEditGrid::Eraser);
-            break;
-        
-        case ID_DRAW_LINE:
-            toggleTool(id);
-            grid->setTool(KIconEditGrid::Line);
-            break;
-    
-        case ID_DRAW_FIND:
-            toggleTool(id);
-            grid->setTool(KIconEditGrid::Find);
-            break;
-    
-        case ID_DRAW_FILL:
-            toggleTool(id);
-            grid->setTool(KIconEditGrid::FloodFill);
-            break;
-    
-        case ID_DRAW_SPRAY:
-            toggleTool(id);
-            grid->setTool(KIconEditGrid::Spray);
-            break;
-
-        default:
-            if(id >= 500 && id <= 600)
-                KMessageBox::sorry(this, i18n("Sorry - not implemented."));
-            break;
-    }
+    grid->setTool(KIconEditGrid::Find);
 }
 
-
-void KIconEdit::slotImage( int id )
+void KIconEdit::slotToolFreehand()
 {
-    switch(id)
-    {
-        case ID_IMAGE_RESIZE:
-            grid->editResize();
-            break;
-
-        case ID_IMAGE_GRAYSCALE:
-            grid->grayScale();
-            break;
-
-        case ID_IMAGE_MAPTOKDE:
-            grid->mapToKDEPalette();
-            break;
-
-        default:
-            break;
-    }
+    grid->setTool(KIconEditGrid::Freehand);
 }
 
+void KIconEdit::slotToolRectangle()
+{
+    grid->setTool(KIconEditGrid::Rect);
+}
+
+void KIconEdit::slotToolFilledRectangle()
+{
+    grid->setTool(KIconEditGrid::FilledRect);
+}
+
+void KIconEdit::slotToolCircle()
+{
+    grid->setTool(KIconEditGrid::Circle);
+}
+
+void KIconEdit::slotToolFilledCircle()
+{
+    grid->setTool(KIconEditGrid::FilledCircle);
+}
+
+void KIconEdit::slotToolEllipse()
+{
+    grid->setTool(KIconEditGrid::Ellipse);
+}
+
+void KIconEdit::slotToolFilledEllipse()
+{
+    grid->setTool(KIconEditGrid::FilledEllipse);
+}
+
+void KIconEdit::slotToolSpray()
+{
+    grid->setTool(KIconEditGrid::Spray);
+}
+
+void KIconEdit::slotToolFlood()
+{
+    grid->setTool(KIconEditGrid::FloodFill);
+}
+
+void KIconEdit::slotToolLine()
+{
+    grid->setTool(KIconEditGrid::Line);
+}
+
+void KIconEdit::slotToolEraser()
+{
+    grid->setTool(KIconEditGrid::Eraser);
+}
+
+void KIconEdit::slotToolSelectRect()
+{
+    grid->setTool(KIconEditGrid::SelectRect);
+}
+
+void KIconEdit::slotToolSelectCircle()
+{
+    grid->setTool(KIconEditGrid::SelectCircle);
+}
 
 void KIconEdit::slotSaved()
 {
@@ -521,9 +531,9 @@ void KIconEdit::slotUpdateStatusSize(int x, int y)
 
 void KIconEdit::slotUpdateStatusScaling(int s, bool show)
 {
-    props(this)->gridscaling = s;
+    KIconEditProperties::self()->properties()->gridscaling = s;
     QString str;
-    
+
     if(show)
     {
         toolbar->setItemEnabled(ID_VIEW_ZOOM_IN, true);
@@ -576,7 +586,7 @@ void KIconEdit::slotUpdateStatusName(const QString & name)
     }
 
     // add to list of recent files - this now works -jwc-
-    kdDebug() << "KIconEdit::slotUpdateStatusName() name is: " << name << endl;
+    //kdDebug() << "KIconEdit::slotUpdateStatusName() name is: " << name << endl;
     addRecent(name);
 
     // -jwc- do not include app name or dash - kapp takes care of that
@@ -620,29 +630,29 @@ void KIconEdit::dragEnterEvent(QDragEnterEvent* e)
 */
 void KIconEdit::dropEvent( QDropEvent *e )
 {
-    kdDebug() << "Got QDropEvent!" << endl;
+    //kdDebug() << "Got QDropEvent!" << endl;
 
     QStrList fileList;
     bool validUrls = false;
     bool loadedinthis = false;
-    
+
     if(QUriDrag::decode(e, fileList))
     {
         QStrListIterator it(fileList);
         for(; it.current(); ++it)
         {
-            kdDebug() << "In dropEvent for "  <<  it.current() << endl;
+            //kdDebug() << "In dropEvent for "  <<  it.current() << endl;
             KURL url(it.current());
             if(!url.isMalformed())
             {
                 validUrls = true;
- 
-                if (!grid->isModified() && !loadedinthis) 
+
+                if (!grid->isModified() && !loadedinthis)
                 {
                     icon->open(&grid->image(), it.current());
                     loadedinthis = true;
                 }
-                else 
+                else
                 {
                     slotNewWin(it.current());
                 }
@@ -650,5 +660,5 @@ void KIconEdit::dropEvent( QDropEvent *e )
         }
     }
 }
-    
+
 
