@@ -19,6 +19,7 @@
 */  
 
 #include <qlayout.h>
+#include <qpainter.h>
 
 #include <kconfig.h>
 #include <klocale.h>
@@ -28,10 +29,7 @@
 
 #include "knew.h"
 
-QList<KIconTemplate> *KIconTemplateContainer::templatelist = 0;
-int KIconTemplateContainer::instances = 0;
-
-void createStandardTemplates(QList<KIconTemplate> *list)
+void createStandardTemplates(KIconTemplateContainer *list)
 {
     KIconLoader *kil = KGlobal::iconLoader();
 
@@ -71,18 +69,9 @@ void createStandardTemplates(QList<KIconTemplate> *list)
     list->append(it);
 }
 
-KIconTemplateContainer::KIconTemplateContainer() : QObject()
+KIconTemplateContainer::KIconTemplateContainer() : QPtrList<KIconTemplate>()
 {
-  QString path;
-  instances++;
-  kdDebug() << "KIconTemplateContainer: instances " << instances << endl;
-  if(templatelist)
-    return;
-
-  kdDebug() << "KIconTemplateContainer: Creating templates" << endl;
-
-  templatelist = new QList<KIconTemplate>;
-  templatelist->setAutoDelete(true);
+  setAutoDelete(true);
 
   QStrList names;
   KConfig *k = kapp->config();
@@ -94,32 +83,18 @@ KIconTemplateContainer::KIconTemplateContainer() : QObject()
     it->path = k->readEntry(names.at(i));
     it->title = names.at(i);
     //kdDebug() << "Template: " << names.at(i) << "\n" << path.data() << endl;
-    templatelist->append(it);
+    append(it);
   }
 
-  if(templatelist->count() == 0)
+  if(count() == 0)
   {
-    createStandardTemplates(templatelist);
+    createStandardTemplates(this);
   }
 }
 
 KIconTemplateContainer::~KIconTemplateContainer()
 {
-  instances--;
-  kdDebug() << "KIconTemplateContainer: instances " << instances << endl;
-  if(instances == 0)
-  {
-    kdDebug() << "KIconTemplateContainer: Deleting templates" << endl;
-    templatelist->clear();
-    delete templatelist;
-    kdDebug() << "KIconTemplateContainer: Deleted templates" << endl;
-  }
-}
-
-QList<KIconTemplate> *KIconTemplateContainer::getTemplates()
-{
-  KIconTemplateContainer t;
-  return t.templatelist;
+  clear();
 }
 
 KIconListBoxItem::KIconListBoxItem( KIconTemplate *t )
@@ -131,21 +106,21 @@ KIconListBoxItem::KIconListBoxItem( KIconTemplate *t )
   setText( t->title );
 }
 
-void KIconListBoxItem::paint( QPainter *p )    
+void KIconListBoxItem::paint( QPainter *p )
 {
-  p->drawPixmap( 3, 0, pm );      
-  QFontMetrics fm = p->fontMetrics();      
-  int yPos;                       // vertical text position      
-  if ( pm.height() < fm.height() )          
-    yPos = fm.ascent() + fm.leading()/2;      
-  else            
-    yPos = pm.height()/2 - fm.height()/2 + fm.ascent();      
-  p->drawText( pm.width() + 5, yPos, text() );    
+  p->drawPixmap( 3, 0, pm );
+  QFontMetrics fm = p->fontMetrics();
+  int yPos;                       // vertical text position
+  if ( pm.height() < fm.height() )
+    yPos = fm.ascent() + fm.leading()/2;
+  else
+    yPos = pm.height()/2 - fm.height()/2 + fm.ascent();
+  p->drawText( pm.width() + 5, yPos, text() );
 }
 
-int KIconListBoxItem::height(const QListBox *lb ) const    
+int KIconListBoxItem::height(const QListBox *lb ) const
 {
-  return QMAX( pm.height(), lb->fontMetrics().lineSpacing() + 1 );    
+  return QMAX( pm.height(), lb->fontMetrics().lineSpacing() + 1 );
 }
     
 int KIconListBoxItem::width(const QListBox *lb ) const
@@ -155,7 +130,7 @@ int KIconListBoxItem::width(const QListBox *lb ) const
 
 NewSelect::NewSelect(QWidget *parent) : QWidget( parent )
 {
-  wiz = (QWizard*) parent;
+  wiz = (KWizard*) parent;
   grp = new QButtonGroup( this );
   connect( grp, SIGNAL( clicked( int ) ), SLOT( buttonClicked( int ) ) );
   grp->setExclusive( true );
@@ -184,7 +159,7 @@ NewSelect::~NewSelect()
 
 void NewSelect::buttonClicked(int id)
 {
-  kdDebug() << "Button: " << id << endl;
+  //kdDebug() << "Button: " << id << endl;
 
   emit iconopenstyle(id);
 }
@@ -192,7 +167,7 @@ void NewSelect::buttonClicked(int id)
 NewFromTemplate::NewFromTemplate( QWidget* parent )
   : QWidget( parent )
 {
-  wiz = (QWizard*) parent;
+  wiz = (KWizard*) parent;
   
   QVBoxLayout* ml = new QVBoxLayout(this, 10);
   
@@ -206,10 +181,12 @@ NewFromTemplate::NewFromTemplate( QWidget* parent )
   connect( templates, SIGNAL( highlighted( int ) ), SLOT( checkSelection( int ) ) );
   l->addWidget( templates );
   
-  QList<KIconTemplate> *tlist = KIconTemplateContainer::getTemplates();
+  KIconTemplateContainer *tlist = new KIconTemplateContainer();
 
   for( int i = 0; i < (int) tlist->count(); i++ )
     templates->insertItem( new KIconListBoxItem( tlist->at( i ) ) );
+
+  delete tlist;
 }
 
 NewFromTemplate::~NewFromTemplate()
@@ -218,6 +195,7 @@ NewFromTemplate::~NewFromTemplate()
 
 void NewFromTemplate::checkSelection( int )
 {
+  //kdDebug() << "checkSelection(int) " << templates->currentItem()  << endl;
   if( templates->currentItem() != -1 )
     wiz->finishButton()->setEnabled( true );
   else
@@ -225,9 +203,10 @@ void NewFromTemplate::checkSelection( int )
 }
 
 KNewIcon::KNewIcon( QWidget* parent )
-  : QWizard( parent, 0, true )
+  : KWizard( parent, 0, true )
 {
-  setCaption( i18n( "Create new icon" ) );
+  //kdDebug() << "KNewIcon" << endl;
+  setCaption( i18n( "Create New Icon" ) );
   resize( 400, 250 );
   
   openstyle = 0;
@@ -242,13 +221,15 @@ KNewIcon::KNewIcon( QWidget* parent )
   scratch = new KResizeWidget( this, 0, QSize( 32, 32 ) );
   // this doesn't accept default valid size, besides spin buttons won't allow 
   // an invalid size to be set by the user - forces user to change valid default 
-  // size to create the new icon object - 
+  // size to create the new icon object -
   connect( scratch, SIGNAL( validSize( bool ) ), SLOT( checkPage( bool ) ) );
-  
+  connect(this, SIGNAL(selected(const QString &)), this, SLOT(checkPage(const QString &)));
   templ = new NewFromTemplate(this);
+  templ->hide();
 
   addPage(select, i18n("Select icontype"));
   addPage(scratch, i18n("Create from scratch"));
+  act = scratch;
   //addPage(templ, i18n("Create from template"));
 }
 
@@ -280,47 +261,38 @@ void KNewIcon::cancelClicked()
 void KNewIcon::iconOpenStyle(int style)
 {
   openstyle = style;
+
   if( act )
     removePage( act );
-  if(style == 0)
+
+  if(openstyle == Blank)
   {
     act = scratch;
-    setNextEnabled( select, true );
+    setNextEnabled( act, true );
     addPage( scratch, i18n( "Create from scratch" ) );
-    showPage( select );
   }
-  else if( style == 1 )
+  else if( openstyle == Template )
   {
     act = templ;
-    setNextEnabled( select, true );
+    setNextEnabled( act, true );
     addPage( templ, i18n( "Create from template" ) );
-    showPage( select );
   }
 }
 
 void KNewIcon::checkPage(int p)
 {
-
-if(openstyle == Blank)
-    finishButton()->setEnabled(true);
-else if(p == 0)
-    finishButton()->setEnabled(false);
-else
-    templ->checkSelection(0);
-
-/*
-  if(p == 0)
-    finishButton()->setEnabled(false);
-  else if(openstyle == Blank)
-    scratch->checkValue(0);
-  else
-    templ->checkSelection(0);
-*/
+    //kdDebug() << "checkPage(int) " << openstyle << " " << p << endl;
+    if(openstyle == Blank)
+        finishButton()->setEnabled(true);
+    else if(p == 0)
+        finishButton()->setEnabled(false);
+    else
+        templ->checkSelection(0);
 }
 
-void KNewIcon::checkPage(bool /* ok */)
+void KNewIcon::checkPage(const QString &)
 {
-  if(/* ok && */ openstyle == Blank)
+  if(currentPage() == select || openstyle == Blank)
     finishButton()->setEnabled(true);
   else
     finishButton()->setEnabled(false);
