@@ -16,7 +16,7 @@
     along with this library; see the file COPYING.LIB.  If not, write to
     the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
-*/  
+*/
 
 #include <qhbox.h>
 #include <qlabel.h>
@@ -24,6 +24,7 @@
 #include <qkeycode.h>
 #include <qgroupbox.h>
 #include <qpushbutton.h>
+#include <kbuttonbox.h>
 
 #include <klocale.h>
 #include <knuminput.h>
@@ -37,13 +38,13 @@
 KResizeWidget::KResizeWidget( QWidget* parent, const char* name, const QSize& size )
  : QWidget( parent, name )
 {
-  setBackgroundColor( red );
+  //setBackgroundColor( red );
 
   QHBoxLayout* genLayout = new QHBoxLayout( this );
-  
+
   QGroupBox* group = new QGroupBox( i18n( "Size:" ), this );
   genLayout->addWidget( group );
-  
+
   QHBoxLayout* layout = new QHBoxLayout( group, 10 );
 
   //x_line = new KIntNumInput( QString::null, 1, 200, 1, 1, QString::null, 10, false, group );
@@ -87,28 +88,27 @@ void KResizeWidget::checkValue( int )
 KResizeDialog::KResizeDialog( QWidget* parent, const char* name, const QSize size )
  : QDialog( parent, name, true )
 {
-  setCaption(i18n("Select size:"));
+  setCaption(i18n("Select Size:"));
   setFocusPolicy( QWidget::NoFocus );
-  
+
   // TODO : Do we need this ?
   QVBoxLayout* ml = new QVBoxLayout( this, 10 );
- 
+
   rw = new KResizeWidget( this, "resize widget", size );
   rw->setMinimumSize( 100, 100 );
   ml->addWidget( rw, 1 );
   connect( rw, SIGNAL( validSize( bool ) ), this, SLOT( validSize( bool ) ) );
 
-  QHBox* buttons = new QHBox( this );
-  ml->addWidget( buttons );
-    
-  ok = new QPushButton( i18n ( "&OK" ), buttons );
-  ok->setEnabled( false );
+  KButtonBox *bb = new KButtonBox( this );
+  bb->addStretch();
+  ok = bb->addButton( i18n("&OK") );
   ok->setDefault( true );
+  ok->setEnabled( false );
+  cancel = bb->addButton( i18n( "&Cancel" ) );
+  bb->layout();
+  ml->addWidget( bb);
   connect( ok, SIGNAL( clicked() ), SLOT( accept() ) );
-    
-  cancel = new QPushButton( i18n( "&Cancel" ), buttons );
   connect( cancel, SIGNAL( clicked() ), SLOT( reject() ) );
-
   checkValue( 0 );
 }
 
@@ -118,7 +118,7 @@ KResizeDialog::~KResizeDialog()
 
 bool KResizeDialog::eventFilter(QObject *obj, QEvent *e)
 {
-  if ( e->type() == QEvent::KeyPress && obj == this && !testWFlags(WType_Modal))
+  if ( e->type() == QEvent::KeyPress && obj == this && !testWFlags(Qt::WType_Dialog | Qt::WShowModal))
   {
     QKeyEvent *k = (QKeyEvent*)e;
     if(k->key() == Key_Escape || k->key() == Key_Return || k->key() == Key_Enter)
@@ -143,3 +143,4 @@ void KResizeDialog::checkValue( int )
 {
   rw->checkValue( 0 );
 }
+#include "kresize.moc"
