@@ -27,13 +27,11 @@
 #include <kimageio.h>
 #include <kseparator.h>
 #include <klocale.h>
-#include <kstddirs.h>
 #include <kmessagebox.h>
 #include <kdebug.h>
 #include <kio/jobclasses.h>
 #include <kio/file.h>
 #include <kio/job.h>
-#include <kio/jobclasses.h>
 #include <kio/netaccess.h>
 
 #include <qdir.h>
@@ -46,22 +44,13 @@
 
 #include "resource.h"
 #include "img_saver.h"
+#include "previewer.h"
 
 
-#define OP_FILE_ASK_FORMAT "AskForSaveFormat"
-#define OP_FORMAT_HICOLOR  "HiColorSaveFormat"
-#define OP_FORMAT_COLOR    "ColorSaveFormat"
-#define OP_FORMAT_GRAY     "GraySaveFormat"
-#define OP_FORMAT_BW       "BWSaveFormat"
-#define OP_PREVIEW_GROUP   "ScanPreview"
-#define OP_PREVIEW_FILE     "PreviewFile"
-#define OP_PREVIEW_FORMAT   "PreviewFormat"
-#define OP_FILE_GROUP      "Files"
-
-FormatDialog::FormatDialog( QWidget *parent, const char *name )
-   :KDialogBase( parent, "FormDialog", true,
+FormatDialog::FormatDialog( QWidget *parent, const QString& imgFormat, const char *name )
+   :KDialogBase( parent, name, true,
                  /* Tabbed,*/ i18n( "Kooka save assistant" ),
-		 Ok|Cancel, Ok, parent,  name )
+		 Ok|Cancel, Ok )
 
 {
    buildHelp();
@@ -69,15 +58,15 @@ FormatDialog::FormatDialog( QWidget *parent, const char *name )
    // QFrame *page = addPage( QString( "Save the image") );
    QFrame *page = new QFrame( this );
    page->setFrameStyle( QFrame::Box | QFrame::Sunken );
-   CHECK_PTR( page );
+   Q_CHECK_PTR( page );
    setMainWidget( page );
    
    QVBoxLayout *bigdad = new QVBoxLayout( page, marginHint(), spacingHint());
-   CHECK_PTR(bigdad);
+   Q_CHECK_PTR(bigdad);
 
    // some nice words
    QLabel *l0 = new QLabel( page );
-   CHECK_PTR(l0);
+   Q_CHECK_PTR(l0);
    l0->setText( i18n( "<B>Save Assistant</B><P>Select an image format to save the scanned image." ));
    bigdad->addWidget( l0 );
 
@@ -87,19 +76,19 @@ FormatDialog::FormatDialog( QWidget *parent, const char *name )
    // Layout-Boxes
    // QHBoxLayout *hl1= new QHBoxLayout( );  // Caption
    QHBoxLayout *lhBigMiddle = new QHBoxLayout( spacingHint() );  // Big middle
-   CHECK_PTR(lhBigMiddle);
+   Q_CHECK_PTR(lhBigMiddle);
    bigdad->addLayout( lhBigMiddle );
    QVBoxLayout *lvFormatSel = new QVBoxLayout( spacingHint() );  // Selection List
-   CHECK_PTR(lvFormatSel);
+   Q_CHECK_PTR(lvFormatSel);
    lhBigMiddle->addLayout( lvFormatSel );
    
    // Insert Scrolled List for formats
    QLabel *l1 = new QLabel( page );
-   CHECK_PTR(l1);
+   Q_CHECK_PTR(l1);
    l1->setText( i18n( "Available image formats:" ));
    
    lb_format = new QListBox( page, "ListBoxFormats" );
-   CHECK_PTR(lb_format);
+   Q_CHECK_PTR(lb_format);
 
 #ifdef USE_KIMAGEIO
    QStringList fo = KImageIO::types();
@@ -113,33 +102,28 @@ FormatDialog::FormatDialog( QWidget *parent, const char *name )
    
    // Insert label for helptext
    l_help = new QLabel( page );
-   CHECK_PTR(l_help);
+   Q_CHECK_PTR(l_help);
    l_help->setFrameStyle( QFrame::Panel|QFrame::Sunken );
    l_help->setText( i18n("-No format selected-" ));
    l_help->setAlignment( AlignVCenter | AlignHCenter );
+   l_help->setMinimumWidth(230);
 
    // Insert Selbox for subformat
    l2 = new QLabel( page );
-   CHECK_PTR(l2);
+   Q_CHECK_PTR(l2);
    l2->setText( i18n( "Select the image sub-format" ));
    cb_subf = new QComboBox( page, "ComboSubFormat" );
-   CHECK_PTR( cb_subf );
+   Q_CHECK_PTR( cb_subf );
 
    // Checkbox to store setting
-   
-#if 0 
-   QFrame *vf = new QFrame(page);
-   vf->setFrameStyle( QFrame::Panel|QFrame::Sunken );
-#endif
-   cbRemember = new QCheckBox(i18n("Remember this format for this image type"),
+   cbDontAsk  = new QCheckBox(i18n("Don't ask again for the save format if it is defined."),
 			      page );
+   Q_CHECK_PTR( cbDontAsk );
 
-   QCheckBox *cbDontAsk  = new QCheckBox(i18n("Don't ask again for this format"),
-			      page );
+   QFrame *hl = new QFrame(page);
+   Q_CHECK_PTR( hl );
+   hl->setFrameStyle( QFrame::HLine|QFrame::Sunken );
 
-   // cbRemember->setFrameStyle( QFrame::Panel|QFrame::Sunken );
-   CHECK_PTR( cbRemember );
-   
    // bigdad->addWidget( l_caption, 1 );
    lvFormatSel->addWidget( l1, 1 );
    lvFormatSel->addWidget( lb_format, 6 );
@@ -148,10 +132,9 @@ FormatDialog::FormatDialog( QWidget *parent, const char *name )
 
    lhBigMiddle->addWidget( l_help, 2 );
    //bigdad->addStretch(1);
-   bigdad->addWidget( cbRemember , 2 );
+   bigdad->addWidget( hl, 1 );
    bigdad->addWidget( cbDontAsk , 2 );
 
-   // bigdad->addWidget( cbRemember,1 );
    bigdad->activate();
    
 }
@@ -192,7 +175,7 @@ void FormatDialog::setSelectedFormat( QString fo )
 }
 
 
-QString FormatDialog::getFormat( void ) const
+QString FormatDialog::getFormat( ) const
 {
    int item = lb_format->currentItem();
 
@@ -205,7 +188,7 @@ QString FormatDialog::getFormat( void ) const
 }
 
 
-QCString FormatDialog::getSubFormat( void ) const
+QCString FormatDialog::getSubFormat( ) const
 {
    // Not yet...
    return( "" );
@@ -222,19 +205,6 @@ void FormatDialog::buildHelp( void )
 }
 
 
-bool FormatDialog::rememberFormat( void ) const
-{
-   bool result = false;
-   
-   if( cbRemember )
-   {
-      return( cbRemember->isChecked());
-   }
-
-   return( result );
-}
-
-
 /* ********************************************************************** */
 
 ImgSaver::ImgSaver(  QWidget *parent, const KURL dir_name )
@@ -244,7 +214,7 @@ ImgSaver::ImgSaver(  QWidget *parent, const KURL dir_name )
    if( dir_name.isEmpty() || dir_name.protocol() != "file" )
    {
       kdDebug(28000) << "ImageServer initialised with wrong dir " << dir_name.url() << endl;
-      directory = kookaImgRoot();
+      directory = Previewer::galleryRoot();
    }
    else
    {
@@ -255,9 +225,7 @@ ImgSaver::ImgSaver(  QWidget *parent, const KURL dir_name )
       }
       else
       {
-	 QString filename = dir_name.url();
-	 directory  = filename.remove(0, 5);  // remove file: from beginning
-	 if( directory.right(1) != "/" ) directory += "/";
+	 directory = dir_name.directory(true, false);
       }
    }
 
@@ -274,7 +242,7 @@ ImgSaver::ImgSaver(  QWidget *parent, const KURL dir_name )
 ImgSaver::ImgSaver( QWidget *parent )
    :QObject( parent )
 {
-   directory = kookaImgRoot();
+   directory = Previewer::galleryRoot();
    createDir( directory );
 
    readConfig();
@@ -327,8 +295,9 @@ ImgSaveStat ImgSaver::saveImage( QImage *image )
    }
    else
    {
-      if( image->depth() == 1 )
+      if( image->depth() == 1 || image->numColors() == 2 )
       {
+	 kdDebug(28000) << "This is black And White!" << endl;
 	 imgType = PT_BW_IMAGE;
       }
       else
@@ -346,7 +315,7 @@ ImgSaveStat ImgSaver::saveImage( QImage *image )
    QString subformat = findSubFormat( format );
    // Call save-Function with this params
 
-   if( format.isEmpty() || format == "Skipped"  )
+   if( format.isEmpty() )
    {
     	kdDebug(28000) << "Save canceled by user -> no save !" << endl;
     	return( ISS_SAVE_CANCELED );
@@ -388,56 +357,57 @@ QString ImgSaver::createFilename( QString format )
 }
 
 /**
- *   This function gets a filename from the parent.
+ *   This function gets a filename from the parent. The filename must not be relative.
  **/
-ImgSaveStat ImgSaver::saveImage( QImage *image, QString filename, QString imgFormat )
+ImgSaveStat ImgSaver::saveImage( QImage *image, const KURL& filename, const QString& imgFormat )
 {
     QString format = imgFormat;
     
-    if( imgFormat.isNull() || imgFormat.isEmpty())
-	QImage::imageFormat( filename );
     /* Check if the filename is local */
-    KURL url( filename );
-    if( url.protocol() != "file" )
+    if( !filename.isLocalFile())
     {
 	kdDebug(29000) << "ImgSaver: Can only save local image, sorry !" << endl;
 	return( ISS_ERR_PROTOCOL );
     }
-    QString fname = filename.remove(0, 5);  // remove file: from beginning
 
-    QFileInfo fi( fname );
-    if( fi.isRelative() )
-	filename = directory +"/"+ filename;
+    QString localFilename;
+    localFilename = filename.directory( false, true) + filename.fileName();
     
-    kdDebug(28000) << "saveImage: Saving "<< filename << " in format " << format << endl;
+    kdDebug(28000) << "saveImage: Saving "<< localFilename << " in format " << format << endl;
     if( format == "" ) 
 	format = "BMP";
 
-    return( save( image, filename, format, "" ) );
+    return( save( image, localFilename, format, "" ) );
 }
 
 
 
 
  
-ImgSaveStat ImgSaver::savePreview( QImage *image )
+ImgSaveStat ImgSaver::savePreview( QImage *image, const QCString& scannerName )
 {
    if( !image ||  image->isNull() )
       return( ISS_ERR_PARAM );
    
    QString format = findFormat( PT_PREVIEW );
 
-   // Previewfile always comes absolute
-      
-   ImgSaveStat stat = save( image, previewfile, format, "" );
+   ImgSaveStat stat = ISS_ERR_FORMAT_NO_WRITE;
 
+   QString previewfile = Previewer::previewFile( scannerName );
+   if( ! format.isEmpty() )
+   {
+      // Previewfile always comes absolute
+      stat = save( image, previewfile, format, "" );
+   }
+   
    if( stat == ISS_OK )
    {
       KConfig *konf = KGlobal::config ();
-      konf->setGroup( OP_FILE_GROUP );
+      konf->setGroup( scannerName );
 
       konf->writeEntry( OP_PREVIEW_FILE,   previewfile );
       konf->writeEntry( OP_PREVIEW_FORMAT, format );
+      konf->sync();
    }
 
    return( stat );
@@ -449,36 +419,89 @@ ImgSaveStat ImgSaver::savePreview( QImage *image )
 QString ImgSaver::findFormat( picType type )
 {
    QString format;
-   // Preview always as bitmap
-   if( type == PT_PREVIEW )
-   {
-      KConfig *konf = KGlobal::config ();
-      konf->setGroup( OP_FILE_GROUP );
-      format = konf->readEntry( OP_PREVIEW_FORMAT, "nothing" );
-
-      if( format == "nothing" )
-      {
-	 format = startFormatDialog( type );
-      }
-   }
+   KConfig *konf = KGlobal::config ();
+   konf->setGroup( OP_FILE_GROUP );
 
    if( type == PT_THUMBNAIL )
    {
       return( "BMP" );
    }
    
-   // real images 
-   if( type != PT_PREVIEW && type != PT_THUMBNAIL && ask_for_format )
+   // real images
+   switch( type )
    {
-      format = startFormatDialog( type );
+      case PT_THUMBNAIL:
+	 format = konf->readEntry( OP_FORMAT_THUMBNAIL, "BMP" );
+	 kdDebug( 28000) << "Format for Thumbnails: " << format << endl;
+	 break;
+      case PT_PREVIEW:
+	 format = konf->readEntry( OP_PREVIEW_FORMAT, "BMP" );
+	 kdDebug( 28000) << "Format for Preview: " << format << endl;
+	 break;
+      case PT_COLOR_IMAGE:
+	 format = konf->readEntry( OP_FORMAT_COLOR, "nothing" );
+	 kdDebug( 28000 ) <<  "Format for Color: " << format << endl;
+	 break;
+      case PT_GRAY_IMAGE:
+	 format = konf->readEntry( OP_FORMAT_GRAY, "nothing" );
+	 kdDebug( 28000 ) <<  "Format for Gray: " << format << endl;
+	 break;
+      case PT_BW_IMAGE:
+	 format = konf->readEntry( OP_FORMAT_BW, "nothing" );
+	 kdDebug( 28000 ) <<  "Format for BlackAndWhite: " << format << endl;
+	 break;
+      case PT_HICOLOR_IMAGE:
+	 format = konf->readEntry( OP_FORMAT_HICOLOR, "nothing" );
+	 kdDebug( 28000 ) <<  "Format for HiColorImage: " << format << endl;
+	 break;
+      default:
+	 format = "nothing";
+	 kdDebug( 28000 ) <<  "ERR: Could not find image type !" << endl;
+
+	 break;
+   }
+
+   if( type != PT_PREVIEW ) /* Use always bmp-Default for preview scans */
+   {
+      if( format == "nothing" || ask_for_format )
+      {
+	 format = startFormatDialog( type );
+      }
    }
    return( format );
    
 }
 
+QString ImgSaver::picTypeAsString( picType type ) const
+{
+   QString res;
+   
+   switch( type )
+   {
+      case PT_COLOR_IMAGE:
+	 res = i18n( "palleted color image (16 or 24 bit depth)" );
+	 break;
+      case PT_GRAY_IMAGE:
+	 res = i18n( "palleted gray scale image (16 bit depth)" );
+	 break;
+      case PT_BW_IMAGE:
+	 res = i18n( "lineart image (black and white, 1 bit depth)" );
+	 break;
+      case PT_HICOLOR_IMAGE:
+	 res = i18n( "high (or true-) color image, not palleted" );
+	 break;
+      default:
+	 res = i18n( "Unknown image type" );
+	 break;
+   }
+   return( res );
+}
+
+
 QString ImgSaver::startFormatDialog( picType type)
 {
-   FormatDialog fd( 0, "FormatDialog" );
+   
+   FormatDialog fd( 0, picTypeAsString( type ), "FormatDialog" );
       
    // set default values
    if( type != PT_PREVIEW )
@@ -486,26 +509,45 @@ QString ImgSaver::startFormatDialog( picType type)
       QString defFormat = getFormatForType( type );
       fd.setSelectedFormat( defFormat );
    }
-      
+
+   QString format;
    if( fd.exec() )
    {
-      QString format = fd.getFormat();
+      format = fd.getFormat();
       kdDebug(28000) << "Storing to format <" << format << ">" << endl;
-      if( fd.rememberFormat() )
-      {
-	 storeFormatForType( type, format );
-      }
+      bool ask = fd.askForFormat();
+      kdDebug(28000)<< "Store askFor is " << ask << endl;
+      storeFormatForType( type, format, ask );
       subformat = fd.getSubFormat();
-
-      return( format );
    }
-   return( i18n("Skipped") );
+   return( format );
 }
 
+
+/*
+ *  This method returns true if the image format given in format is remembered
+ *  for that image type.
+ */
+bool ImgSaver::isRememberedFormat( picType type, QString format ) const
+{
+   if( getFormatForType( type ) == format )
+   {
+      return( true );
+   }
+   else
+   {
+      return( false );
+   }
+   
+}
+
+
+
+
 QString ImgSaver::getFormatForType( picType type ) const
 {
    KConfig *konf = KGlobal::config ();
-   CHECK_PTR( konf );
+   Q_CHECK_PTR( konf );
    konf->setGroup( OP_FILE_GROUP );
 
    QString f;
@@ -532,12 +574,15 @@ QString ImgSaver::getFormatForType( picType type ) const
 }
 
 
-void ImgSaver::storeFormatForType( picType type, QString format )
+void ImgSaver::storeFormatForType( picType type, QString format, bool ask )
 {
    KConfig *konf = KGlobal::config ();
-   CHECK_PTR( konf );
+   Q_CHECK_PTR( konf );
    konf->setGroup( OP_FILE_GROUP );
 
+   konf->writeEntry( OP_FILE_ASK_FORMAT, ask );
+   ask_for_format = ask;
+   
    switch( type )
    {
       case PT_COLOR_IMAGE:
@@ -556,6 +601,7 @@ void ImgSaver::storeFormatForType( picType type, QString format )
 	 kdDebug(28000) << "Wrong Type  - cant store format setting" << endl;
 	 break;
    }
+   konf->sync();
 }
 
 
@@ -587,7 +633,19 @@ ImgSaveStat ImgSaver::save( QImage *image, const QString &filename,
    {
       // remember the last processed file - only the filename - no path
       QFileInfo fi( filename );
-
+      QString dirPath = fi.dirPath();
+      QDir dir = QDir( dirPath );
+      
+      if( ! dir.exists() )
+      {
+	 /* The dir to save in always should exist, except in the first preview save */
+	 kdDebug(28000) << "Creating dir " << dirPath << endl;
+	 if( !dir.mkdir( dirPath ) )
+	 {
+	    kdDebug(28000) << "ERR: Could not create directory" << endl;
+	 }
+      }
+      
       if( fi.exists() && !fi.isWritable() )
       {
 	 kdDebug(28000) << "Cant write to file <" << filename << ">, cant save !" << endl;
@@ -628,20 +686,11 @@ void ImgSaver::readConfig( void )
 {
 
    KConfig *konf = KGlobal::config ();
-   CHECK_PTR( konf );
+   Q_CHECK_PTR( konf );
    konf->setGroup( OP_FILE_GROUP );
    ask_for_format = konf->readBoolEntry( OP_FILE_ASK_FORMAT, true );
 
-   konf->setGroup( OP_PREVIEW_GROUP );
-
-   /* This is a bit ugly, but will be fixed later */
-   /* The save root is defined to $HOME/.kscan in scanpackager, this should be
-    * handled in at a central point. TODO ! */
    QDir home = QDir::home();
-   previewfile = kookaImgRoot() + "preview.bmp";
-   
-   previewfile = konf->readPathEntry( OP_PREVIEW_FILE, previewfile );
-
 }
 
 
@@ -669,36 +718,6 @@ QString ImgSaver::errorString( ImgSaveStat stat )
 
 }
 
-QString ImgSaver::kookaImgRoot( void )
-{
-   QString dir = (KGlobal::dirs())->saveLocation( "data", "ScanImages", true );
+/* extension needs to be added */
 
-   if( dir.right(1) != "/" )
-      dir += "/";
-   
-   return( dir );
-
-}
-
-
-#if 0
-/* Returns the path relativ to the kookaImgRoot. */
-QString ImgSaver::relativeToImgRoot( QString path )
-{
-   QString dir = kookaImgRoot(); /* Always with trailing / */
-   QString res = path;
-   
-   int idx = path.find( dir, 0 ); /* Search if dir is in path */
-   if( idx > -1 )
-   {
-      /* was found */
-      int dirlen = dir.length();
-      int rightlen = path.length() - dirlen - idx -1;
-      res = path.right(rightlen);
-      kdDebug(28000) << "relativToImgRoot returns " << res << endl;
-      
-   }
-   return( res );
-}
-#endif
 #include "img_saver.moc"
