@@ -4,102 +4,288 @@
 #include "devselector.h"
 #include "ksaneocr.h"
 #include "img_saver.h"
+#include "kookapref.h"
+#include "imgnamecombo.h"
 
+#include <qlabel.h>
 #include <qpainter.h>
 #include <qlayout.h>
 #include <qsplitter.h>
 #include <qstrlist.h>
 #include <qpaintdevice.h>
 #include <qpaintdevicemetrics.h>
-
+#include <qpopupmenu.h>
 
 
 #include <kurl.h>
 #include <krun.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kconfig.h>
 #include <kdebug.h>
 #include <ktrader.h>
 #include <klibloader.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <krun.h>
 #include <keditcl.h>
+#include <kled.h>
+#include <kcombobox.h>
+#include <kaction.h>
 
 #define PACKAGER_TAB 0
 #define PREVIEWER_TAB 1
 
-#define STARTUP_IMG_SELECTION "SelectedImageOnStartup"
-#define STARTUP_SELECTED_PAGE "TabWidgetPage"
+#define STARTUP_IMG_SELECTION   "SelectedImageOnStartup"
+#define STARTUP_SELECTED_PAGE   "TabWidgetPage"
+#define STARTUP_SCANPARAM_SIZES "ScanParamDialogSizes"
+#define STARTUP_VIEWER_SIZES    "ViewerSplitterSizes"
 
-KookaView::KookaView(QWidget *parent)
+
+KookaView::KookaView(QWidget *parent, const QCString& deviceToUse)
     : QSplitter(parent)
 {
 
    /* Another splitter for splitting the Packager Tree from the Scan Parameter */
    ocrFabric = 0L;
    
-   QSplitter *left_splitter = new QSplitter( QSplitter::Vertical, this );
+   paramSplitter = new QSplitter( QSplitter::Vertical, this );
    setOpaqueResize( false );
-   left_splitter->setOpaqueResize( false );
+   paramSplitter->setOpaqueResize( false );
 
    /* An image canvas for the large image, right side */
    
    img_canvas  = new ImageCanvas( this );
+   img_canvas->setMinimumSize(100,200);
+   img_canvas->enableContextMenu(true);
    
    setResizeMode( img_canvas,    QSplitter::Stretch );
-   setResizeMode( left_splitter, QSplitter::FollowSizeHint );
+   setResizeMode( paramSplitter, QSplitter::KeepSize);
 
+   /* Create a vbox to take the tabwidget and the the combobox */
+   QVBox *vbox = new QVBox( paramSplitter );
    /* The Tabwidget to contain the preview and the packager */
-   tabw  = new QTabWidget( left_splitter, "TABWidget" );
+   tabw  = new QTabWidget( vbox, "TABWidget" );
 
    /* A new packager to contain the already scanned images */
    packager = new ScanPackager( tabw );
    {
    }
+      
+   /* build up the Preview/Packager-Tabview */
+   tabw->insertTab( packager, i18n( "&Gallery"), PACKAGER_TAB );
+
+   tabw->setMinimumSize(100, 100);
+
+   /*
+    * Create a Kombobox that holds the last folders visible even on the preview page
+    */
+   QHBox *recentBox = new QHBox( vbox );
+   recentBox->setMargin(KDialog::marginHint());
+   QLabel *lab = new QLabel( i18n("Gallery"), recentBox );
+   lab->setSizePolicy( QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed) );
+   recentFolder = new ImageNameCombo( recentBox );
+
+   
+   connect( packager,  SIGNAL( galleryPathSelected( KFileTreeBranch*, const QString&)),
+	    recentFolder, SLOT( slotGalleryPathChanged( KFileTreeBranch*, const QString& )));
+
+   connect( packager,  SIGNAL( directoryToRemove( KFileTreeBranch*, const QString&)),
+	    recentFolder, SLOT(   slotPathRemove( KFileTreeBranch*, const QString& )));
+
+   connect( recentFolder, SIGNAL(activated( const QString& )),
+	    packager, SLOT(slotSelectDirectory( const QString& )));
+   
+   /* the object from the kscan lib to handle low level scanning */
+   sane = new KScanDevice( this );
+   Q_CHECK_PTR(sane);
+   // connect( sane, SIGNAL( sigCloseDevice()), this, SLOT( slCloseScanDevice()));
+
+   /* select the scan device, either user or from config, this creates and assembles
+    * the complete scanner options dialog
+    * scan_params must be zero for that */
+   scan_params = 0L;
+   preview_canvas = 0L;
    
-   /* Image Canvas for the preview image, same object as the large image canvas */
-   preview_img = 0L;
    preview_canvas = new Previewer( tabw );
    {
       preview_canvas->setMinimumSize( 100,100);
    	
-      preview_img = new QImage();
-      preview_img->load( packager->getSaveRoot() + "preview.bmp" );
-      preview_canvas->newImage( preview_img );
+      /* since the scan_params will be created in slSelectDevice, do the
+       * connections later
+       */
    }
-
-   /* build up the Preview/Packager-Tabview */
-   tabw->insertTab( packager, i18n( "&Images"), PACKAGER_TAB );
    tabw->insertTab( preview_canvas, i18n("&Preview"), PREVIEWER_TAB );
 
-   tabw->setMinimumSize(100, 100);
+   if( slSelectDevice(deviceToUse))
+   {
+      /* If a scanner exists */
+
+      /* Load from config which tab page was selected last time */
+      KConfig *konf = KGlobal::config ();
+      konf->setGroup(GROUP_STARTUP);
+      QString startup = konf->readEntry( STARTUP_SELECTED_PAGE, "nothing" );
+      if( startup == "previewer" )
+	 tabw->showPage(preview_canvas);
+      else
+	 tabw->showPage(packager);
+   }
+   else
+   {
+      /* If there is no scanner, disable the preview tab */
+      tabw->setTabEnabled( preview_canvas, false );
+      tabw->showPage( packager );
+   }
+
+   /* New image created after scanning */
+   connect(sane, SIGNAL(sigNewImage(QImage*)), packager, SLOT(slAddImage(QImage*)));
+   /* New preview image */
+   connect(sane, SIGNAL(sigNewPreview(QImage*)), this, SLOT( slNewPreview(QImage*)));
+
+   connect( sane, SIGNAL( sigScanStart() ), this, SLOT( slScanStart()));
+   connect( sane, SIGNAL( sigScanFinished(KScanStat)), this, SLOT(slScanFinished(KScanStat)));
+   connect( sane, SIGNAL( sigAcquireStart()), this, SLOT( slAcquireStart()));
+   /* Image canvas should show a new document */
+   connect( packager, SIGNAL( showImage( QImage* )),
+            img_canvas, SLOT( newImage( QImage*)));
+
+   /* Packager unloads the image */
+   connect( packager, SIGNAL( unloadImage( QImage* )),
+            img_canvas, SLOT( deleteView( QImage*)));
+
+
+}
+
+
+KookaView::~KookaView()
+{
+   saveProperties( KGlobal::config () );
+   kdDebug(28000)<< "Finished saving config data" << endl;
+}
+
+
+bool KookaView::slSelectDevice( const QCString& useDevice )
+{
+
+   kdDebug(28000) << "Kookaview: select a device!" << endl;
+   bool haveConnection = false;
+
+   QCString selDevice;
+   /* in case useDevice is the term 'gallery', the user does not want to
+    * connect to a scanner, but only work in gallery mode. Otherwise, try
+    * to read the device to use from config or from a user dialog */
+   if( useDevice != "gallery" )
+   {
+      selDevice =  useDevice;
+      if( selDevice.isEmpty())
+      {
+	 selDevice = userDeviceSelection();
+      }
+   }
+   
+   if( !selDevice.isEmpty() )
+   {
+      kdDebug(28000) << "Opening device " << selDevice << endl;
+
+      if( connectedDevice == selDevice ) {
+	 kdDebug( 28000) << "Device " << selDevice << " is already selected!" << endl;
+	 return( true );
+      }
+      
+      if( scan_params )
+      {
+	 /* This deletes the existing scan_params-object */
+	 slCloseScanDevice();
+      }
+      /* This connects to the selected scanner */
+      scan_params = new ScanParams( paramSplitter );
+      Q_CHECK_PTR(scan_params);
+      paramSplitter->setResizeMode( scan_params, QSplitter::FollowSizeHint );
+
+      if( sane->openDevice( selDevice ) == KSCAN_OK )
+      {
+         connect( scan_params,    SIGNAL( scanResolutionChanged( int, int )),
+                  preview_canvas, SLOT( slNewScanResolutions( int, int )));
+
+	 if( ! scan_params->connectDevice( sane ) )
+	 {
+	    kdDebug(28000) << "Connecting to the scanner failed :( ->TODO" << endl;
+	 }
+	 else
+	 {
+	    haveConnection = true;
+	    connectedDevice = selDevice;
+
+	    /* New Rectangle selection in the preview, now scanimge exists */
+	    ImageCanvas *previewCanvas = preview_canvas->getImageCanvas();
+	    connect( previewCanvas , SIGNAL( newRect(QRect)),
+		     scan_params, SLOT(slCustomScanSize(QRect)));
+	    connect( previewCanvas, SIGNAL( noRect()),
+		     scan_params, SLOT(slMaximalScanSize()));
+	    // connect( scan_params,    SIGNAL( scanResolutionChanged( int, int )),
+            // 		     preview_canvas, SLOT( slNewScanResolutions( int, int )));
+	 }
+      }
+      else
+      {
+	 kdDebug(28000) << "Could not open device <" << selDevice << ">" << endl;
+	 scan_params->connectDevice(0);
+      }
+
+      /* try to load the size from config */
+   }
+   else
+   {
+      // no devices available or starting in gallery mode
+      if( scan_params )
+	 scan_params->connectDevice( 0L );
+   }
 
    KConfig *konf = KGlobal::config ();
-   konf->setGroup(GROUP_STARTUP);
-   QString startup = konf->readEntry( STARTUP_SELECTED_PAGE, "nothing" );
-   if( startup == "previewer" )
-      tabw->showPage(preview_canvas);
-   else
-      tabw->showPage(packager);
+   QString referToScanner( sane->shortScannerName());
+   if( !haveConnection ) referToScanner = "gallery";
 
-   /* ..and create the Scanner parameter object, which displays the parameter
-    *   the current scanner provides.
-    */
-   scan_params = new ScanParams( left_splitter);
-   CHECK_PTR(scan_params);
+   konf->setGroup( referToScanner );
+   QValueList<int> sizes = konf->readIntListEntry( STARTUP_SCANPARAM_SIZES );
+   QValueList<int> vsizes = konf->readIntListEntry( STARTUP_VIEWER_SIZES );
+   
+   if( sizes.count() == 0  )
+   {
+      kdDebug(28000) << "Setting default sizes" << endl;
+	 
+      /* Shitty, nothing yet in the config */
+      if( haveConnection )
+      {
+	 sizes << packager->height();
+	 sizes << scan_params->height();
+	 vsizes << (scan_params->sizeHint()).width();
+      }
+      else
+      {
+	 /* only push one value to vsizes */
+	 vsizes << 150;
+      }
+   }
+   kdDebug(28000) << "Setting sizes !" << endl;
+   setSizes( vsizes );
+   if( haveConnection )
+   {
+      paramSplitter->setSizes( sizes );
 
-   /* the object from the kscan lib to handle low level scanning */
-   sane = new KScanDevice( this );
-   CHECK_PTR(sane);
+      scan_params->show();
+      preview_canvas->loadPreviewImage( selDevice );
+   }
+
+   return( haveConnection );
+}
+
+QCString KookaView::userDeviceSelection( ) const
+{
+   /* Human readable scanner descriptions */
+   QStringList hrbackends;
 
    /* a list of backends the scan backend knows */
    QStrList backends = sane->getDevices();
-   
-   /* Human readable scanner descriptions */
-   QStringList hrbackends;
    QStrListIterator  it( backends );
-
+   
    QCString selDevice;
    if( backends.count() > 0 )
    {
@@ -111,7 +297,7 @@ KookaView::KookaView(QWidget *parent)
       }
 
       /* allow the user to select one */
-       DeviceSelector ds( this, backends, hrbackends );
+       DeviceSelector ds( 0, backends, hrbackends );
        selDevice = ds.getDeviceFromConfig( );
 
        if( selDevice.isEmpty() || selDevice.isNull() )
@@ -123,93 +309,10 @@ KookaView::KookaView(QWidget *parent)
 	  }
        }
    }
-       
-   if( ! selDevice.isNull() )
-   {
-      kdDebug(28000) << "Opening device " << selDevice << endl;
-
-      /* This connects to the selected scanner */
-      sane->openDevice( selDevice );
-      if( ! scan_params->connectDevice( sane ) )
-      {
-	 kdDebug(28000) << "Connecting to the scanner failed :( ->TODO" << endl;
-      }
-   }
-   else
-   {
-      // no devices available
-      scan_params->connectDevice( 0L );
-      preview_canvas->setEnabled( false );
-      
-   }
-   
-   scan_params->resize( scan_params->sizeHint() );
-   scan_params->show();
-
-
-   /* New image created after scanning */
-   connect(sane, SIGNAL(sigNewImage(QImage*)), packager, SLOT(slAddImage(QImage*)));
-   /* New preview image */
-   connect(sane, SIGNAL(sigNewPreview(QImage*)), this, SLOT( slNewPreview(QImage*)));
-
-   /* Image canvas should show a new document */
-   connect( packager, SIGNAL( showImage( QImage* )),
-            img_canvas, SLOT( newImage( QImage*)));
-
-   /* Packager unloads the image */
-   connect( packager, SIGNAL( unloadImage( QImage* )),
-            img_canvas, SLOT( deleteView( QImage*)));
-
-   /* New Rectangle selection in the preview */
-   connect( preview_canvas->getImageCanvas(), SIGNAL( newRect(QRect)),
-            scan_params, SLOT(slCustomScanSize(QRect)));
-   connect( preview_canvas->getImageCanvas(), SIGNAL( noRect()),
-            scan_params, SLOT(slMaximalScanSize()));
-
-
-#if 0
-   KTrader::OfferList offers = KTrader::self()->query("text/html", "'KParts/ReadOnlyPart' in ServiceTypes");
-
-   KLibFactory *factory = 0;
-   // in theory, we only care about the first one.. but let's try all
-   // offers just in case the first can't be loaded for some reason
-   KTrader::OfferList::Iterator it(offers.begin());
-   for( ; it != offers.end(); ++it)
-   {
-      KService::Ptr ptr = (*it);
-
-      // we now know that our offer can handle HTML and is a part.
-      // since it is a part, it must also have a library... let's try to
-      // load that now
-      factory = KLibLoader::self()->factory( ptr->library() );
-      if (factory)
-      {
-	 m_html = static_cast<KParts::ReadOnlyPart *>(factory->create(this, ptr->name(),
-								      "KParts::ReadOnlyPart"));
-	 break;
-      }
-   }
-
-   // if our factory is invalid, then we never found our component
-   // and we might as well just exit now
-   if (!factory)
-   {
-      KMessageBox::error(this, i18n("Could not find a suitable HTML component"));
-      return;
-   }
-#endif
-
+   return( selDevice );
 }
 
 
-KookaView::~KookaView()
-{
-   saveProperties( KGlobal::config () );
-   kdDebug(28000)<< "Finished saving config data" << endl;
-   // if( preview_img ) delete( preview_img );
-
-}
-
 void KookaView::loadStartupImage( void )
 {
    kdDebug( 28000) << "Starting to load startup image" << endl;
@@ -219,12 +322,21 @@ void KookaView::loadStartupImage( void )
    if( konf )
    {
       konf->setGroup(GROUP_STARTUP);
-      QString startup = konf->readEntry( STARTUP_IMG_SELECTION, "" );
+      bool wantReadOnStart = konf->readBoolEntry( STARTUP_READ_IMAGE, true );
 
-      if( !startup.isEmpty())
+      if( wantReadOnStart )
       {
-	 kdDebug(28000) << "Loading startup image !" << endl;
-	 packager->slSelectImage( startup );
+	 QString startup = konf->readEntry( STARTUP_IMG_SELECTION, "" );
+
+	 if( !startup.isEmpty() )
+	 {
+	    kdDebug(28000) << "Loading startup image !" << endl;
+	    packager->slSelectImage( KURL(startup) );
+	 }
+      }
+      else
+      {
+	 kdDebug(28000) << "Do not load startup image due to config value" << endl;
       }
    }
 }
@@ -289,23 +401,19 @@ void KookaView::slNewPreview( QImage *new_img )
 {
    if( new_img )
    {
-      if( preview_img )
-	 delete( preview_img );
-      preview_img = new QImage( *new_img );
-
       if( ! new_img->isNull() )
       {
 	 ImgSaveStat is_stat = ISS_OK;
 	 ImgSaver img_saver( this );
 
-	 is_stat = img_saver.savePreview( new_img );
+	 is_stat = img_saver.savePreview( new_img, sane->shortScannerName() );
 
 	 if( is_stat != ISS_OK )
 	 {
 	    kdDebug(28000) << "ERROR in saving preview !" << endl;
 	 }
       }
-      preview_canvas->newImage( preview_img );
+      preview_canvas->newImage( new_img ); 
    }
 }
 
@@ -373,18 +481,74 @@ void KookaView::startOCR( const QImage *img )
       if( ocrFabric == 0L )
 	 ocrFabric = new KSANEOCR(this );
 
-      CHECK_PTR( ocrFabric );
+      Q_CHECK_PTR( ocrFabric );
       ocrFabric->setImage( img );
 
       if( !ocrFabric->startExternOcrVisible() )
       {
-	 KMessageBox::error(0, i18n("Could not start OCR-Process,\n"
+	 KMessageBox::sorry(0, i18n("Could not start OCR-Process.\n"
 				    "Probably there is already one running." ));
 
       }
    }
 }
 
+void KookaView::slScanStart( )
+{
+   kdDebug(28000) << "Scan starts " << endl;
+   if( scan_params )
+   {
+      scan_params->setEnabled( false );
+      KLed *led = scan_params->operationLED();
+      if( led )
+      {
+	 led->setColor( Qt::red );
+	 led->setState( KLed::On );
+      }
+   }
+}
+
+void KookaView::slAcquireStart( )
+{
+   kdDebug(28000) << "Acquire starts " << endl;
+   if( scan_params )
+   {
+      KLed *led = scan_params->operationLED();
+      if( led )
+      {
+	 led->setColor( Qt::green );
+      }
+   }
+}
+
+
+
+void KookaView::slScanFinished( KScanStat stat )
+{
+   kdDebug(28000) << "Scan finished with status " << stat << endl;
+   if( scan_params )
+   {
+      scan_params->setEnabled( true );
+      KLed *led = scan_params->operationLED();
+      if( led )
+      {
+	 led->setColor( Qt::green );
+	 led->setState( KLed::Off );
+      }
+   }
+}
+
+
+void KookaView::slCloseScanDevice( )
+{
+   kdDebug(28000) << "Scanner Device closes down !" << endl;
+   if( scan_params ) {
+      delete scan_params;
+      scan_params = 0;
+   }
+   sane->slCloseDevice();
+}
+
 void KookaView::slCreateNewImgFromSelection()
 {
    if( img_canvas->rootImage() )
@@ -491,7 +655,17 @@ void KookaView::slSaveScanParams( void )
 {
    if( !sane ) return;
 
+   KScanOptSet optSet( "SaveSet" );
+   
+   sane->getCurrentOptions( &optSet );
+#if 0
+   SaveSetDialog dialog( this, &optSet );
+   if( dialog.exec())
+   {
+      kdDebug(28000)<< "Executed successfully" << endl;
+   }
    sane->slSaveScanConfigSet( "sysmtem-default", "default configuration" );
+#endif
 }
 
 
@@ -517,6 +691,21 @@ void KookaView::saveProperties(KConfig *config)
       tabwPre = "previewer";
 
    config->writeEntry( STARTUP_SELECTED_PAGE, tabwPre );
+
+   /* Save the scan parameters size in accordance to the selected scanner */
+   if( sane && scan_params )
+   {
+      config->setGroup( sane->shortScannerName());
+      QValueList<int> pssizes = paramSplitter->sizes();
+      config->writeEntry( STARTUP_SCANPARAM_SIZES, pssizes );
+   }
+   else
+   {
+      config->setGroup( "gallery" );
+   }
+   /* Sizes of the vertical splitter */
+   QValueList<int> vsizes = sizes();
+   config->writeEntry(STARTUP_VIEWER_SIZES, vsizes );
 }
 
 
@@ -524,18 +713,18 @@ void KookaView::slOpenCurrInGraphApp( void )
 {
    QString file;
    
-   if( packager ) {
-      file = packager->getCurrImageFileName( true );
+   if( packager )
+   {
+      KFileTreeViewItem *ftvi = packager->currentKFileTreeViewItem();
+
+      if( ! ftvi ) return;
       
-      kdDebug(28000) << "Trying to open <" << file << ">" << endl;
-      if( ! file.isEmpty() )
-      {
-	 KURL::List urllist;
+      kdDebug(28000) << "Trying to open <" << ftvi->url().prettyURL()<< ">" << endl;
+      KURL::List urllist;
 	 
-	 urllist.append( KURL(file) );
-	 KFileOpenWithHandler kfoh;
-	 kfoh.displayOpenWithDialog( urllist );
-      }
+      urllist.append( ftvi->url());
+	 
+      KRun::displayOpenWithDialog( urllist );
    }
 }
 
@@ -642,4 +831,15 @@ QImage KookaView::rotateRight( QImage *m_img )
    return( rot );
 }
 
+void KookaView::connectViewerAction( KAction *action )
+{
+   QPopupMenu *popup = img_canvas->contextMenu();
+
+   if( popup && action )
+   {
+      action->plug( popup );
+   }
+}
+
+
 #include "kookaview.moc"
