@@ -121,7 +121,7 @@ private:
    // int 	        readDir( QListViewItem *parent, QString dir_to_read );
     void         showContextMenu( QPoint p, bool show_folder = true );
 
-    QDir         curr_copy_dir;
+    QString      m_currCopyDir;
     QString      currSelectedDir;
     KIO::Job     *copyjob;
     KPopupMenu   *popup;   
