@@ -1,4 +1,4 @@
-// $Id: areaselect.cpp,v 1.22 2000/12/11 19:53:27 jcaliff Exp $
+// $Id: areaselect.cpp,v 1.23 2001/10/10 17:57:45 mueller Exp $
 
 #include <stdio.h>
 #include <qcursor.h>
@@ -8,7 +8,7 @@
 #include <qclipboard.h>
 
 #include <klocale.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kdebug.h>
 #include <kmessagebox.h>
 #include <kiconloader.h>
