@@ -10,7 +10,7 @@ class AreaSelect : public Tool
 {
 Q_OBJECT
 public:
-AreaSelect(const char *toolname);
+AreaSelect(const QString & toolname);
   /*  virtual ~AreaSelect(); */
   virtual void mousePressEvent(QMouseEvent *e);
   virtual void mouseMoveEvent(QMouseEvent *e);
