@@ -1,6 +1,6 @@
 // -*- c++ -*-
 
-// $Id: canvas.h,v 1.11 2000/12/11 19:53:27 jcaliff Exp $
+// $Id: canvas.h,v 1.13 2001/11/03 14:22:04 andreas Exp $
 
 #ifndef CANVAS_H
 #define CANVAS_H
@@ -9,36 +9,35 @@
 #include <qevent.h>
 #include <qpixmap.h>
 #include <qobject.h>
-#include <qpixmap.h>
 #include <qwmatrix.h>
 
 class Tool;
 
 class Canvas : public QWidget
 {
-Q_OBJECT
+  Q_OBJECT
 
 public:
-Canvas(int width, int height,
-       QWidget *parent= 0, const char *name=0);
-Canvas(const QString & filename,
-       QWidget *parent= 0, const char *name=0);
-~Canvas();
+  Canvas(int width, int height, QWidget *parent= 0, const char *name=0);
+  Canvas(const QString & filename, QWidget *parent= 0, const char *name=0);
+  ~Canvas();
 
   QPixmap *pixmap();
   void setPixmap(QPixmap *);
   void setDepth(int);
-  inline int getDepth();
+  int getDepth() const { return pix->depth(); }
 
-  const QRect &selection();
+  const QRect &selection() const;
   void setSelection(const QRect&);
-  inline bool hasSelection() const;
+  bool hasSelection() const { return haveSelection_; }
   void clearSelection();
-  QPixmap *selectionData();
 
-  void cut(); // copies from selection into clipboard and then cuts selection
-  void copy(bool andCut); // copys from selection into clipboard
-  void paste(); // paste from clipboard into canvas
+  /** copies from selection into clipboard and then cuts selection */
+  void cut();
+  /** copys from selection into clipboard */
+  void copy();
+  /* paste from clipboard into canvas */
+  void paste( int x, int y );
 
   //static inline bool hasClipboardData();
   //static inline const QPixmap *clipboardData();
@@ -71,10 +70,6 @@ Canvas(const QString & filename,
   void keyPressEvent(QKeyEvent *e);
   void keyReleaseEvent(QKeyEvent *e);
 
-    bool hasClipboardData();
-    const QPixmap * clipboardData() { return &clipboardPix; }
-
-
 public slots:
   void markModified();
 
@@ -94,29 +89,20 @@ protected:
   QWMatrix *matrix;
   Tool *currentTool;
 
-  /**
-   * Zoomed copy
-   */
+  /** Zoomed copy */
   QPixmap *zoomed;
 
-  /**
-   * Master copy
-   */
+  /** Master copy */
   QPixmap *pix;
 
-  /**
-   * Clipboard Data from Cut/Copy
-   */
+  /** Clipboard Data from Cut/Copy */
   //static QPixmap *clipboardPix;
   QPixmap clipboardPix;
-  /**
-   * % of original size
-   */
+
+  /** % of original size */
   int zoomFactor;
 
-  /**
-   * Has the pixmap been modified?
-   */
+  /** Has the pixmap been modified? */
   bool modified_;
   state s;
   QRect selection_;
@@ -127,13 +113,4 @@ protected:
   
 };
 
-int 
-Canvas::getDepth()
-{ return pix->depth(); }
-
-bool 
-Canvas::hasSelection() const
-{ return haveSelection_; }
-
-
 #endif // CANVAS_H
