@@ -1,12 +1,12 @@
 // -*- c++ -*-
 
-// $Id: depthdialog.h,v 1.2 1998/10/18 19:59:45 habenich Exp $
+// $Id: depthdialog.h,v 1.3 1999/03/01 23:32:09 kulow Exp $
 
 #ifndef DEPTHDIALOG_H
 #define DEPTHDIALOG_H
 
 #include <qdialog.h>
-#include <qcombo.h>
+#include <qcombobox.h>
 #include <qlabel.h>
 #include "canvas.h"
 
