@@ -1,4 +1,4 @@
-// $Id: infodialog.cpp,v 1.14 2001/07/25 15:35:16 rich Exp $
+// $Id: infodialog.cpp,v 1.15 2001/10/10 17:57:45 mueller Exp $
 
 #include <qgrid.h>
 #include <qimage.h>
@@ -7,7 +7,7 @@
 //#include <qlineedit.h>
 #include <qpushbutton.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kseparator.h>
