@@ -1,16 +1,17 @@
 // -*- c++ -*-
 
-// $Id: infodialog.h,v 1.4 1999/03/01 23:32:14 kulow Exp $
+// $Id: infodialog.h,v 1.5 2001/07/25 15:35:16 rich Exp $
 
 #ifndef IMAGEINFODIALOG_H
 #define IMAGEINFODIALOG_H
 
-#include <qdialog.h>
 #include <qcombobox.h>
 #include <qlabel.h>
-#include "canvas.h"
+#include <kdialog.h>
 
-class imageInfoDialog : public QDialog
+class Canvas;
+
+class imageInfoDialog : public KDialog
 {
     Q_OBJECT
 
