@@ -1,4 +1,4 @@
-// $Id: line.cpp,v 1.22 2000/06/05 11:04:59 hoelzer Exp $
+// $Id: line.cpp,v 1.25 2000/11/25 10:06:51 mlaurent Exp $
 
 // Note: When used to draw more than one line segment should use draw poly line
 // functions to avoid glitches at the joints.
@@ -13,7 +13,7 @@
 #include "line.h"
 #include <kiconloader.h>
 
-Line::Line(const char *toolname) : Tool(toolname)
+Line::Line(const QString & toolname) : Tool(toolname)
 {
   drawing= FALSE;
   tooltip= i18n("Line");
@@ -22,7 +22,7 @@ Line::Line(const char *toolname) : Tool(toolname)
 
 void Line::activating()
 {
-kdDebug(3000) << "Line::activating() hook called\n" << endl;
+kdDebug(4400) << "Line::activating() hook called\n" << endl;
 
   canvas->setCursor(crossCursor);
 }
@@ -34,11 +34,11 @@ void Line::mousePressEvent(QMouseEvent *e)
 #endif
   QPainter paint;
 
-  kdDebug(3000) << "RubberLine::mousePressEvent() handler called\n" << endl;
+  kdDebug(4400) << "RubberLine::mousePressEvent() handler called\n" << endl;
 
   if (isActive()) {
     if (drawing) {
-      kdDebug(3000) << "Line: Warning button press received while drawing\n" << endl;
+      kdDebug(4400) << "Line: Warning button press received while drawing\n" << endl;
     }
     else {
       startx= (e->pos()).x();
@@ -77,7 +77,7 @@ void Line::mousePressEvent(QMouseEvent *e)
 #endif
   
   if (!isActive()) {
-kdWarning(3000) << "Line: Warning event received when inactive (ignoring)\n" << endl;
+kdWarning(4400) << "Line: Warning event received when inactive (ignoring)\n" << endl;
   }
 }
 
@@ -115,7 +115,7 @@ void Line::mouseMoveEvent(QMouseEvent *e)
     }
   }
   else {
-kdWarning(3000) << "Line: Warning event received when inactive (ignoring)\n" << endl;
+kdWarning(4400) << "Line: Warning event received when inactive (ignoring)\n" << endl;
   }
 }
 
@@ -125,10 +125,10 @@ void Line::mouseReleaseEvent(QMouseEvent *e)
   QPainter paint;
   QWMatrix m;
 
-kdDebug(3000) << "Line::mouseReleaseEvent() handler called\n" << endl;
+kdDebug(4400) << "Line::mouseReleaseEvent() handler called\n" << endl;
 
   if (isActive() && drawing && (e->button() == activeButton)) {
-    emit modified();
+    canvas->markModified();
     x= (e->pos()).x();
     y= (e->pos()).y();
 
@@ -160,7 +160,7 @@ kdDebug(3000) << "Line::mouseReleaseEvent() handler called\n" << endl;
     canvas->repaint(0);
   }
   else {
-kdWarning(3000) << "Warning event received when inactive (ignoring)\n" << endl;
+kdWarning(4400) << "Warning event received when inactive (ignoring)\n" << endl;
   }
 }
 
