@@ -3,7 +3,7 @@
 // Line class
 // This class is a subclass of Tool and provides a rubber line drawing tool.
 
-// $Id: line.h,v 1.6 1999/06/19 23:17:06 kulow Exp $
+// $Id: line.h,v 1.7 2000/08/06 10:25:10 bieker Exp $
 
 #ifndef LINE_H
 #define LINE_H
@@ -15,7 +15,7 @@ class Line : public Tool
 {
   Q_OBJECT
 public:
-  Line(const char *toolname);
+  Line(const QString & toolname);
   void mousePressEvent(QMouseEvent *e);
   void mouseMoveEvent(QMouseEvent *e);
   void mouseReleaseEvent(QMouseEvent *e);
