@@ -3,7 +3,6 @@
 #ifndef MAINVIEW_H
 #define MAINVIEW_H
 
-
 #include <qwidget.h>
 
 class View;
@@ -12,40 +11,31 @@ class Canvas;
 class QBoxLayout;
 
 /**
- * view window for kpaint
- * just created for layout.
+ * view window for kpaint just created for layout.
  */
 class MainView : public QWidget
 {
-Q_OBJECT
+  Q_OBJECT
 public:
-MainView(QWidget *parent=0, const char *name=0);
+  MainView(QWidget *parent=0, const char *name=0);
+  ~MainView();
 
-  inline QScrollView *getViewport() const;
-  inline Canvas *getCanvas() const;
+  QScrollView *getViewport() const { return v; }
+  Canvas *getCanvas() const { return c; }
+
+public slots:
+  void updateLayout();
+
+protected:
+  void resizeEvent( QResizeEvent *e );
 
 private:
-
   // Child widgets
-  View *view;
   QScrollView *v;
   Canvas *c;
 
   // Layoutmanager
   QBoxLayout *lm;
-
 };
 
-QScrollView *
-MainView::getViewport() const
-{
-  return v;
-}
-
-Canvas *
-MainView::getCanvas() const
-{
-  return c;
-}
-
 #endif // MAINVIEW_H
