@@ -21,13 +21,13 @@
 */
 
 
-#include <qtableview.h>
+#include <qttableview.h>
 #include <qpixmap.h>
 #include <qpainter.h>
 #include <qimage.h>
 #include <qevent.h>
 
-class paletteWidget : public QTableView
+class paletteWidget : public QtTableView
 {
     Q_OBJECT
 
