@@ -1,7 +1,7 @@
 #include <kdebug.h>
 #include <qpushbutton.h>
 #include <klocale.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include "palettedialog.h"
 
 paletteDialog::paletteDialog(QPixmap *p, QWidget *parent, const char *name)
