@@ -1,5 +1,5 @@
 // -*- c++ -*-
-// $Id: pen.h,v 1.6 1999/06/19 23:17:07 kulow Exp $
+// $Id: pen.h,v 1.7 2000/08/06 10:25:10 bieker Exp $
 
 #ifndef PEN_H
 #define PEN_H
@@ -12,7 +12,7 @@ class Pen : public Tool
 {
   Q_OBJECT
 public:
-  Pen(const char *toolname);
+  Pen(const QString & toolname);
   void mousePressEvent(QMouseEvent *e);
   void mouseMoveEvent(QMouseEvent *e);
   void mouseReleaseEvent(QMouseEvent *e);
