@@ -1,4 +1,4 @@
-// $Id: roundangle.cpp,v 1.11 2000/06/05 11:04:59 hoelzer Exp $
+// $Id: roundangle.cpp,v 1.14 2000/11/25 10:06:51 mlaurent Exp $
 
 #include <kdebug.h>
 #include <stdio.h>
@@ -12,7 +12,7 @@
 
 #define ROUNDNESS (40)
 
-Roundangle::Roundangle(const char *toolname) : Tool(toolname)
+Roundangle::Roundangle(const QString & toolname) : Tool(toolname)
 {
   drawing= FALSE;
 
@@ -22,17 +22,17 @@ Roundangle::Roundangle(const char *toolname) : Tool(toolname)
 
 void Roundangle::activating()
 {
-kdDebug(3000) << "Roundangle::activating() hook called\n" << endl;
+kdDebug(4400) << "Roundangle::activating() hook called\n" << endl;
   canvas->setCursor(crossCursor);
 }
 
 void Roundangle::mousePressEvent(QMouseEvent *e)
 {
-kdDebug(3000) << "Roundangle::mousePressEvent() handler called\n" << endl;
+kdDebug(4400) << "Roundangle::mousePressEvent() handler called\n" << endl;
   
   if (isActive()) {
     if (drawing) {
-      kdDebug(3000) << "RubberLine: Warning Left Button press received when pressed\n" << endl;
+      kdDebug(4400) << "RubberLine: Warning Left Button press received when pressed\n" << endl;
     }
     else {
       startx= (e->pos()).x();
@@ -44,7 +44,7 @@ kdDebug(3000) << "Roundangle::mousePressEvent() handler called\n" << endl;
     } 
   }
   if (!isActive()) {
-kdWarning(3000) << "Warning event received when inactive (ignoring)\n" << endl;
+kdWarning(4400) << "Warning event received when inactive (ignoring)\n" << endl;
   }
 }
 
@@ -84,7 +84,7 @@ void Roundangle::mouseMoveEvent(QMouseEvent *e)
     }
   }
   else {
-kdWarning(3000) << "Warning event received when inactive (ignoring)\n" << endl;
+kdWarning(4400) << "Warning event received when inactive (ignoring)\n" << endl;
   }
 }
 
@@ -94,10 +94,10 @@ void Roundangle::mouseReleaseEvent(QMouseEvent *e)
   QPainter paint;
   QWMatrix m;
 
-kdDebug(3000) << "Roundangle::mouseReleaseEvent() handler called\n" << endl;
+kdDebug(4400) << "Roundangle::mouseReleaseEvent() handler called\n" << endl;
 
   if (isActive() && (e->button() == activeButton)) {
-    emit modified();
+    canvas->markModified();
     x= (e->pos()).x();
     y= (e->pos()).y();
 
@@ -137,7 +137,7 @@ kdDebug(3000) << "Roundangle::mouseReleaseEvent() handler called\n" << endl;
     canvas->repaint(0);
   }
   else {
-kdWarning(3000) << "Warning event received when inactive (ignoring)\n" << endl;
+kdWarning(4400) << "Warning event received when inactive (ignoring)\n" << endl;
   }
 }
 
