@@ -5,9 +5,9 @@
 #define TEXT_H
 
 #include "tool.h"
-#include <qstack.h>
+#include <qptrstack.h>
 
-typedef QStack<int> LineStack;
+typedef QPtrStack<int> LineStack;
 
 class Text : public Tool
 {
@@ -39,7 +39,7 @@ private:
     cursorH, cursorW,
     lastx, lasty;
   bool drawing, showingC;
-  //  int activeButton;
+  int activeButton;
   QString charBuffer;
   LineStack lineStack;
 };
