@@ -1,6 +1,6 @@
 // -*- c++ -*-
 
-// $Id: tool.h,v 1.12 2000/08/06 10:25:10 bieker Exp $
+// $Id: tool.h,v 1.14 2001/11/03 14:22:04 andreas Exp $
 
 #ifndef TOOL_H
 #define TOOL_H
@@ -13,7 +13,6 @@
 #include <qbrush.h>
 #include <qwidget.h>
 #include <qpixmap.h>
-#include <qpixmap.h>
 #include "canvas.h"
 
 #define DEFAULT_RASTER_OP NotROP
@@ -59,18 +58,21 @@ public:
    * Make the tool inactive
    */
   void deactivate();
-  bool isActive();
+  bool isActive() const { return active; }
+
   void setLeftPen(QPen &p);
   void setLeftBrush(QBrush &b);
   void setRightPen(QPen &p);
   void setRightBrush(QBrush &b);
+
   QString tip() { return tooltip; };
   virtual QPixmap pixmap() const = 0;
 
-  /**
-   * Used by the properties dialog
-   */
-  int getPages();
+  bool isSpecial() const { return special; }
+  void setSpecial( bool s ) { special = s; }
+
+  /** Used by the properties dialog */
+  int getPages() const { return props; }
   QWidget *getCustomPage(QWidget *) { return 0; };
 
   // Event handlers (handle events on canvas)
@@ -119,10 +121,11 @@ protected:
   QPen rightpen;
   QBrush rightbrush;
 
-  /**
-   * Which pages are supported
-   */
+  /** Which pages are supported */
   unsigned int props;
+
+  /** If true the tool will not be listed in the tool menu etc. */
+  bool special;
 };
 
 QString
