@@ -26,12 +26,13 @@
 #include <klocale.h>
 #include <kmainwindow.h>
 #include <qwhatsthis.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <qpixmap.h>
 #include <qiconset.h>
 #include <knotifyclient.h>
 
 #include <qdialog.h>
+#include <qcursor.h>
 #include <qpainter.h>
 #include <qbitmap.h>
 
@@ -105,7 +106,9 @@ KLineal::KLineal(QWidget*parent,const char* name):KMainWindow(parent,name){
   mLabel = new QLabel(this);
   mLabel->setGeometry(0,height()-12,32,12);
   mLabel->setBackgroundColor(backgroundColor());
-  mLabel->setFont(QFont("Helvetica", 10));
+  QFont labelFont("Helvetica", 10);
+  labelFont.setPixelSize(10);
+  mLabel->setFont(labelFont);
   QWhatsThis::add(mLabel,
   	i18n(
   		"This is the current distance measured in pixels"
@@ -113,7 +116,9 @@ KLineal::KLineal(QWidget*parent,const char* name):KMainWindow(parent,name){
 	mColorLabel = new QLabel(this);
   mColorLabel->resize(45,12);
   mColorLabel->setBackgroundColor(backgroundColor());
-  mColorLabel->setFont(QFont("fixed", 10));
+  QFont colorFont("fixed", 10);
+  colorFont.setPixelSize(10);
+  mColorLabel->setFont(colorFont);
   mColorLabel->move(mLabel->pos() + QPoint(0, 20));
   QWhatsThis::add(mColorLabel,
   	i18n(
@@ -128,7 +133,8 @@ KLineal::KLineal(QWidget*parent,const char* name):KMainWindow(parent,name){
   mOrientation = South;
   setOrientation(South);
   setMediumLength();
-  mMenu = new KPopupMenu(i18n("K-Ruler"));
+  mMenu = new KPopupMenu();
+  mMenu->insertTitle(i18n("K-Ruler"));
   KPopupMenu *oriMenu = new KPopupMenu(this);
   oriMenu->insertItem(menuIcon("kruler-north"), i18n("North"), this, SLOT(setNorth()), Key_N);
   oriMenu->insertItem(menuIcon("kruler-east"), i18n("East"), this, SLOT(setEast()), Key_E);
@@ -256,10 +262,12 @@ void KLineal::reLength(int percentOfScreen) {
   if (percentOfScreen < 10) {
     return;
   }
-  mLongEdgeLen = QApplication::desktop()->width() * percentOfScreen / 100;
+  int scnum = QApplication::desktop()->screenNumber(this);
   if (mOrientation == North || mOrientation == South) {
+    mLongEdgeLen = QApplication::desktop()->screenGeometry(scnum).width() * percentOfScreen / 100;
     resize(mLongEdgeLen, height());
   } else {
+    mLongEdgeLen = QApplication::desktop()->screenGeometry(scnum).height() * percentOfScreen / 100;
     resize(width(), mLongEdgeLen);
   }
   if (x()+width() < 10) {
@@ -513,7 +521,9 @@ void KLineal::mouseReleaseEvent(QMouseEvent * /*inEvent*/) {
 */
 void KLineal::drawScale(QPainter &painter) {
   painter.setPen(black);
-  painter.setFont(QFont("Helvetica", 8));
+  QFont scaleFont("Helvetica", 8);
+  scaleFont.setPixelSize(8);
+  painter.setFont(scaleFont);
   QFontMetrics metrics = painter.fontMetrics();
   int longCoo;
   int longLen;
