@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: kuickdata.cpp,v 1.2 2002/02/10 15:53:51 gassauer Exp $
+** $Id: kuickdata.cpp,v 1.2.2.1 2002/04/23 19:32:43 mm Exp $
 **
 ** KuickData, a class containing/loading/saving  all preferences of KuickShow
 **
@@ -20,7 +20,7 @@
 
 KuickData::KuickData()
 {
-  fileFilter  = "*.jpeg *.jpg *.gif *.xpm *.ppm *.pgm *.png *.bmp *.psd *.eim *.tiff *.xcf";// *.mng";
+  fileFilter  = "*.jpeg *.jpg *.gif *.xpm *.ppm *.pgm *.pbm *.pnm *.png *.bmp *.psd *.eim *.tiff *.xcf";// *.mng";
   slideDelay       = 3000;
   preloadImage     = true;
 
