@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: kuickshow.cpp,v 1.22 2002/03/23 12:47:35 pfeiffer Exp $
+** $Id: kuickshow.cpp,v 1.22.2.2 2002/04/19 00:30:45 pfeiffer Exp $
 **
 ** KuickShow - a fast and comfortable image viewer based on Rasterman's Imlib
 **
@@ -200,6 +200,12 @@ void KuickShow::initGUI( const KURL& startDir )
     coll->action("home")->plug( tBar );
     coll->action("reload")->plug( tBar );
 
+    tBar->insertSeparator();
+    
+    coll->action( "short view" )->plug( tBar );
+    coll->action( "detailed view" )->plug( tBar );
+    coll->action( "preview")->plug( tBar );
+
     tBar->insertSeparator();
     configure->plug( tBar );
     slide->plug( tBar );
@@ -532,9 +538,9 @@ bool KuickShow::eventFilter( QObject *o, QEvent *e )
 		// browser the initial current-item and wait for it to tell us
 		// when it's ready. Then we will replay this KeyEvent.
 		fileWidget->setInitialItem( fi.fileName() );
+		delayedRepeatEvent( m_viewer, k );
 		connect( fileWidget, SIGNAL( finished() ),
 			 SLOT( slotReplayEvent() ));
-		delayedRepeatEvent( m_viewer, k );
 		return true;
 	    }
 
@@ -801,6 +807,15 @@ void KuickShow::slotReplayEvent()
 
     eventFilter( e->viewer, e->event );
     delete e;
+    
+    // ### WORKAROUND for QIconView bug in Qt <= 3.0.3 at least
+    if ( fileWidget && fileWidget->view() ) {
+        QWidget *widget = fileWidget->view()->widget();
+        if ( widget->inherits( "QIconView" ) || widget->child(0, "QIconView" ) ){
+            fileWidget->setSorting( fileWidget->sorting() );
+        }
+    }
+    // --------------------------------------------------------------
 }
 
 void KuickShow::slotReplayAdvance()
@@ -814,6 +829,15 @@ void KuickShow::slotReplayAdvance()
     DelayedRepeatEvent *e = m_delayedRepeatItem;
     m_delayedRepeatItem = 0L; // otherwise, eventFilter aborts
 
+    // ### WORKAROUND for QIconView bug in Qt <= 3.0.3 at least
+    if ( fileWidget && fileWidget->view() ) {
+        QWidget *widget = fileWidget->view()->widget();
+        if ( widget->inherits( "QIconView" ) || widget->child(0, "QIconView" ) ){
+            fileWidget->setSorting( fileWidget->sorting() );
+        }
+    }
+    // --------------------------------------------------------------
+
     slotAdvanceImage( e->viewer, e->steps );
     delete e;
 }
