@@ -1,13 +1,13 @@
 /*
 * colour.cpp -- Implementation of class ColourFilter.
 * Author:  Sirtaj Singh Kang <taj@kde.org>
-* Version:  $Id: colour.cpp,v 1.14 2001/01/10 20:45:21 mkretz Exp $
+* Version:  $Id: colour.cpp,v 1.15 2001/10/10 17:57:48 mueller Exp $
 * Generated:  Tue Sep 22 02:26:05 EST 1998
 */
 
 #include <qcolor.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kdebug.h>
 
