@@ -26,7 +26,7 @@ class InfoWin : public InfoWin_Base
 {
   Q_OBJECT
 public:
-  InfoWin( QWidget* parent = 0, const char* name = "Info Window", WFlags fl = WType_TopLevel | WStyle_Dialog );
+  InfoWin( QWidget* parent = 0, const char* name = "Info Window", WFlags fl = Qt::WType_TopLevel | Qt::WType_Dialog );
   ~InfoWin();
 
   void setDimensions( int, int );
