@@ -21,8 +21,6 @@
 
 #include <kparts/browserextension.h>
 
-#include <kparts/factory.h>
-
 #include "canvas.h"
 
 namespace KIO { class Job; class SimpleJob; }
@@ -31,29 +29,14 @@ class KInstance;
 class KAction;
 class KViewKonqExtension;
 class KTempFile;
-
-class KViewFactory : public KParts::Factory
-{
-  Q_OBJECT
-public:
-  KViewFactory();
-  virtual ~KViewFactory();
-
-  virtual KParts::Part *createPart( QWidget *parentWidget, const char *widgetName, QObject *parent, const char *name, const char *classname, const QStringList &args );
-
-
-  static KInstance *instance();
-
-private:
-  static KInstance *s_instance;
-};
-
+class KAboutData;
 
 class KViewPart: public KParts::ReadOnlyPart
 {
   Q_OBJECT
 public:
-  KViewPart( QWidget *parentWidget, const char *widgetName, QObject *parent, const char *name );
+  KViewPart( QWidget *parentWidget, const char *widgetName, 
+             QObject *parent, const char *name, const QStringList & );
   virtual ~KViewPart();
 
   virtual bool openURL( const KURL &url );
@@ -61,6 +44,8 @@ public:
 
   KImageCanvas *canvas() const { return m_pCanvas; }
 
+  static KAboutData *createAboutData();
+
 protected:
   virtual bool openFile() { return false; } // not called
 
