@@ -24,7 +24,7 @@
 #include <qlineedit.h>
 #include <qradiobutton.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <knumvalidator.h>
 #include <kcolorbutton.h>
 #include <kdebug.h>
@@ -33,7 +33,7 @@ KViewConfDialog::KViewConfDialog( QWidget* parent,  const char* name, bool modal
     : KViewConfDialog_Base( parent, name, modal, fl )
 {
   kapp->setTopWidget( this );
-  m_interval->setValidator( new KIntValidator( m_interval ) );
+  m_interval->setValidator( new KIntValidator( 1,9999,m_interval ) );
   m_interval->setFocus();
 }
 
@@ -97,6 +97,7 @@ void KViewConfDialog::slotDefault()
   m_resizeWindow->setChecked( true );
   m_resizeImage->setChecked( true );
   m_colorButton->setColor( QColor( 0, 0, 0 ) );
+  m_fastscaling->setChecked( true);
 }
 
 #include "kviewconfdialog.moc"
