@@ -1,13 +1,15 @@
 /*
  * viewer.cpp -- Implementation of class KImageViewer.
  * Author:       Sirtaj Singh Kang
- * Version:      $Id: viewer.cpp,v 1.79 2001/06/15 15:13:32 mkretz Exp $
+ * Version:      $Id: viewer.cpp,v 1.95 2002/03/24 15:25:41 pfeiffer Exp $
  * Generated:    Wed Oct 15 11:37:16 EST 1997
  */
 
 #include <assert.h>
 #include <unistd.h>
 
+#include <qclipboard.h>
+#include <qcursor.h>
 #include <qpopupmenu.h>
 #include <qstrlist.h>
 #include <qaccel.h>
@@ -17,8 +19,9 @@
 #include <qcolor.h>
 #include <qfileinfo.h>
 #include <qdatetime.h>
+#include <qstyle.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kmainwindow.h>
 #include <kmenubar.h>
 #include <ktoolbar.h>
@@ -39,6 +42,7 @@
 #include <ktempfile.h>
 #include <kwinmodule.h> //to get the workarea Rect
 
+
 #include "viewer.h"
 #include "canvas.h"
 #include "version.h"
@@ -49,6 +53,8 @@
 #include "imagelistdialog.h"
 #include "kviewconfdialog.h"
 #include "infowin.h"
+#include <kstatusbar.h>
+#include <kiconloader.h>
 
 enum {
   ID_FILENAME,
@@ -61,6 +67,7 @@ const int MessageDelay = 3000;
 
 KImageViewer::KImageViewer( KFilterList* filters )
   : KMainWindow( 0 ),
+  scanDialog( 0 ),
   _imageLoaded( false ),
   m_bFullScreen( false ),
   m_recent( 0 ),
@@ -93,7 +100,7 @@ KImageViewer::KImageViewer( KFilterList* filters )
   resize( 250, 150 );
 
   // Caption
-  setCaption( i18n( "no image loaded" ) );
+  setCaption( i18n( "No Image Loaded" ) );
 
   // make a StatusBar
   statusBar()->insertItem( i18n( "no image loaded" ), ID_FILENAME, 1 );
@@ -168,7 +175,7 @@ void KImageViewer::slot_fileClose()
     _canvas->clear();
     menuEntriesEnabled( false );
     _imageLoaded = false;
-    setCaption( i18n( "no image loaded" ) );
+    setCaption( i18n( "No Image Loaded" ) );
     statusBar()->changeItem( i18n( "no image loaded" ), ID_FILENAME );
     statusBar()->changeItem( " 0x0 ", ID_SIZE );
     m_filename = "";
@@ -535,9 +542,11 @@ void KImageViewer::slot_loadFile( const QString & file, const KURL &_url )
 	rzWinToImg();
       else if( m_resizeMode & ( ResizeImage | ResizeWindow ) )
       {
-	slot_zoom100();
-	if( ( _canvas->contentsWidth() > _canvas->visibleWidth() ) || ( _canvas->contentsHeight() > _canvas->visibleHeight() ) )
-	  slot_zoomMaxpect();
+        QSize ws = m_kwinmodule->workArea().size();
+        if ((size.width() > ws.width()) || (size.height() > ws.height()))
+          slot_zoomMaxpect();
+	else
+          slot_zoom100();
       }
     }
 
@@ -800,12 +809,15 @@ void KImageViewer::slot_cut()
 
 void KImageViewer::slot_copy()
 {
-  // TODO: stub
+  QClipboard *cb = QApplication::clipboard();
+  cb->setImage( _canvas->getImage());
 }
 
 void KImageViewer::slot_paste()
 {
-  // TODO: stub
+  // Get QImage from clipboard and create a new image.
+  QClipboard *cb = QApplication::clipboard();
+  addImage( cb->image() );
 }
 
 void KImageViewer::slot_confAccels()
@@ -831,10 +843,6 @@ void KImageViewer::slot_prefs()
   }
 }
 
-void KImageViewer::resizeEvent( QResizeEvent * )
-{
-}
-
 void KImageViewer::slot_toolBarMoved()
 {
   if( m_resizeMode == ResizeImage )
@@ -881,18 +889,25 @@ void KImageViewer::rzWinToImg()
 
   int widthmax  = workarea.width()  - x - frameright;
   int heightmax = workarea.height() - y - framebottom;
+
+  bool position = false;
   
   if( width > widthmax )
   {
     x = QMAX( x - frame.x(), x - ( width - widthmax ) ) + leftpanel;
-    widthmax  = desktop.width()  - x - frameright - rightpanel;
+    width  = desktop.width()  - x - frameright - rightpanel;
+    position = true;
   }
   if( height > heightmax )
   {
     y = QMAX( y - frame.y(), y - ( height - heightmax ) ) + toppanel;
-    heightmax = desktop.height() - y - framebottom - bottompanel;
+    height = desktop.height() - y - framebottom - bottompanel;
+    position = true;
   }
-  setGeometry( x, y, QMIN( width, widthmax ), QMIN( height, heightmax ) );
+  if (position)
+    setGeometry( x, y, width, height );
+  else
+    resize(width, height);
 }
 
 void KImageViewer::setupActions( KFilterList *filters )
@@ -909,6 +924,10 @@ void KImageViewer::setupActions( KFilterList *filters )
   KStdAction::quit( this, SLOT( slot_quitApp() ), actionCollection() );
 
   //setup the edit menu
+//  KStdAction::cut(this, SLOT( slot_cut()), actionCollection());
+  KStdAction::copy(this, SLOT( slot_copy()), actionCollection());
+  KStdAction::paste(this, SLOT( slot_paste()), actionCollection());
+
   m_editCrop = new KAction( i18n( "&Crop" ), Key_C, this, SLOT( slot_cropImage() ), actionCollection(), "crop" );
   m_editCrop->setEnabled( false );
   m_editReset = KStdAction::undo( this, SLOT( slot_reset() ), actionCollection() );
@@ -934,7 +953,7 @@ void KImageViewer::setupActions( KFilterList *filters )
   m_viewZoomOut = KStdAction::zoomOut( this, SLOT( slot_zoomOut10() ), actionCollection() );
   m_viewDouble = new KAction( i18n( "&Double size" ), Key_BracketRight, this, SLOT( slot_zoomIn200() ), actionCollection(), "double_size" );
   m_viewHalf = new KAction( i18n( "&Half size" ), Key_BracketLeft, this, SLOT( slot_zoomOut50() ), actionCollection(), "half_size" );
-  m_viewFullScreen = new KAction( i18n( "&Fullscreen Mode" ), "window_fullscreen", CTRL+SHIFT+Key_F, this, SLOT( slot_fullScreen() ), actionCollection(), "fullscreen" );
+  m_viewFullScreen = new KAction( i18n( "Fullscreen &Mode" ), "window_fullscreen", CTRL+SHIFT+Key_F, this, SLOT( slot_fullScreen() ), actionCollection(), "fullscreen" );
   m_imageSlide = new KAction( i18n( "&Slideshow On/Off" ), Key_S, _imageList, SLOT( slot_toggleSlideshow() ), actionCollection(), "slideshow" );
 
   // Go menu
@@ -964,9 +983,9 @@ void KImageViewer::setupActions( KFilterList *filters )
 
   // flip menu
   m_flipMenu = new KActionMenu( i18n( "&Flip" ), actionCollection(), "flip" );
-  m_flipV = new KAction( i18n( "&vertical" ), Key_V, this, SLOT( slot_flipVertical() ), actionCollection(), "flip_vertical" );
+  m_flipV = new KAction( i18n( "&Vertical" ), Key_V, this, SLOT( slot_flipVertical() ), actionCollection(), "flip_vertical" );
   m_flipMenu->insert( m_flipV );
-  m_flipH = new KAction( i18n( "&horizontal" ), Key_H, this, SLOT( slot_flipHorizontal() ), actionCollection(), "flip_horizontal" );
+  m_flipH = new KAction( i18n( "&Horizontal" ), Key_H, this, SLOT( slot_flipHorizontal() ), actionCollection(), "flip_horizontal" );
   m_flipMenu->insert( m_flipH );
 
   //setup the desktop menu
@@ -980,6 +999,8 @@ void KImageViewer::setupActions( KFilterList *filters )
 
   // image menu
   m_imageInfo = new KAction( i18n( "&Info" ), Key_I, this, SLOT( slot_showImageInfo() ), actionCollection(), "info" );
+  (void) new KAction(i18n("&Scan Image..."), BarIcon("scanner"), 0, this, SLOT(slotScan()),
+			actionCollection(), "scan_image");
 
   // setup Settings menu
   m_settingsShowMenuBar = KStdAction::showMenubar( this, SLOT( slot_toggleMenuBar() ), actionCollection() );
@@ -989,7 +1010,6 @@ void KImageViewer::setupActions( KFilterList *filters )
   KStdAction::preferences( this, SLOT( slot_prefs() ), actionCollection() );
   KStdAction::keyBindings( this, SLOT( slot_confAccels() ), actionCollection() );
   KStdAction::configureToolbars( this, SLOT( slot_editToolbars() ), actionCollection() );
-
   m_editCrop->setEnabled( false );
   connect( _canvas, SIGNAL( selected( bool ) ), m_editCrop, SLOT( setEnabled( bool ) ) );
 
@@ -1090,8 +1110,19 @@ void KImageViewer::slot_zoom50()
 void KImageViewer::slot_zoom100()
 {
   _mat.reset();
-  _mat.scale( 1, 1 );
-  _canvas->transformImage( _mat );
+  if( m_resizeMode & FastScale )
+  {
+    _mat.scale( 1, 1 );
+    _canvas->transformImage( _mat );
+  }
+  else
+  {
+    int width  = _canvas->originalSize().width();
+    int height = _canvas->originalSize().height();
+    sizeCorrection( width, height );
+    resize( width, height );
+    _canvas->slot_maxToWin();
+  }
   rzWinToImg();
 }
 
@@ -1172,7 +1203,7 @@ void KImageViewer::sizeCorrection( int & width, int & height, bool add )
     switch( toolBar()->barPos() )
     {
       case KToolBar::Top:
-	height += ( kapp->style().guiStyle() == WindowsStyle ? 1 : 0 ) * ( add ? 1 : -1 );
+	/* height += ( kapp->style().guiStyle() == WindowsStyle ? 1 : 0 ) * ( add ? 1 : -1 ); */
       case KToolBar::Bottom:
         height += ( m_toolbarorientationchanged ? toolBar()->width() - 1 : toolBar()->height() ) * ( add ? 1 : -1 );
         break;
@@ -1181,15 +1212,46 @@ void KImageViewer::sizeCorrection( int & width, int & height, bool add )
         width += ( m_toolbarorientationchanged ? toolBar()->height() + 1 : toolBar()->width() ) * ( add ? 1 : -1 );
         break;
       case KToolBar::Flat:
-        height += kapp->style().toolBarHandleExtent() + ( kapp->style().guiStyle() == WindowsStyle ? 2 : 0 ) * ( add ? 1 : -1 );
+        height += kapp->style().pixelMetric( QStyle::PM_DockWindowHandleExtent ) /*+ ( kapp->style().guiStyle() == WindowsStyle ? 2 : 0 ) * ( add ? 1 : -1 ) */;
         break;
     }
   }
-  if( menuBar()->isVisibleTo( this ) )
+  if( menuBar()->isVisibleTo( this ) && ( ! menuBar()->isTopLevelMenu() ) )
     height += menuBar()->heightForWidth( width ) * ( add ? 1 : -1 );
   if( statusBar()->isVisibleTo( this ) )
     height += statusBar()->height() * ( add ? 1 : -1 );
 }
 
+void KImageViewer::slotScan()
+{
+    if ( !scanDialog )
+    {
+	scanDialog = KScanDialog::getScanDialog();
+	if ( scanDialog )
+	{
+	    scanDialog->setMinimumSize(300, 300);
+
+	    connect(scanDialog, SIGNAL(finalImage(const QImage &, int)),
+		    this, SLOT(slotShowImage(const QImage &)));
+	}
+	else
+        {
+	    KMessageBox::sorry(0L, i18n("No Scan-Service available"),
+			       i18n("You do not seem to have SANE support or your scanner "
+			       "is not attached properly. Please check these items before "
+			       "scanning again."));
+	    kdDebug(31000) << "*** No Scan-service available, aborting!" << endl;
+	    return;
+	}
+    }
+
+    if ( scanDialog->setup() )
+        scanDialog->show();
+}
+
+void KImageViewer::slotShowImage(const QImage &img)
+{
+    addImage( img );
+}
 #include "viewer.moc"
 
