@@ -1,8 +1,11 @@
-#include <qobject.h>
+#include <stdlib.h>
+
+#include <qfileinfo.h>
 #include <qlayout.h>
 #include <qscrollview.h>
 #include <qscrollbar.h>
 #include <qtimer.h>
+#include <qpainter.h>
 #include <qprinter.h>
 #include <qprintdialog.h>
 #include <qobjectlist.h>
@@ -13,11 +16,12 @@
 #include <kinstance.h>
 #include <klocale.h>
 #include <kiconloader.h>
+#include <kio/job.h>
 #include <kaction.h>
 #include <kstdaction.h>
 #include <kmessagebox.h>
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kconfig.h>
 
 #include <stdlib.h>
@@ -57,13 +61,12 @@ KViewPartFactory::~KViewPartFactory()
 }
 
 
-KParts::Part *KViewPartFactory::createPart( QWidget *parentWidget, const char *widgetName, QObject *parent, const char *name, const char *classname, const QStringList &args )
+KParts::Part *KViewPartFactory::createPartObject( QWidget *parentWidget, const char *widgetName, QObject *parent, const char *name, const char *, const QStringList &args )
 {
   QString partname = "";
   if (args.count() >= 1)
     partname = args[0];
   KParts::Part *obj = new KViewPart(partname, parentWidget, widgetName, parent, name);
-  emit objectCreated(obj);
   return obj;
 }
 
@@ -94,6 +97,10 @@ KViewPart::KViewPart(QString partname, QWidget *parentWidget, const char *widget
 {
   setInstance(KViewPartFactory::instance());
 
+  watch = KDirWatch::self();
+  connect(watch, SIGNAL(dirty(const QString&)), this, SLOT(fileChanged(const QString&)));
+  watch->startScan();
+
   mainWidget = new QWidget(parentWidget, widgetName);
   mainWidget->setFocusPolicy(QWidget::StrongFocus);
   setWidget(mainWidget);
@@ -119,41 +126,29 @@ KViewPart::KViewPart(QString partname, QWidget *parentWidget, const char *widget
 
   // Try to load
   KLibFactory *factory = KLibLoader::self()->factory(QString("libk%1").arg(_partname).utf8());
-  if (factory)
-  {
+  if (factory) {
     multiPage = (KMultiPage*) factory->create(mainWidget, QString("k%1").arg(_partname).utf8(), "KPart");
+  } else {
+    KMessageBox::error(mainWidget, QString("No libk%1 found !").arg(_partname));
+    ::exit(-1);
   }
-  else
-    {
-      KMessageBox::error(mainWidget, QString("No libk%1 found !").arg(_partname));
-      ::exit(-1);
-    }
-
   hbox->addWidget(multiPage->widget());
 
-
   // connect to the multi page view
   connect(multiPage, SIGNAL(numberOfPages(int)), this, SLOT(numberOfPages(int)));
   connect(multiPage, SIGNAL(pageInfo(int, int)), this, SLOT(pageInfo(int, int)) );
-  connect(multiPage->scrollView(), SIGNAL(contentsMoving(int,int)),
-	  this, SLOT(contentsMoving(int,int)));
+  connect(multiPage->scrollView(), SIGNAL(contentsMoving(int,int)), this, SLOT(contentsMoving(int,int)));
   multiPage->scrollView()->installEventFilter(this);
-
-  connect( multiPage, SIGNAL( started( KIO::Job * ) ),
-	   this, SIGNAL( started( KIO::Job * ) ) );
-  connect( multiPage, SIGNAL( completed() ),
-	   this, SIGNAL( completed() ) );
-  connect( multiPage, SIGNAL( canceled( const QString & ) ),
-	   this, SIGNAL( canceled( const QString & ) ) );
+  connect( multiPage, SIGNAL( started( KIO::Job * ) ), this, SIGNAL( started( KIO::Job * ) ) );
+  connect( multiPage, SIGNAL( completed() ), this, SIGNAL( completed() ) );
+  connect( multiPage, SIGNAL( canceled( const QString & ) ), this, SIGNAL( canceled( const QString & ) ) );
   connect( multiPage, SIGNAL( previewChanged(bool)), this, SLOT(updatePreview(bool)));
-
-
+  connect( multiPage, SIGNAL( setStatusBarText( const QString& ) ), this, SIGNAL( setStatusBarText( const QString& ) ) );
 
   // settings menu
   showmarklist = new KToggleAction (i18n("Show &Page List"), 0, this, SLOT(slotShowMarkList()), actionCollection(), "show_page_list");
   showPreview = new KToggleAction (i18n("Show P&review"), 0, this, SLOT(slotPreview()), actionCollection(), "show_preview");
-  watchAct = new KToggleAction(i18n("&Watch file"), 0, 0, 0, actionCollection(), "watch_file");
-
+  watchAct = new KToggleAction(i18n("&Watch File"), 0, 0, 0, actionCollection(), "watch_file");
 
   // view menu
   QStringList orientations;
@@ -187,59 +182,30 @@ KViewPart::KViewPart(QString partname, QWidget *parentWidget, const char *widget
   endAct = KStdAction::lastPage(this, SLOT(lastPage()), actionCollection());
   gotoAct = KStdAction::gotoPage(this, SLOT(goToPage()), actionCollection());
 
-  readDownAct = new KAction(i18n("Read down document"), "next",
+  readDownAct = new KAction(i18n("Read down Document"), "next",
 			    Key_Space, this, SLOT(readDown() ),
 			    actionCollection(), "go_read_down");
-  /*
-    markAct =
-      new KAction(i18n("Toggle this page mark"),
-		  QIconSet(BarIcon("flag", KGVFactory::instance())),
-		  Key_Enter, w, SLOT(markPage() ), actionCollection(), "markPage");
-    */
-
-    //TODO -- disable entry if there aren't any page names
-    //Settings menu
-    /*
-    fancyAct =
-      new KToggleAction (i18n("Show Page Names"),
-			 0, this, SLOT(slotFancy()), actionCollection(),
-			 "fancy_page_labels");
-    fancyAct->setChecked (w->areFancyPageLabelsEnabled ());
-    */
 
   printAction = KStdAction::print(this, SLOT(slotPrint()), actionCollection());
-  saveAction = KStdAction::saveAs(this, SLOT(slotSave()), actionCollection());
+  saveAction = KStdAction::saveAs(multiPage, SLOT(slotSave()), actionCollection());
 
   // keyboard accelerators
   accel = new KAccel(mainWidget);
-  accel->insertItem(i18n("Scroll Up"), "Scroll Up", "Up");
-  accel->insertItem(i18n("Scroll Down"), "Scroll Down", "Down");
-  accel->insertItem(i18n("Scroll Left"), "Scroll Left", "Left");
-  accel->insertItem(i18n("Scroll Right"), "Scroll Right", "Right");
+  accel->insert(I18N_NOOP("Scroll Up"), Key_Up, this, SLOT(scrollUp()));
+  accel->insert(I18N_NOOP("Scroll Down"), Key_Down, this, SLOT(scrollDown()));
+  accel->insert(I18N_NOOP("Scroll Left"), Key_Left, this, SLOT(scrollLeft()));
+  accel->insert(I18N_NOOP("Scroll Right"), Key_Right, this, SLOT(scrollRight()));
 
-  accel->insertItem(i18n("Scroll Up Page"), "Scroll Up Page", "Shift+Up");
-  accel->insertItem(i18n("Scroll Down Page"), "Scroll Down Page", "Shift+Down");
-  accel->insertItem(i18n("Scroll Left Page"), "Scroll Left Page", "Shift+Left");
-  accel->insertItem(i18n("Scroll Right Page"), "Scroll Right Page", "Shift+Right");
+  accel->insert(I18N_NOOP("Scroll Up Page"), SHIFT+Key_Up, this, SLOT(scrollUpPage()));
+  accel->insert(I18N_NOOP("Scroll Down Page"), SHIFT+Key_Down, this, SLOT(scrollDownPage()));
+  accel->insert(I18N_NOOP("Scroll Left Page"), SHIFT+Key_Left, this, SLOT(scrollLeftPage()));
+  accel->insert(I18N_NOOP("Scroll Right Page"), SHIFT+Key_Right, this, SLOT(scrollRightPage()));
 
   accel->readSettings();
 
-  accel->connectItem("Scroll Up", this, SLOT(scrollUp()));
-  accel->connectItem("Scroll Down", this, SLOT(scrollDown()));
-  accel->connectItem("Scroll Left", this, SLOT(scrollLeft()));
-  accel->connectItem("Scroll Right", this, SLOT(scrollRight()));
-
-  accel->connectItem("Scroll Up Page", this, SLOT(scrollUpPage()));
-  accel->connectItem("Scroll Down Page", this, SLOT(scrollDownPage()));
-  accel->connectItem("Scroll Left Page", this, SLOT(scrollLeftPage()));
-  accel->connectItem("Scroll Right Page", this, SLOT(scrollRightPage()));
-
   setXMLFile("kviewerpart.rc");
 
 
-  connect(&watch, SIGNAL(dirty(const QString&)), this, SLOT(fileChanged(const QString&)));
-
-
   m_extension = new KViewPartExtension(this);
 
   // create the goto dialog
@@ -264,11 +230,10 @@ KViewPart::KViewPart(QString partname, QWidget *parentWidget, const char *widget
   vp->installEventFilter(this);
   // we also have to set an filter on the child
   // TODO: solve this more elegant
-  if (vp->children())
-    {
-      QWidget *w = (QWidget*)((QObjectList*)(vp->children()))->first();
-      w->installEventFilter(this);
-    }
+  if (vp->children()) {
+    QWidget *w = (QWidget*)((QObjectList*)(vp->children()))->first();
+    w->installEventFilter(this);
+  }
 }
 
 
@@ -284,8 +249,6 @@ void KViewPart::fillPaperSizes()
   _paperSizes.clear();
 
   QString fname = KGlobal::dirs()->findResource("data", "kviewshell/paper-formats");
-  kdDebug() << "Paper: " << fname << endl;
-
   KConfig paper(fname, true);
   paper.setGroup("Paper");
   unsigned int count = paper.readNumEntry("Count");
@@ -313,7 +276,7 @@ void KViewPart::fillPaperSizes()
 void KViewPart::setPaperSize(double w, double h)
 {
   // reflect in scrollbox
-  scrollBox->setMinimumHeight((int) 75.0*h/w);
+  scrollBox->setMinimumHeight( int(75.0*h/w+0.5));
 
   // forward
   multiPage->setPaperSize(w, h);
@@ -330,42 +293,66 @@ QStringList KViewPart::fileFormats()
 
 void KViewPart::slotShowMarkList()
 {
-  if (showmarklist->isChecked())
-    {
-      markList->show();
-      scrollBox->show();
-    }
-  else
-    {
-      markList->hide();
-      scrollBox->hide();
-    }
+  if (showmarklist->isChecked()) {
+    markList->show();
+    scrollBox->show();
+  } else {
+    markList->hide();
+    scrollBox->hide();
+  }
 }
 
 bool KViewPart::openFile()
 {
-  // Note: KDirWatch is able to watch files, as well.
-  // Hope this stays that way...
-  watch.addDir(m_file);
-  watch.startScan();
-
-  return true;
-}
-
-bool KViewPart::openURL(const KURL &url)
-{
-  // This will download the file, if necessary and call
-  // KViewPart::openFile() which sete the file watching mechanism off.
-  KParts::ReadOnlyPart::openURL(url);
-
-  // Now call the openURL-method of the multipage and give it a URL
-  // pointing to the downloaded file.
   KURL tmpFileURL;
+
+  // We try to be error-tolerant about filenames. If the user calls us
+  // with something like "test", and we are using the DVI-part, we'll
+  // also look for "testdvi" and "test.dvi".
+  QFileInfo fi(m_file);
+  if (fi.exists() == false) {
+    // First produce a list of possible endings we try to append to
+    // the filename. We decompose the format strings like "*.dvi
+    // *.DVI|DVI File" coming from the multipage part.
+    QStringList endings;
+    QStringList formats = multiPage->fileFormats();
+    for ( QStringList::Iterator it = formats.begin(); it != formats.end(); ++it ) {
+      QString ending = (*it).simplifyWhiteSpace();
+      int bar = ending.find('|');
+      if (bar != -1)
+	ending = ending.left(bar);
+
+      QStringList localendings = QStringList::split(" ",ending);
+      for ( QStringList::Iterator it2 = localendings.begin(); it2 != localendings.end(); ++it2 )
+	endings += (*it2).mid(2); // remove "*." of "*.dvi"
+    }
+
+    // Now try to append the endings with and without dots, and see if
+    // that gives a file.
+    for ( QStringList::Iterator it = endings.begin(); it != endings.end(); ++it ) {
+      fi.setFile(m_file+(*it));
+      if (fi.exists() == true) {
+	m_file = m_file+(*it);
+	break;
+      } else {
+	fi.setFile(m_file+"."+(*it));
+	if (fi.exists() == true) {
+	  m_file = m_file+"."+(*it);
+	  break;
+	}
+      }
+    }
+    m_url.setPath(QFileInfo(m_file).absFilePath());
+  }
+
+  // Now call the openURL-method of the multipage and give it an URL
+  // pointing to the downloaded file.
   tmpFileURL.setPath(m_file);
+  emit setWindowCaption( tmpFileURL.prettyURL() ); // set Window caption WITHOUT the reference part!
+  tmpFileURL.setRef(m_url.ref()); // Pass the reference part of the URL through to the multipage
   bool r = multiPage->openURL(tmpFileURL);
 
   updateScrollBox();
-  checkActions();
   markList->select(0);
 
   if (r) {
@@ -373,15 +360,21 @@ bool KViewPart::openURL(const KURL &url)
     QScrollView *sv = multiPage->scrollView();
     if (sv)
       sv->center(sv->contentsWidth()/2, 0);
+
+    // Add the file to the watchlist
+    watch->addFile( m_file );
+  } else {
+    m_url = "";
+    emit setWindowCaption( "" );
   }
+
+  checkActions();
   return r;
 }
 
 
 void KViewPart::fileChanged(const QString &file)
 {
-  kdDebug() << "File changed: " << file << endl;
-
   if (file == m_file && watchAct->isChecked())
     multiPage->reload();
 }
@@ -389,8 +382,8 @@ void KViewPart::fileChanged(const QString &file)
 
 bool KViewPart::closeURL()
 {
-  watch.removeDir(m_file);
-  watch.stopScan();
+  if( watch && !m_file.isEmpty() )
+    watch->removeFile( m_file );
 
   KParts::ReadOnlyPart::closeURL();
 
@@ -420,27 +413,29 @@ void KViewPart::slotMedia(int id)
 {
   double w=0.0, h=0.0;
 
-  switch (id)
-    {
-    case 0:
-      w = 29.7; h = 42.0;
-      break;
-    case 1:
-      w = 21.0; h = 29.7;
-      break;
-    case 2:
-      w = 14.85; h = 21.0;
-      break;
-    case 3:
-      w = 21.59; h = 27.94;
-      break;
-    case 4:
-      w = 21.50; h = 35.56;
-      break;
-    case 5:
-      // TODO : paper size dialog!
-      break;
-    }
+  // This hard-coded list is really a shame. We should use a more
+  // flexible global list here. If you modify here, don't forget to
+  // modify the hard-coded list in readSettings() as well!
+  switch (id) {
+  case 0:
+    w = 29.7; h = 42.0;
+    break;
+  case 1:
+    w = 21.0; h = 29.7;
+    break;
+  case 2:
+    w = 14.85; h = 21.0;
+    break;
+  case 3:
+    w = 21.59; h = 27.94;
+    break;
+  case 4:
+    w = 21.50; h = 35.56;
+    break;
+  case 5:
+    // TODO : paper size dialog!
+    break;
+  }
 
   if (w != 0.0 && h != 0.0)
     if (orientation->currentItem() == 0)
@@ -458,16 +453,13 @@ void KViewPart::numberOfPages(int nr)
 
   markList->clear();
 
-  if (nr == 0)
-    {
-      // clear scroll box
-      scrollBox->setPageSize(QSize(0,0));
-      scrollBox->setViewSize(QSize(0,0));
-
-      _currentPage = 0;
-
-      return;
-    }
+  if (nr == 0) {
+    // clear scroll box
+    scrollBox->setPageSize(QSize(0,0));
+    scrollBox->setViewSize(QSize(0,0));
+    _currentPage = 0;
+    return;
+  }
 
   for (int i=0; i<nr; i++)
     markList->insertItem(QString("%1").arg(i+1), i);
@@ -503,11 +495,11 @@ void KViewPart::pageInfo(int numpages, int currentpage)
 
 void KViewPart::setPage(int page)
 {
+  _currentPage = page;
+
   if (!multiPage->gotoPage(page))
     return;
 
-  _currentPage = page;
-
   markList->select(page);
 
   checkActions();
@@ -550,7 +542,7 @@ void KViewPart::goToPage()
 void KViewPart::slotGotoDialog(const QString &page)
 {
   bool ok;
-  int p = page.toInt(&ok);
+  int p = page.toInt(&ok)-1;
   if (ok && p >= 0 && p < pages())
     setPage(p);
 }
@@ -558,6 +550,12 @@ void KViewPart::slotGotoDialog(const QString &page)
 
 void KViewPart::pageSelected(int nr)
 {
+  // Check beforehand if there is really a new page to display. Often
+  // an item in the markList is selected AFTER the page has been set,
+  // and then we don't want the mulipage to render twice.
+  if (_currentPage == nr)
+    return;
+
   if ((nr >= 0) && (nr<pages()))
     setPage(nr);
 }
@@ -616,7 +614,17 @@ void KViewPart::fitSize()
 
 void KViewPart::fitToHeight()
 {
-  _zoom = multiPage->zoomForHeight(pageSize().height());
+  // See below, in the documentation of the method "fitToWidth" for an
+  // explanation of the complicated calculation we are doing here.
+  int targetHeight  = multiPage->scrollView()->viewportSize(0,0).height()-1;
+  int targetWidth;
+  if (orientation->currentItem() == 0)
+    targetWidth = (int)(targetHeight * _paperWidth/_paperHeight +0.5);
+  else
+    targetWidth = (int)(targetHeight * _paperHeight/_paperWidth +0.5);
+  targetHeight = multiPage->scrollView()->viewportSize(targetWidth, targetHeight).height()-1;
+  
+  _zoom = multiPage->zoomForHeight(targetHeight);
   if (_zoom < minZoom/1000.0)
     _zoom = minZoom/1000.0;
   if (_zoom > maxZoom/1000.0)
@@ -628,7 +636,30 @@ void KViewPart::fitToHeight()
 
 void KViewPart::fitToWidth()
 {
-  _zoom = multiPage->zoomForWidth(pageSize().width());
+  // There is a slight complication here... if we just take the width
+  // of the viewport and scale the contents by a factor x so that it
+  // fits the viewport exactly, then, depending on choosen papersize
+  // (landscape, etc.), the contents may be higher than the viewport
+  // and the QScrollview may or may not insert a scrollbar at the
+  // right. If the scrollbar appears, then the usable width of the
+  // viewport becomes smaller, and scaling by x does not really fit
+  // the (now smaller page) anymore.
+
+  // Caluculate the width and heigt of the view, disregarding the
+  // possible complications with scrollbars, e.g. assuming the maximal
+  // space is available.
+  int targetWidth  = multiPage->scrollView()->viewportSize(0,0).width()-1;
+  int targetHeight;
+  if (orientation->currentItem() == 0)
+    targetHeight = (int)(targetWidth * _paperHeight/_paperWidth +0.5);
+  else
+    targetHeight = (int)(targetWidth * _paperWidth/_paperHeight +0.5);
+  // Think again, this time use only the area which is really
+  // acessible (which, in case that targetWidth targetHeight don't fit
+  // the viewport, is really smaller because of the scrollbars).
+  targetWidth      = multiPage->scrollView()->viewportSize(targetWidth, targetHeight).width()-1;
+
+  _zoom = multiPage->zoomForWidth(targetWidth);
   if (_zoom < minZoom/1000.0)
     _zoom = minZoom/1000.0;
   if (_zoom > maxZoom/1000.0)
@@ -663,6 +694,7 @@ void KViewPart::checkActions()
   startAct->setEnabled(doc && page() > 0);
   endAct->setEnabled(doc && page()+1 < pages());
   gotoAct->setEnabled(doc && pages()>1);
+  readDownAct->setEnabled(doc);
 
   zoomInAct->setEnabled(doc);
   zoomOutAct->setEnabled(doc);
@@ -700,24 +732,25 @@ bool KViewPart::eventFilter(QObject *obj, QEvent *ev)
   if (obj == this && ev->type() == QEvent::Resize)
     QTimer::singleShot(0, this, SLOT(updateScrollBox()));
 
-  if (obj != this)
-    {
-      if (ev->type() == QEvent::MouseButtonPress)
-	{
-	  mousePos = ((QMouseEvent*)ev)->globalPos();
-	  multiPage->scrollView()->setCursor(Qt::sizeAllCursor);
-	}
-      if (ev->type() == QEvent::MouseMove)
-	{
-	  QPoint newPos = ((QMouseEvent*)ev)->globalPos();
-	  QPoint delta = mousePos - newPos;
-	  multiPage->scrollView()->scrollBy(delta.x(), delta.y());
-	  mousePos = newPos;
-	}	
-      if (ev->type() == QEvent::MouseButtonRelease)
-	multiPage->scrollView()->setCursor(Qt::arrowCursor);
+  if (obj != this) {
+    if (ev->type() == QEvent::MouseButtonPress) {
+      mousePos = ((QMouseEvent*)ev)->globalPos();
+      multiPage->scrollView()->setCursor(Qt::sizeAllCursor);
     }
 
+    if (ev->type() == QEvent::MouseMove) {
+      QPoint newPos = ((QMouseEvent*)ev)->globalPos();
+      if ( ((QMouseEvent*)ev)->state() == LeftButton ) {
+	QPoint delta = mousePos - newPos;
+	multiPage->scrollView()->scrollBy(delta.x(), delta.y());
+      }
+      mousePos = newPos;
+    }
+    
+    if (ev->type() == QEvent::MouseButtonRelease)
+      multiPage->scrollView()->setCursor(Qt::arrowCursor);
+  }
+  
   return false;
 }
 
@@ -804,6 +837,12 @@ void KViewPart::scrollTo(int x, int y)
 
 void KViewPart::updatePreview(bool avail)
 {
+  if (_numberOfPages == 0)
+    emit setStatusBarText("");
+  else
+    emit setStatusBarText(QString(i18n("Page %1 of %2")).arg(_currentPage+1).arg(_numberOfPages));
+
+
   QPixmap pixmap(scrollBox->width(), scrollBox->height());
   QPainter p(&pixmap);
 
@@ -833,6 +872,7 @@ void KViewPart::slotPrint()
 }
 
 
+
 void KViewPart::readSettings()
 {
   KConfig *config = instance()->config();
@@ -848,6 +888,35 @@ void KViewPart::readSettings()
   if ( (_zoom < minZoom/1000.0) || (_zoom > maxZoom/1000.0))
     _zoom = 1.0;
   _zoom = multiPage->setZoom(_zoom);
+
+  // Read Paper Size and orientation
+  int orient = config->readNumEntry("Orientation", 0 );
+  orientation->setCurrentItem(orient);
+  double w = config->readDoubleNumEntry("PaperWidth", 21.0 );
+  double h = config->readDoubleNumEntry("PaperHeight", 29.7 );
+  if (orient == 0)
+    setPaperSize(w, h);
+  else
+    setPaperSize(h, w);
+
+  // Try the find the suitable paper size. This hard-coded list is
+  // really a shame. We should use a more flexible global list
+  // here. By the way, it is never a good idea to check if two floats
+  // are equal... here that is not a problem (yet) because we never do
+  // any calculation.
+  int mediaitem = 5; // Default: paper size if "other"
+  if ((w == 29.70) && (h == 42.00))
+    mediaitem = 0;
+  if ((w == 21.00) && (h == 29.70))
+    mediaitem = 1;
+  if ((w == 14.85) && (h == 21.00))
+    mediaitem = 2;
+  if ((w == 21.59) && (h == 27.94))
+    mediaitem = 3;
+  if ((w == 21.50) && (h == 35.56))
+    mediaitem = 4;
+  media->setCurrentItem(mediaitem);
+
 }
 
 
@@ -861,6 +930,10 @@ void KViewPart::writeSettings()
   config->writeEntry("WatchFile", watchAct->isChecked());
   config->writeEntry("ShowPreview", showPreview->isChecked());
   config->writeEntry("Zoom", _zoom);
+
+  config->writeEntry("Orientation", orientation->currentItem() );
+  config->writeEntry("PaperWidth",  _paperWidth );
+  config->writeEntry("PaperHeight", _paperHeight );
   config->sync();
 }
 
