@@ -2,7 +2,7 @@
 #define __KVIEWPART_H
 
 
-#include <qlist.h>
+#include <qptrlist.h>
 
 
 #include <kparts/part.h>
@@ -36,7 +36,7 @@ public:
   KViewPartFactory();
   virtual ~KViewPartFactory();
 
-  virtual KParts::Part *createPart( QWidget *parentWidget, const char *widgetName, QObject *parent, const char *name, const char *classname, const QStringList &args );
+  virtual KParts::Part *createPartObject( QWidget *parentWidget, const char *widgetName, QObject *parent, const char *name, const char *classname, const QStringList &args );
 
   static KInstance *instance();
 
@@ -72,8 +72,6 @@ public:
 
 
 public slots:
-
-  virtual bool openURL(const KURL &url);
   virtual bool closeURL();
 
   QStringList fileFormats();
@@ -134,7 +132,7 @@ protected:
 
   bool eventFilter(QObject *obj, QEvent *ev);
 
-  QList<PaperSize> _paperSizes;
+  QPtrList<PaperSize> _paperSizes;
   void fillPaperSizes();
 
   void setPaperSize(double w, double h);
@@ -154,7 +152,7 @@ private slots:
 
 private:
 
-  KDirWatch watch;
+  KDirWatch *watch;
 
   QString _partname;
 
@@ -193,10 +191,10 @@ private:
 
   GotoDialog *_gotoDialog;
 
+  // Paper size in centimeters
   double _paperWidth, _paperHeight;
 
   QPoint mousePos;
-
 };
 
 
@@ -214,5 +212,3 @@ public:
 
 
 #endif
-
-
