@@ -20,7 +20,7 @@
 #include <qdrawutil.h>
 #include <qtooltip.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kpopupmenu.h>
 #include <klocale.h>
 
@@ -29,7 +29,7 @@
 #define FLAG_WIDTH 20
 
 MarkListTable::MarkListTable( QWidget * parent , const char * name )
-        : QTableView( parent, name ), sel(-1), drag(-1), items()
+        : QtTableView( parent, name ), sel(-1), drag(-1), items()
 {
         setFrameStyle( Panel | Sunken );
         setTableFlags( Tbl_autoVScrollBar | Tbl_snapToVGrid | 
@@ -37,24 +37,25 @@ MarkListTable::MarkListTable( QWidget * parent , const char * name )
         setLineWidth( 1 );
         setCellHeight( fontMetrics().lineSpacing()+4 );
         setNumCols( 2 );
-        
+
         pup = new QPopupMenu(0, "pup");
-        pup->insertItem( i18n("Mark current page"), this, SLOT(markSelected()) );
-        pup->insertItem( i18n("Mark all pages"), this, SLOT(markAll()) );
-        pup->insertItem( i18n("Mark even pages"), this, SLOT(markEven()) );
-        pup->insertItem( i18n("Mark odd pages"), this, SLOT(markOdd()) );
-        pup->insertItem( i18n("Toggle page marks"), this, SLOT(toggleMarks()) );
-        pup->insertItem( i18n("Remove page marks"), this, SLOT(removeMarks()) );
+        pup->insertItem( i18n("Mark Current Page"), this, SLOT(markSelected()) );
+        pup->insertItem( i18n("Mark All Pages"), this, SLOT(markAll()) );
+        pup->insertItem( i18n("Mark Even Pages"), this, SLOT(markEven()) );
+        pup->insertItem( i18n("Mark Odd Pages"), this, SLOT(markOdd()) );
+        pup->insertItem( i18n("Toggle Page Marks"), this, SLOT(toggleMarks()) );
+        pup->insertItem( i18n("Remove Page Marks"), this, SLOT(removeMarks()) );
         
-        selectColor = QColor( black );
-        selectTextColor = QColor( white );
+        QColorGroup cg = QApplication::palette().active();
+        selectColor = QColor( cg.highlight() );
+        selectTextColor = QColor( cg.highlightedText() );
         
         initPixmaps();
 }
 
 void MarkListTable::initPixmaps() 
 {
-        QColorGroup cg = QApplication::palette().normal();
+        QColorGroup cg = QApplication::palette().active();
   
         int w = cellWidth(0);
         int h = cellHeight(0);
@@ -107,14 +108,14 @@ MarkListTable::insertItem ( const QString & text, int index,
 
 void MarkListTable::setAutoUpdate ( bool enable)
 {
-	QTableView::setAutoUpdate( enable );
+	QtTableView::setAutoUpdate( enable );
 	if (enable) 
           repaint();
 }
 
 void MarkListTable::clear()
 {
-	QColorGroup cg = QApplication::palette().normal();
+	QColorGroup cg = QApplication::palette().active();
 	if( backgroundColor() != cg.base() )
 		setBackgroundColor(cg.base());
 	items.clear();
@@ -134,7 +135,7 @@ int MarkListTable::cellWidth( int col )
 void
 MarkListTable::paintCell( QPainter *p, int row, int col)
 {
-  QColorGroup cg = QApplication::palette().normal();
+  QColorGroup cg = QApplication::palette().active();
   
   if ( col == 0  ) 
     {
@@ -442,7 +443,7 @@ QStringList MarkList::markList()
 }
 
 QPixmap MarkList::flagPixmap() {
-	QColorGroup cg = QApplication::palette().normal();
+	QColorGroup cg = QApplication::palette().active();
 
 	QPixmap pm;
 	pm.resize(16,16);
