@@ -10,7 +10,7 @@
 #ifndef MARKLIST_H
 #define MARKLIST_H
 
-#include <qtableview.h>
+#include <qttableview.h>
 #include "kpopupmenu.h"
 #include <qstringlist.h>
 #include <qlabel.h>
@@ -35,7 +35,7 @@ public:
 	QString _tip;
 }; 
 
-class MarkListTable: public QTableView
+class MarkListTable: public QtTableView
 {
 	Q_OBJECT
 
@@ -86,7 +86,7 @@ private:
 	int	sel;
 	QPopupMenu* pup;
 	int	drag;
-	QList<MarkListTableItem> items;
+	QPtrList<MarkListTableItem> items;
         QPixmap *flagPixmap, *bulletPixmap;
 };
 
