@@ -5,7 +5,7 @@
     copyright            : (C) 1999 by Klaas Freitag
     email                : freitag@suse.de
 
-    $Id: img_canvas.cpp,v 1.10 2001/07/26 07:13:45 freitag Exp $
+    $Id: img_canvas.cpp,v 1.16 2002/02/28 16:44:19 freitag Exp $
  ***************************************************************************/
 
 /***************************************************************************
@@ -33,18 +33,20 @@
 #include <qapplication.h>
 #include <iostream.h>
 
-#include <qfiledlg.h>
+#include <qfiledialog.h>
 #include <qstring.h>
-#include <qmsgbox.h>
+#include <qmessagebox.h>
 #include <qscrollview.h>
-#include <qpopupmenu.h>
+#include <kpopupmenu.h>
 #include <qlabel.h>
 #include <qdict.h>
 #include <klocale.h>
+#include <kstyle.h>
+#include <kapplication.h>
 
 #include <kpixmapio.h>
 #include <kdebug.h>
-
+#include <kiconloader.h>
 #include <kcmenumngr.h>
 
 #define __IMG_CANVAS_CPP__
@@ -67,7 +69,8 @@ inline void debug_rect( const char *name, QRect *r )
 ImageCanvas::ImageCanvas(QWidget *parent,
 			 const QImage *start_image,
 			 const char *name 	):
-  QScrollView( parent, name )
+   QScrollView( parent, name ),
+   m_contextMenu(0)
 
 {
   scale_factor     = 100; // means orignal size
@@ -97,7 +100,8 @@ ImageCanvas::ImageCanvas(QWidget *parent,
     img_size = size();
   }
 
-  createContextMenu();
+  
+  // createContextMenu();
   update_scaled_pixmap();
 
   // timer-Start and stop
@@ -116,10 +120,12 @@ ImageCanvas::ImageCanvas(QWidget *parent,
 
 ImageCanvas::~ImageCanvas()
 {
+   kdDebug(28000) << "Destructor of ImageCanvas" << endl;
     noRectSlot();
     if( selected ) delete selected;
+    selected = 0;
     if( pmScaled ) delete pmScaled;
-    if( contextMenu ) delete contextMenu;
+    pmScaled = 0;
 }
 
 void ImageCanvas::deleteView( QImage *delimage )
@@ -192,53 +198,45 @@ void ImageCanvas::newImage( QImage *new_image )
    kdDebug(29000) << "repaint ok" << endl;
 }
 
-
-void ImageCanvas::createContextMenu( void )
-{
-
-   contextMenu = new QPopupMenu();
-
-   contextMenu->insertItem( i18n("fit to width"),  ID_FIT_WIDTH );
-   contextMenu->insertItem( i18n("fit to height"), ID_FIT_HEIGHT );
-   contextMenu->insertItem( i18n("set zoom..."),   ID_POP_ZOOM );
-   contextMenu->insertItem( i18n("original size"), ID_ORIG_SIZE );
-   contextMenu->setCheckable( true );
-   connect( contextMenu, SIGNAL( activated(int)), this, SLOT(handle_popup(int)));
-
-   KContextMenuManager::insert( this, contextMenu );
-
-}
-
 QSize ImageCanvas::sizeHint() const
 {
    return( QSize( 2, 2 ));
 }
 
-
-void ImageCanvas::showContextMenu( QPoint p )
+void ImageCanvas::enableContextMenu( bool wantContextMenu )
 {
-    if( ! contextMenu ) return;
+   if( wantContextMenu )
+   {
+      if( ! m_contextMenu )
+      {
+	 m_contextMenu = new KPopupMenu( this );
 
-    QSize is;
-    if( image ) is = image->size();
-
-    if( is.width() > 0 && is.height() > 0 )
-    {
-        // debug ( "opening popup!" );
-        contextMenu->move( p );
-        contextMenu->show();
-    }
+	 KContextMenuManager::insert( this, m_contextMenu );
+      }
+   }
+   else
+   {
+      /* remove all items */
+      if( m_contextMenu ) m_contextMenu->clear();
+      /* contextMenu is not deleted because there is no way to remove
+       * it from the contextMenuManager
+       */
+   }
+   
 }
 
-
 void ImageCanvas::handle_popup( int item )
 {
    if( item < ID_POP_ZOOM || item > ID_ORIG_SIZE ) return;
    double scale;
-
+   
    if( ! image ) return;
    ImgScaleDialog *zoomDia  = 0;
-
+   const int sbWidth = kapp->style().pixelMetric( QStyle::PM_ScrollBarExtent );
+   const QSize noSBSize = size(); /* Size of complete scrollbar */
+   
+   kdDebug(29000)<< "Size of viewport: " << noSBSize.width() << " and " << noSBSize.height() << endl;
+   
    switch( item )
    {
       case ID_POP_ZOOM:
@@ -252,8 +250,8 @@ void ImageCanvas::handle_popup( int item )
               repaint( true);
           }
           delete zoomDia;
+	  zoomDia = 0;
 	  QApplication::restoreOverrideCursor();
-	 // emit( scalingRequested());
 
 	 break;
       case ID_ORIG_SIZE:
@@ -263,28 +261,37 @@ void ImageCanvas::handle_popup( int item )
       break;
       case ID_FIT_WIDTH:
 	 QApplication::setOverrideCursor(waitCursor);
-	 scale = 100*(width()-2) / image->width();
+	 
+	 scale = 100.0 * noSBSize.width() / image->width();
 	 kdDebug(29000) << "Scale ist " << scale << endl;
-	 if( (scale/100 * image->height()) > height() )
+
+	 if( (scale/100.0 * image->height()) >= noSBSize.height() )
 	 {
 	    /* substract for scrollbar */
-	    scale = 100*(width() -25)/image->width();
+	    scale = 100 * (noSBSize.width() - sbWidth) / image->width();
+	    kdDebug(29000) << "FIT WIDTH scrollbar to substract: " << sbWidth << endl;
 	 }
-	 setScaleFactor( scale );
+
+	 kdDebug(29000)<< "Sale Factor double: " << scale << endl;
+	 setScaleFactor( static_cast<int>(scale-0.5) );
 	 repaint( true );
 	 QApplication::restoreOverrideCursor();
       break;
       case ID_FIT_HEIGHT:
 	 QApplication::setOverrideCursor(waitCursor);
 
-	 scale = 100*(height()-2) / image->height();
+	 scale = 100.0 * noSBSize.height() / image->height();
 	 kdDebug(29000) << "Scale ist " << scale << endl;
-	 if( (scale/100 * image->width()) > width() )
+
+	 if( (scale/100.0 * image->width()) >= width() )
 	 {
 	    /* substract for scrollbar */
-	    scale = 100*(height() -25)/image->height();
+	    kdDebug(29000) << "FIT HEIGHT scrollbar to substract: " << sbWidth << endl;
+	    scale = 100.0*(noSBSize.height() -sbWidth) / image->height();
 	 }
-	 setScaleFactor( scale );
+
+	 kdDebug(29000)<< "Sale Factor double: " << scale << endl;
+	 setScaleFactor( static_cast<int>(scale-0.5) );
 	 repaint( true );
 	 QApplication::restoreOverrideCursor();
 	 break;
@@ -297,6 +304,7 @@ void ImageCanvas::handle_popup( int item )
 
 }
 
+
 /**
  *   Returns the selected rect in tenth of percent, not in absolute
  *   sizes, eg. 500 means 50.0 % of original width/height.
@@ -408,12 +416,12 @@ void ImageCanvas::newRectSlot( QRect newSel )
    {
        int h = image->width();
        //kdDebug(29000) << "ImageCanvas got selection Rect: W=" << newSel.width() << ", H=" << newSel.height() << endl;
-       to_map.setWidth(h * newSel.width() / 1000.0);
-       to_map.setX( h * newSel.x() / 1000.0 );
+       to_map.setWidth(static_cast<int>(h * newSel.width() / 1000.0));
+       to_map.setX( static_cast<int>(h * newSel.x() / 1000.0 ));
 
        h = image->height();
-       to_map.setHeight( h * newSel.height() / 1000.0 );
-       to_map.setY( h * newSel.y() / 1000.0 );
+       to_map.setHeight( static_cast<int>(h * newSel.height() / 1000.0 ));
+       to_map.setY( static_cast<int>(h * newSel.y() / 1000.0 ));
 
        *selected = scale_matrix.map( to_map );
        emit( newRect( sel() ));
@@ -469,10 +477,7 @@ void ImageCanvas::viewportMousePressEvent(QMouseEvent *ev)
 		}
 		drawAreaBorder(&p);
          }
-         else printf("MouseReleaseEvent() missed\n");
     }
-    else if( ev->button() == RightButton )
-          showContextMenu( mapToGlobal(QPoint( ev->x(), ev->y())));
 }
 
 
@@ -499,7 +504,7 @@ void ImageCanvas::viewportMouseReleaseEvent(QMouseEvent *ev)
     drawAreaBorder(&p);
     emit newRect( sel() );
     emit newRect( );
-  } else printf("mousePressEvent() missed\n");
+  } 
 }
 
 
@@ -634,9 +639,9 @@ void ImageCanvas::viewportMouseMoveEvent(QMouseEvent *ev)
 
 void ImageCanvas::setScaleFactor( int i )
 {
-  // debug( "Setting Scalefactor to %d", i );
-  scale_factor = i;
-  update_scaled_pixmap();
+   kdDebug(29000) <<  "Setting Scalefactor to " << i << endl;
+   scale_factor = i;
+   update_scaled_pixmap();
 }
 
 
@@ -705,8 +710,8 @@ void ImageCanvas::update_scaled_pixmap( void )
    * with redrawing of new images.
    */
   resizeContents( 0,0 );
-  resizeContents( image->width() * used_xscaler,
-                  image->height() * used_yscaler );
+  resizeContents( static_cast<int>(image->width() * used_xscaler),
+                  static_cast<int>(image->height() * used_yscaler ) );
 
 }
 
