@@ -8,6 +8,7 @@
 class ScanParams;
 class KScanDevice;
 class Previewer;
+class QSplitter;
 
 class ScanDialog : public KScanDialog
 {
@@ -21,12 +22,20 @@ public:
 
 private:
    void createOptionsTab( void );
-      
-private slots:
+
+protected slots:
    void slotFinalImage(QImage *);
    void slotNewPreview( QImage *);
+   void slotScanStart( );
+   void slotScanFinished( KScanStat status );
+   void slotAcquireStart();
+   
+private slots:
    void slotAskOnStartToggle(bool state);
    void slotNetworkToggle( bool state);
+
+
+   void slotClose();
 private:
    ScanParams   *m_scanParams;
    KScanDevice  *m_device;
@@ -35,6 +44,7 @@ private:
    bool         good_scan_connect;
    QCheckBox    *cb_askOnStart;
    QCheckBox    *cb_network;
+   QSplitter    *splitter;
    class ScanDialogPrivate;
    ScanDialogPrivate *d;
 };
