@@ -28,14 +28,16 @@
 #include <qmessagebox.h>
 #include <qlayout.h>
 #include <qdict.h>
-#include <qfile.h>
 #include <qprogressdialog.h>
+#include <qscrollview.h>
+#include <qsizepolicy.h>
 
 #include <kfiledialog.h>
 #include <klocale.h>
 #include <kdebug.h>
 #include <kbuttonbox.h>
 #include <kiconloader.h>
+#include <kled.h>
 #include <kseparator.h>
 
 #include "scanparams.h"
@@ -48,8 +50,8 @@
 
 
 ScanParams::ScanParams( QWidget *parent, const char *name )
-    : QVBox( parent, name ),
-      progressDialog( 0L )
+   : QVBox( parent, name ),
+     m_firstGTEdit( true )
 {
    /* first some initialisation and debug messages */
     sane_device = 0; virt_filename = 0;
@@ -58,7 +60,8 @@ ScanParams::ScanParams( QWidget *parent, const char *name )
     pb_source_sel = 0;
     bg_virt_scan_mode = 0;
     xy_resolution_bind = 0;
-
+    progressDialog = 0;
+    
     /* Preload icons */
     pixMiniFloppy = SmallIcon( "3floppy_unmount" );
 
@@ -67,6 +70,8 @@ ScanParams::ScanParams( QWidget *parent, const char *name )
     pixLineArt = SmallIcon( "palette_lineart" );
     pixHalftone = SmallIcon( "palette_halftone" );
 
+    /* intialise the default last save warnings */
+    startupOptset = 0;
     
 }
 
@@ -104,14 +109,20 @@ bool ScanParams::connectDevice( KScanDevice *newScanDevice )
 
    /* A top layout box */
    // QVBoxLayout *top = new QVBoxLayout(this, 6);
-   QString cap = i18n("<B>Scanner Settings</B><BR>");
+   QHBox *hb = new QHBox( this );
+   QString cap = i18n("<B>Scanner Settings</B> ");
    cap += sane_device->getScannerName();
+   (void ) new QLabel( cap, hb ); 
+   m_led = new KLed( hb );
+   m_led->setState( KLed::Off );
+   m_led->setSizePolicy( QSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed ));
+   
 
-   (void) new QLabel( cap, this );
-
-   KSeparator* niceline = new KSeparator( KSeparator::HLine, this);
+   (void) new KSeparator( KSeparator::HLine, this);
 
    /* Now create Widgets for the important scan settings */
+   QScrollView *sv = 0;
+   
    if( sane_device->optionExists( SANE_NAME_FILE ) )
    {
       /* Its a virtual scanner */
@@ -120,12 +131,25 @@ bool ScanParams::connectDevice( KScanDevice *newScanDevice )
 
    } else {
       scan_mode = ID_SCAN;
-      scannerParams( );
+
+      /* load the startup scanoptions */
+      startupOptset = new KScanOptSet( DEFAULT_OPTIONSET );
+      Q_CHECK_PTR( startupOptset );
+      
+      if( !startupOptset->load( "Startup" ) )
+      { 
+	 kdDebug(29000) << "Could not load Startup-Options" << endl;
+	 delete startupOptset;
+	 startupOptset = 0;
+      }
+      sv = scannerParams( );
    }
+
    /* Reload all options to care for inactive options */
    sane_device->slReloadAll();
 
    /* Create a Start-Scan-Button */
+   (void) new KSeparator( KSeparator::HLine, this);
    KButtonBox *kbb = new KButtonBox( this );
    QPushButton* pb = kbb->addButton( i18n( "&Final Scan" ));
    connect( pb, SIGNAL(clicked()), this, SLOT(slStartScan()) );
@@ -136,7 +160,7 @@ bool ScanParams::connectDevice( KScanDevice *newScanDevice )
 
    /* Initialise the progress dialog */
    progressDialog = new QProgressDialog( i18n("Scanning in progress"),
-					 i18n("Stop"), 1000, this,
+					 i18n("Stop"), 100, 0L,
 					 "SCAN_PROGRESS", true, 0  );
    progressDialog->setAutoClose( true );
    progressDialog->setAutoReset( true );
@@ -149,30 +173,89 @@ bool ScanParams::connectDevice( KScanDevice *newScanDevice )
    connect( progressDialog, SIGNAL( cancelled() ), sane_device,
 	    SLOT( slStopScanning() ) );
 
+#if 0  /* hmm. Calculating the min height does not work in that way */
+   int min1 = toplabel->minimumHeight();
+   int min2 = kbb->minimumHeight();
+   int min3 = sv->minimumHeight();
+   kdDebug(29000) << "Three minheights: " << min1 << " " << min2 <<" " << min3 << endl;
+   int minH = toplabel->minimumHeight() + kbb->minimumHeight() + sv->minimumHeight();
+   kdDebug(29000) << "setting minimumHeight for scanparams: " << minH << endl;
+#endif
+   int minH = 220;
+   if( sv )
+      setMinimumHeight( minH );
+   
    return( true );
 }
 
+
 ScanParams::~ScanParams()
 {
-    delete progressDialog;
+   if( sane_device )
+   {
+      kdDebug(29000) << "Saving scan settings" << endl;
+      sane_device->slSaveScanConfigSet( DEFAULT_OPTIONSET, i18n("the default startup setup") );
+   }
+   
+   if( startupOptset )
+   {
+      delete startupOptset;
+      startupOptset = 0;
+   }
+
+   if( progressDialog )
+   {
+      delete( progressDialog );
+      progressDialog = 0;
+   }
 }
 
-void ScanParams::scannerParams( void ) // QVBoxLayout *top )
+void ScanParams::initialise( KScanOption *so )
+{
+   if( ! so ) return;
+   bool initialised = false;
+   
+   if( startupOptset )
+   {
+      QCString name = so->getName();
+      if( ! name.isEmpty() ){
+	 QCString val = startupOptset->getValue( name );
+	 kdDebug( 29000) << "Initialising <" << name << "> with value <" << val << ">" << endl;
+	 so->set( val );
+	 sane_device->apply(so);
+	 initialised = true;
+      }
+   }
+
+   if( ! initialised )
+   {
+      
+   }
+}
+
+QScrollView *ScanParams::scannerParams( )
 {
    KScanOption *so = 0;
 
    /* Its a real scanner */
    /* Mode setting */
-   QHBox *hb = new QHBox(this);
+   QScrollView *sv = new QScrollView( this );
+   sv->setHScrollBarMode( QScrollView::AlwaysOff );
+   sv->setResizePolicy( QScrollView::AutoOneFit );
+   QVBox *pbox = new QVBox( sv->viewport());
+   sv->setFrameStyle( QFrame::NoFrame );
 
+   sv->addChild( pbox );
+   
+   QHBox *hb = new QHBox(pbox);
+   
    so = sane_device->getGuiElement( SANE_NAME_SCAN_MODE, hb );
    if ( so )
    {
       /* Pretty-Pixmap */
 
       KScanCombo *cb = (KScanCombo*) so->widget();
-
-
+      Q_CHECK_PTR(cb);
       cb->slSetIcon( pixLineArt, i18n("Lineart") );
       cb->slSetIcon( pixLineArt, i18n("Binary" ));
       cb->slSetIcon( pixGray, i18n("Gray") );
@@ -182,47 +265,67 @@ void ScanParams::scannerParams( void ) // QVBoxLayout *top )
       hb->setMargin( KDialog::marginHint() );
       hb->setSpacing( KDialog::spacingHint());
 
+      hb->setStretchFactor( cb, 5 );
+      
       connect( so, SIGNAL(guiChange(KScanOption*)),
 	       this, SLOT(slReloadAllGui( KScanOption* )));
+
+      initialise( so );
    }
 
    /* Add a button for Source-Selection */
    if( sane_device->optionExists( SANE_NAME_SCAN_SOURCE ))
    {
       KScanOption source( SANE_NAME_SCAN_SOURCE );
+      QStrList l = source.getList();
 
-      pb_source_sel = new QPushButton( i18n("Source..."), hb );
-      connect( pb_source_sel, SIGNAL(clicked()), this, SLOT(slSourceSelect()));
+      QWidget *spacer = new QWidget(hb);
+      hb->setStretchFactor( spacer, 1 );
+      kdDebug(29000) << "Source list size: " << l.count() << endl;
+      
+      if( l.count() > 1 )
+      {
+	 pb_source_sel = new QPushButton( i18n("Source..."), hb );
+	 connect( pb_source_sel, SIGNAL(clicked()), this, SLOT(slSourceSelect()));
+	 initialise( &source );
+	 hb->setStretchFactor( pb_source_sel, 3 );
 
 #if 0 /* Testing !! TODO: remove */
       if( ! source.active() ) {
 	 pb_source_sel->setEnabled( false );
       }
 #endif
+      }
+      else
+      {
+	 kdDebug(29000) << "only one scan-source, do not show button." << endl;
+      }
    }
 
    /* Resolution Setting -> X-Resolution Setting */
-   so = sane_device->getGuiElement( SANE_NAME_SCAN_X_RESOLUTION, this,
+   so = sane_device->getGuiElement( SANE_NAME_SCAN_X_RESOLUTION, pbox /* this */,
 				    i18n("Resolution (dpi):").local8Bit() );
+   
    if ( so )
    {
-      int x_y_res = 100;
-
-      so->set( x_y_res );
-      sane_device->apply( so );
+      initialise( so );
+      int x_y_res;
+      so->get( &x_y_res );
       so->slRedrawWidget( so );
 
+      /* connect to slot that passes the resolution to the previewer */
+      connect( so, SIGNAL(guiChange(KScanOption*)),
+	       this, SLOT( slNewXResolution(KScanOption*)));
+      
       connect( so, SIGNAL(guiChange(KScanOption*)),
 	       this, SLOT(slReloadAllGui( KScanOption* )));
 
       xy_resolution_bind =
-	 sane_device->getGuiElement(SANE_NAME_RESOLUTION_BIND, this,
+	 sane_device->getGuiElement(SANE_NAME_RESOLUTION_BIND, pbox,
 				    i18n( "Bind X- and Y-Resolution" ).local8Bit() );
       if( xy_resolution_bind  )
       {
-	 xy_resolution_bind->set( 0 );
-	 sane_device->apply( xy_resolution_bind );
-
+	 initialise( xy_resolution_bind );
 	 xy_resolution_bind->slRedrawWidget( xy_resolution_bind );
 	 /* Connect to Gui-change-Slot */
 	 connect( xy_resolution_bind, SIGNAL(guiChange(KScanOption*)),
@@ -230,23 +333,25 @@ void ScanParams::scannerParams( void ) // QVBoxLayout *top )
       }
 
       /* Resolution Setting -> Y-Resolution Setting */
-      so = sane_device->getGuiElement( SANE_NAME_SCAN_Y_RESOLUTION, this );
+      so = sane_device->getGuiElement( SANE_NAME_SCAN_Y_RESOLUTION, pbox);
+      int y_res = x_y_res;
       if ( so )
       {
-	 so->set( x_y_res );
-	 sane_device->apply( so );
+	 initialise( so );
+	 so->get( &y_res );
 	 so->slRedrawWidget( so );
       }
+
+      emit( scanResolutionChanged( x_y_res, y_res ));
    }
    else
    {
       /* If the SCAN_X_RES does not exists, perhaps just SCAN_RES does */
-      so = sane_device->getGuiElement( SANE_NAME_SCAN_RESOLUTION, this,
+      so = sane_device->getGuiElement( SANE_NAME_SCAN_RESOLUTION, pbox,
 				       i18n("Resolution (dpi):") );
       if( so )
       {
-	 so->set( 100 );
-	 sane_device->apply( so );
+	 initialise( so );
       }
       else
       {
@@ -255,43 +360,52 @@ void ScanParams::scannerParams( void ) // QVBoxLayout *top )
    }
 
    /* Insert another beautification line */
-   KSeparator *niceline = new KSeparator( KSeparator::HLine, this);
+   (void) new KSeparator( KSeparator::HLine, pbox );
 
    /* Speed-Setting - show only if active */
    KScanOption kso_speed( SANE_NAME_SCAN_SPEED );
    if( kso_speed.valid() && kso_speed.softwareSetable() && kso_speed.active())
    {
-      so = sane_device->getGuiElement( SANE_NAME_SCAN_SPEED, this );
+      so = sane_device->getGuiElement( SANE_NAME_SCAN_SPEED, pbox);
+      initialise( so );
    }
 
    /* Threshold-Setting */
-   so = sane_device->getGuiElement( SANE_NAME_THRESHOLD, this );
+   so = sane_device->getGuiElement( SANE_NAME_THRESHOLD, pbox );
    if( so )
    {
-      so->set(50);
+      initialise( so );
    }
 
    /* Brightness-Setting */
-   so = sane_device->getGuiElement( SANE_NAME_BRIGHTNESS, this );
-
+   so = sane_device->getGuiElement( SANE_NAME_BRIGHTNESS, pbox );
+   if( so ) initialise( so );
+   
    /* Contrast-Setting */
-   so = sane_device->getGuiElement( SANE_NAME_CONTRAST, this );
+   so = sane_device->getGuiElement( SANE_NAME_CONTRAST, pbox );
+   if( so ) initialise( so );
    /* Custom Gamma */
 
    /* Sharpness */
-   so = sane_device->getGuiElement( "sharpness", this );
+   so = sane_device->getGuiElement( "sharpness", pbox );
+   if( so ) initialise( so );
+
+
    /* The gamma table can be used - add  a button for editing */
    if( sane_device->optionExists( SANE_NAME_CUSTOM_GAMMA ) )
    {
-      QHBox *hb1 = new QHBox(this);
+      QHBox *hb1 = new QHBox(pbox);
 
       so = sane_device->getGuiElement( SANE_NAME_CUSTOM_GAMMA, hb1);
 
       if( so )
       {
 	 int isOn;
+	 initialise( so );
 	 so->get( &isOn );
 	
+	 (void) new QWidget( hb1 ); /* dummy widget to eat space */
+	 
 	 kdDebug(29000) << "Custom Gamma Table is <" << (isOn ? "on" : "off") << ">" << endl;
 	
 	 /* Connect a signal to refresh activity of the gamma tables */
@@ -299,7 +413,7 @@ void ScanParams::scannerParams( void ) // QVBoxLayout *top )
 	       this, SLOT(slReloadAllGui( KScanOption* )));
 
 	 pb_edit_gtable = new QPushButton( i18n("Edit..."), hb1 );
-	 CHECK_PTR(pb_edit_gtable);
+	 Q_CHECK_PTR(pb_edit_gtable);
 	 pb_edit_gtable->setEnabled( isOn );
 	
 	 connect( pb_edit_gtable, SIGNAL( clicked () ),
@@ -314,19 +428,25 @@ void ScanParams::scannerParams( void ) // QVBoxLayout *top )
    /* my Epson Perfection backends offer a list of user defined gamma values */
    
    /* Insert another beautification line */
-   KSeparator *niceline1 = new KSeparator( KSeparator::HLine, this);
-
-   so = sane_device->getGuiElement( SANE_NAME_NEGATIVE, this  );
+   if( sane_device->optionExists( SANE_NAME_GRAY_PREVIEW ) ||
+       sane_device->optionExists( SANE_NAME_NEGATIVE ) )
+   {
+      (void) new KSeparator( KSeparator::HLine, pbox );
+   }
 
+   so = sane_device->getGuiElement( SANE_NAME_NEGATIVE, pbox  );
+   initialise( so );
+   
    /* PREVIEW-Switch */
    kdDebug(29000) << "Try to get Gray-Preview" << endl;
    if( sane_device->optionExists( SANE_NAME_GRAY_PREVIEW ))
    {
-     so = sane_device->getGuiElement( SANE_NAME_GRAY_PREVIEW, this );
+     so = sane_device->getGuiElement( SANE_NAME_GRAY_PREVIEW, pbox );
+     initialise( so );
      cb_gray_preview = (QCheckBox*) so->widget();
      QToolTip::add( cb_gray_preview, i18n("Acquire a gray preview even in color mode (faster)") );
    }
-   // top->addStretch( 1 );
+   return( sv );
 }
 
 
@@ -419,7 +539,7 @@ void ScanParams::slFileSelect( void )
    if( scan_mode == ID_QT_IMGIO )
    {
       QStrList filterList = QImage::inputFormats();
-      filter = i18n( "*.*|All Files (*.*)");
+      filter = i18n( "*|All Files (*)");
       for( QCString fi_item = filterList.first(); !fi_item.isEmpty();
 	   fi_item = filterList.next() )
       {
@@ -435,7 +555,7 @@ void ScanParams::slFileSelect( void )
 
 
    KFileDialog fd(last_virt_scan_path.path(), filter, this, "FileDialog",true);
-   fd.setCaption( i18n("Select the inputfile") );
+   fd.setCaption( i18n("Select the Input File") );
    /* Read the filename and remind it */
    QString fileName;
    if ( fd.exec() == QDialog::Accepted ) {
@@ -625,7 +745,7 @@ void ScanParams::slStartScan( void )
 	    // stat = performADFScan();
 	 }
       } else {
-	 kdDebug(29000) << "Reading dir by Qt-internal imagereading file " << q << endl;
+	 kdDebug(29000) << "Reading 	dir by Qt-internal imagereading file " << q << endl;
 	 sane_device->acquire( q );
       }
    }
@@ -638,18 +758,53 @@ void ScanParams::slEditCustGamma( void )
     kdDebug(29000) << "Called EditCustGamma ;)" << endl;
     KGammaTable old_gt;
 
-    KScanOption redGt( SANE_NAME_GAMMA_VECTOR_R );
-    if( redGt.active()) kdDebug(29000) << "RED-GT is active now !" << endl;
-
-    KScanOption blueGt( SANE_NAME_GAMMA_VECTOR_B );
-    if( blueGt.active()) kdDebug(29000) << "blue-GT is active now !" << endl;
-
-    KScanOption greenGt( SANE_NAME_GAMMA_VECTOR_G );
-    if( greenGt.active()) kdDebug(29000) << "green-GT is active now !" << endl;
-
     KScanOption grayGt( SANE_NAME_GAMMA_VECTOR );
-    if( grayGt.active()) kdDebug(29000) << "Gray-GT is active now !" << endl;
-    grayGt.get( &old_gt );
+    KScanOption redGt( SANE_NAME_GAMMA_VECTOR_R );
+
+    /* Since gammatable options are not set in the default gui, it must be
+     * checked if it is the first edit. If it is, take from loaded default
+     * set if available there */
+    if( m_firstGTEdit && startupOptset )
+    {
+       m_firstGTEdit = false;
+       KScanOption *gt = startupOptset->get(SANE_NAME_GAMMA_VECTOR);
+       if( !gt )
+       {
+	  /* If it  not gray, it should be one color. */
+	  gt = startupOptset->get( SANE_NAME_GAMMA_VECTOR_R );
+       }
+
+       if( gt )
+	  gt->get( &old_gt );
+    }
+    else
+    {
+       /* it is not the first edit, use older values */
+       if( grayGt.active())
+       {
+	  /* This will be fine for all color gt's. */
+	  grayGt.get( &old_gt );
+	  kdDebug(29000) << "Gray Gamma Table is active " << endl;
+       }
+       else
+       {
+	  /* Gray is not active, but at the current implementation without
+	   * red/green/blue gammatables, but one for all, all gammatables
+	   * are equally. So taking the red one should be fine. TODO
+	   */
+	  if( redGt.active())
+	  {
+	     redGt.get( &old_gt );
+	     kdDebug(29000) << "Getting old gamma table from Red channel" << endl;
+	  }
+	  else
+	  {
+	     /* uh ! No current gammatable could be retrieved. Use the 100/0/0 gt
+	      * created by KGammaTable's constructor. Nothing to do for that.
+	      */
+	  }
+       }
+    }
 
     kdDebug(29000) << "Old gamma table: " << old_gt.getGamma() << ", " << old_gt.getBrightness() << ", " << old_gt.getContrast() << endl;
 
@@ -717,7 +872,7 @@ void ScanParams::slReloadAllGui( KScanOption* t)
 
     sane_device->slReloadAllBut( t );
 
-    /* Custom Gamma */
+    /* Custom Gamma <- What happens if that does not exist for some scanner ? TODO */
     KScanOption kso( SANE_NAME_CUSTOM_GAMMA );
 
     if( pb_edit_gtable )
@@ -742,7 +897,7 @@ void ScanParams::slAcquirePreview( void )
     slMaximalScanSize();
 
     if( ! sane_device ) kdDebug(29000) << "Aeetsch: sane_device is 0 !" << endl;
-    CHECK_PTR( sane_device );
+    Q_CHECK_PTR( sane_device );
     KScanStat stat = sane_device->acquirePreview( gray_preview );
 
     if( stat != KSCAN_OK )
@@ -802,28 +957,64 @@ void ScanParams::slCustomScanSize( QRect sel)
 }
 
 
-	/**
-	 * sets the scan area to the default, which is the whole area.
-	 */
+/**
+ * sets the scan area to the default, which is the whole area.
+ */
 void ScanParams::slMaximalScanSize( void )
 {
    kdDebug(29000) << "Setting to default" << endl;
    slCustomScanSize(QRect( 0,0,1000,1000));
 }
 
-#if 0
-QSize  ScanParams::sizeHint( )
+
+void ScanParams::slNewXResolution(KScanOption *opt)
 {
-   QPushButton pb_example( i18n("Preview Scan"), this );
-   // int w = pb_example.width();
+   if(! opt ) return;
 
-   /** Hmm - not really clean  TODO ! */
-   return( QSize( 360, 360 ) );
+   kdDebug(29000) << "Got new X-Resolution !" << endl;
 
-   // return( QSize( 2.2*w, 2.2*w) );
+   int x_res = 0;
+   opt->get( &x_res );
 
+   int y_res = x_res;
+   
+   if( xy_resolution_bind && xy_resolution_bind->active() )
+   {
+      /* That means, that x and y may be different */
+      KScanOption opt_y( SANE_NAME_SCAN_Y_RESOLUTION );
+      if( opt_y.valid () )
+      {
+	 opt_y.get( &y_res );
+      }
+   }
+
+   emit( scanResolutionChanged( x_res, y_res ) );
 }
-#endif
+
+void ScanParams::slNewYResolution(KScanOption *opt)
+{
+   if( ! opt ) return;
+
+   int y_res = 0;
+   opt->get( &y_res );
+
+   int x_res = y_res;
+   
+   if( xy_resolution_bind && xy_resolution_bind->active())
+   {
+      /* That means, that x and y may be different */
+      KScanOption opt_x( SANE_NAME_SCAN_X_RESOLUTION );
+      if( opt_x.valid () )
+      {
+	 opt_x.get( &x_res );
+      }
+   }
+
+   emit( scanResolutionChanged( x_res, y_res ) );
+   
+}
+
+
 KScanStat ScanParams::performADFScan( void )
 {
    KScanStat stat = KSCAN_OK;
